% calc_int
%
% Input  : info,mark,para,ad_data,para_p
% Output : hb_data,ad_data,para_p,err_flg
% Example: [hb_data,ad_data,para_p,err_flg] = calc_int(info,mark,para,ad_data,para_p);

%*******************************************************
%*           Make Integral Hb Data Function            *
%*                   Shingo Kawasaki                   *
%*                  HITACHI MECICAL                    *
%*******************************************************
% History?F03.11.08 Ver2.01  Kusabuka multi probe 
% History?F04.06.17 Ver2.03 Kusabuka  no load Message add
% History :06.06.28 Ver 2.05 Kusabuka    mark check bugu

function [hb_data,ad_data,para_p,err_flg] = calc_int(info,mark,para,ad_data,para_p);
wh = waitbar(0,'Please wait...');
%fprintf('calc_int\n');
data_cnt = 0;

%*********** Initialization ***********
if isfield(ad_data,'seg')==1;ad_data=rmfield(ad_data,'seg');end;
if isfield(ad_data,'fit')==1;ad_data=rmfield(ad_data,'fit');end;
clear oxy_fit;
clear deo_fit;
clear tot_fit;
clear mark_fit;
clear mark_fit_block;
add_mark  = 0;
err_flg=0;

clear hb_data;
hb_data = struct('ana_mode',{'','','','',''},'calc_flg',{'','','','',''});

for p_cnt=1:para_p.max_prb;
   waitbar(p_cnt/para_p.max_prb,wh);
   if (p_cnt==1 & para_p.sel_prb1 ~=1) | (p_cnt==2 & para_p.sel_prb2 ~=1) | (p_cnt==3 & para_p.sel_prb3 ~=1) |(p_cnt==4 & para_p.sel_prb4 ~=1) |(p_cnt==5 & para_p.sel_prb5 ~=1);
   elseif(p_cnt==1 & para_p.load_prb1 ~=1 ) | (p_cnt==2 & para_p.load_prb2 ~=1) | (p_cnt==3 & para_p.load_prb3 ~=1) |(p_cnt==4 & para_p.load_prb4 ~=1) |(p_cnt==5 & para_p.load_prb5 ~=1);    
   else;
         
      %*********** None Mark **********
      if mark.num==0;
         warndlg('Nonexistent Mark!','Warning');
         err_flg=1;
         break;
      end;

      %*********** Find Add Mark ***********
      ret = inttmchk(info,para,mark,hb_data,p_cnt,para.pre,para.post,para.relax);
      if ret == 3;
         warndlg('Please Select Mark!','Warning');
         err_flg=1;
         break;
      elseif ret == 1;
         warndlg('Input analyze time is too long !','Warning');
         err_flg=1;
         break;
      elseif ret == 2;
         %warndlg('Mark over laps !','Warning');
         %err_flg=1;
         %break;
      end;

      if para.sel_move == 0;
         add_mark  = find(mark.ave==1);
      else;
         add_mark  = find(mark.ave==1 & mark.move==0);
      end;
      %********** mark stim time cheak ***********
%      if info(p_cnt).measure_mode(1)==1;
%         for cnt=1:length(add_mark);
%             stim_time(cnt)=mark.point(add_mark(cnt),3)-mark.point(add_mark(cnt),2);
%            if cnt > 1;
%               if stim_time(cnt-1) ~= stim_time(cnt);
%                  warndlg('Stimulus time is different.!','Warning');
%                  err_flg=1;
%                  break;
%               end;
%            end;
%         end;
%      end;
      %*********** Cutting out Mark Block **********
      if info(p_cnt).measure_mode(1)==1; %****** Stim Mode *******
         block = mark.point(add_mark(1),3)-mark.point(add_mark(1),2)+para.pre+para.post+para.relax;
      elseif info(p_cnt).measure_mode(1)==2; %****** Event Mode *******
         block = 1+para.pre+para.post+para.relax;
      end;

      if err_flg ~=0;
          break;
      end;
      
      for j = 1:length(add_mark);
         ad_data(p_cnt).seg(:,:,j) = ad_data(p_cnt).raw([(mark.point(add_mark(j),2)-para.pre):mark.point(add_mark(j),2)+block-para.pre-1],[1:info(p_cnt).ad_ch_max]);
      end;

      %*********** Initialization ***********
      hb_data(p_cnt).ana_mode = 2;
      hb_data(p_cnt).calc_flg = 1;
      
      if p_cnt==1;  para_p.cal_flg1 = 2;end;
      if p_cnt==2;  para_p.cal_flg2 = 2;end;
      if p_cnt==3;  para_p.cal_flg3 = 2;end;
      if p_cnt==4;  para_p.cal_flg4 = 2;end;
      if p_cnt==5;  para_p.cal_flg5 = 2;end;
      %*********** data Select ***********
      data_cnt = data_cnt +1;
      %******** Calc polyfit using Pre and Post ************
      fprintf('Probe %d calculation.\n',p_cnt);

      block_time = [1:block]';
      for ad_ch = 1:info(p_cnt).ad_ch_max;
%         for sg = 1:last_mark);end;
         for sg = 1:length(add_mark);
         	mark_fit(1:para.pre)                          = ad_data(p_cnt).seg(1:para.pre,ad_ch,sg);
            mark_fit(para.pre+1:para.pre+para.post)       = ad_data(p_cnt).seg(block-para.post+1:block,ad_ch,sg);
            mark_fit_block(1:para.pre)                    = 1:para.pre;
            mark_fit_block(para.pre+1:para.pre+para.post) = block-para.post+1:block;
            ad_data(p_cnt).fit(:,ad_ch,sg)                = polyval(polyfit(mark_fit_block,mark_fit,para.fit_val),block_time);
         end;
      end;

      %********** Calc Integral Hb Data **********
%      for sg = 1:last_mark;end;
      for sg = 1:length(add_mark);
         for hb_ch = 1:(info(p_cnt).ad_ch_max/2);
            ad_ch_780 = info(p_cnt).adnmpn(2*hb_ch-1)+1;
            ad_ch_830 = info(p_cnt).adnmpn(2*hb_ch)+1;
      
            wlen_780 = round(info(p_cnt).wlen(ad_ch_780));
            wlen_830 = round(info(p_cnt).wlen(ad_ch_830));
      
            eoxy_780 = para.e_coef(find(para.e_coef(:,1)==wlen_780),3);
            eoxy_830 = para.e_coef(find(para.e_coef(:,1)==wlen_830),3);
            edeo_780 = para.e_coef(find(para.e_coef(:,1)==wlen_780),2);
            edeo_830 = para.e_coef(find(para.e_coef(:,1)==wlen_830),2);
      
            for j = 1:block;    
               %****** 780nm Fitting ******
               if ((ad_data(p_cnt).seg(j,ad_ch_780,sg)>0 & ad_data(p_cnt).fit(j,ad_ch_780,sg)>0) | (ad_data(p_cnt).seg(j,ad_ch_780,sg)<0 & ad_data(p_cnt).fit(j,ad_ch_780,sg)<0));
                  a_780 = log(ad_data(p_cnt).fit(j,ad_ch_780,sg)/ad_data(p_cnt).seg(j,ad_ch_780,sg));
               else;
                  a_780 = 0;
               end;
         
               %****** 830nm Fitting ******
               if ((ad_data(p_cnt).seg(j,ad_ch_830,sg)>0 & ad_data(p_cnt).fit(j,ad_ch_830,sg)>0) | (ad_data(p_cnt).seg(j,ad_ch_830,sg)<0 & ad_data(p_cnt).fit(j,ad_ch_830,sg)<0));
                  a_830 = log(ad_data(p_cnt).fit(j,ad_ch_830,sg)/ad_data(p_cnt).seg(j,ad_ch_830,sg));
               else;
                  a_830 = 0;
               end;
         
               %****** Oxy Hb ******
               if ((eoxy_780*edeo_830 - eoxy_830*edeo_780)==0);
                  oxy_fit(j,hb_ch,sg) = 0;
               else;
                  oxy_fit(j,hb_ch,sg) = (a_780*edeo_830 - a_830*edeo_780)/(eoxy_780*edeo_830 - eoxy_830*edeo_780);
               end;
         
               %****** Deoxy Hb ******
               if ((edeo_780*eoxy_830 - edeo_830*eoxy_780)==0);
                  deo_fit(j,hb_ch,sg) = 0;
               else;
                  deo_fit(j,hb_ch,sg) = (a_780*eoxy_830 - a_830*eoxy_780)/(edeo_780*eoxy_830 - edeo_830*eoxy_780); 
               end;
            end;
         end;
      end;
      tot_fit = oxy_fit + deo_fit;

      %***************** Calc Average *******************
      % added by xu cui
      if any(find(mark.contrast==1)) && any(find(mark.contrast==-1))
          tmp = zeros( size(oxy_fit,1), size(oxy_fit,2) );
          count = 0;
          tmp2 = tmp;          
          count2 = 0;
          for ii=1:length(add_mark)
              if mark.contrast(add_mark(ii)) == 1
                tmp = tmp + oxy_fit(:,:,ii);
                count = count + 1;
              elseif mark.contrast(add_mark(ii)) == -1
                tmp2 = tmp2 + oxy_fit(:,:,ii);
                count2 = count2 + 1;                  
              end
          end
          hb_data(p_cnt).raw(1,:,:) = tmp/count - tmp2/count2;

          tmp = zeros( size(deo_fit,1), size(deo_fit,2) );
          count = 0;
          tmp2 = tmp;          
          count2 = 0;          
          for ii=1:length(add_mark)
              if mark.contrast(add_mark(ii)) == 1
                tmp = tmp + deo_fit(:,:,ii);
                count = count + 1;
              elseif mark.contrast(add_mark(ii)) == -1
                tmp2 = tmp2 + deo_fit(:,:,ii);
                count2 = count2 + 1;                  
              end
          end
          hb_data(p_cnt).raw(2,:,:) = tmp/count - tmp2/count2;

          tmp = zeros( size(tot_fit,1), size(tot_fit,2) );
          count = 0;
          tmp2 = tmp;          
          count2 = 0;          
          for ii=1:length(add_mark)
              if mark.contrast(add_mark(ii)) == 1
                tmp = tmp + tot_fit(:,:,ii);
                count = count + 1;
              elseif mark.contrast(add_mark(ii)) == -1
                tmp2 = tmp2 + tot_fit(:,:,ii);
                count2 = count2 + 1;                  
              end
          end
          hb_data(p_cnt).raw(3,:,:) = tmp/count - tmp2/count2;      
      else
          hb_data(p_cnt).raw(1,:,:) = (sum(oxy_fit(:,:,:),3)/length(add_mark));
          hb_data(p_cnt).raw(2,:,:) = (sum(deo_fit(:,:,:),3)/length(add_mark));
          hb_data(p_cnt).raw(3,:,:) = (sum(tot_fit(:,:,:),3)/length(add_mark));
    %      hb_data(p_cnt).raw(1,:,:) = (sum(oxy_fit(:,:,add_mark),3)/length(add_mark));
    %      hb_data(p_cnt).raw(2,:,:) = (sum(deo_fit(:,:,add_mark),3)/length(add_mark));
    %      hb_data(p_cnt).raw(3,:,:) = (sum(tot_fit(:,:,add_mark),3)/length(add_mark));
      end

      %***************** Calc Filter *******************
      Fs = 1000/info(p_cnt).smpl_period;

      if para.high_flg==1 & para.low_flg==1; %**** Band Pass ****
         hb_data(p_cnt).calc_flg = 2;
         [b,a]=ellip(4,0.1,40,[para.high_val para.low_val]*2/Fs);
         [H,w]=freqz(b,a,512);
         for i=1:info(p_cnt).ad_ch_max/2;
            hb_data(p_cnt).fil(1,:,i) = filtfilt(b,a,hb_data(p_cnt).raw(1,:,i));
            hb_data(p_cnt).fil(2,:,i) = filtfilt(b,a,hb_data(p_cnt).raw(2,:,i));
            hb_data(p_cnt).fil(3,:,i) = filtfilt(b,a,hb_data(p_cnt).raw(3,:,i));
         end;
      end;

      if para.high_flg==1 & para.low_flg==0; %**** High Pass ****
         hb_data(p_cnt).calc_flg = 2;
         [b,a]=ellip(4,0.1,40,[para.high_val]*2/Fs,'high');
         [H,w]=freqz(b,a,512);
         for i=1:info(p_cnt).ad_ch_max/2;
            hb_data(p_cnt).fil(1,:,i) = filtfilt(b,a,hb_data(p_cnt).raw(1,:,i));
            hb_data(p_cnt).fil(2,:,i) = filtfilt(b,a,hb_data(p_cnt).raw(2,:,i));
            hb_data(p_cnt).fil(3,:,i) = filtfilt(b,a,hb_data(p_cnt).raw(3,:,i));
         end;
      end;

      if para.high_flg==0 & para.low_flg==1; %**** Low Pass ****
         hb_data(p_cnt).calc_flg = 2;
         [b,a]=ellip(4,0.1,40,[para.low_val]*2/Fs);
         [H,w]=freqz(b,a,512);
         for i=1:info(p_cnt).ad_ch_max/2;
            hb_data(p_cnt).fil(1,:,i) = filtfilt(b,a,hb_data(p_cnt).raw(1,:,i));
            hb_data(p_cnt).fil(2,:,i) = filtfilt(b,a,hb_data(p_cnt).raw(2,:,i));
            hb_data(p_cnt).fil(3,:,i) = filtfilt(b,a,hb_data(p_cnt).raw(3,:,i));
         end;
      end;
      
      %**** Moving Average ****
      if para.moveave_flg==1;
         if Fs*para.move_val*3 > length(hb_data(p_cnt).raw(1,:,1));
            warndlg('Data must have length more than 3 times filter order.','Warning !!');
            err_flg=4;
            break;
         end;
         a=1;
         % ceil
         b(1:ceil(Fs*para.move_val))=1/(Fs*para.move_val);
         hb_data(p_cnt).calc_flg = 2;
         %*** It is a moving average after a filter. ****
         if para.high_flg==1 | para.low_flg==1;
            for ch=1:info(p_cnt).ad_ch_max/2;
               hb_data(p_cnt).fil(1,:,ch) = filtfilt(b,a,hb_data(p_cnt).fil(1,:,ch));
               hb_data(p_cnt).fil(2,:,ch) = filtfilt(b,a,hb_data(p_cnt).fil(2,:,ch));
               hb_data(p_cnt).fil(3,:,ch) = filtfilt(b,a,hb_data(p_cnt).fil(3,:,ch));
            end;
         else;            %*** It is a moving average to RawData. ****
            for ch=1:info(p_cnt).ad_ch_max/2;
               hb_data(p_cnt).fil(1,:,ch) = filtfilt(b,a,hb_data(p_cnt).raw(1,:,ch));
               hb_data(p_cnt).fil(2,:,ch) = filtfilt(b,a,hb_data(p_cnt).raw(2,:,ch));
               hb_data(p_cnt).fil(3,:,ch) = filtfilt(b,a,hb_data(p_cnt).raw(3,:,ch));
            end;
         end;
      end;
      
  end;
end;

clear last_mark;
close(wh);
clear wh;
% if err_flg ~= 0;
%    del_fig(7,89);
% end;

if  (para_p.load_prb1 == 0 & para_p.load_prb2 ==0 & para_p.load_prb3 ==0 ...
       & para_p.load_prb4 == 0 & para_p.load_prb5 ==0);
   warndlg('Please read data.','Warning'); 
   return;
elseif data_cnt == 0 & isempty(add_mark)~=1 & mark.num ~= 0 & err_flg==0;
   warndlg('Warning Probe Select!  Please choose the proper Probe No.','Warning');
   return;
end;

