% Hb_fft_graph
%
% Input  : info,mark,para,para_p,hb_data,Sel_graph
% Output : None
% Example: hb_fft_graph(info,mark,para,para_p,hb_data,Sel_graph);

%*******************************************************
%*                Hb Data FFT Function                 *
%*                   Shingo Kawasaki                   *
%*                  HITACHI MECICAL                    *
%*******************************************************
% HistoryF02.11.11 Ver1.01  Futahashi KL conversion function is added
% HistoryF03.05.06 Ver2.00  Isawa     A display is changed into point->sec.
% HistoryF03.11.18 Ver2.01  Kusabuka@multi probe
% HistoryF06.03.07 Ver2.06  Kusabuka  Remake

function [fft_data,fft_graph_h] = hb_fft_graph(info,mark,para,para_p,hb_data,hb_graph_h,Sel_graph);

p_cnt                          = Sel_graph;
fft_graph_h(Sel_graph).chk_val = 1;
fft_graph_h(p_cnt).y_min       = 0;
fft_graph_h(p_cnt).y_max       = 20;

%********* FFT processing ***********
if hb_data(p_cnt).ana_mode == 1;      % continuas
    Fs = 1000/info(p_cnt).smpl_period;
    w  = (0:info(p_cnt).datanum-1)/info(p_cnt).datanum*(Fs);
    fft_data(p_cnt).fft_w = w;
else;                                % integral
    if para.sel_move == 0;            % Body move
        add_mark = find(mark.ave==1);
    else;
        add_mark = find(mark.ave==1 & mark.move==0);
    end;
    Fs = 1000/info(p_cnt).smpl_period;
    if info(p_cnt).measure_mode(1)==1; % STIM
        block = mark.point(add_mark(1),3)-mark.point(add_mark(1),2)+para.pre+para.post+para.relax;
    end;                               % EVENT
    if info(p_cnt).measure_mode(1)==2;
        block = 1+para.pre+para.post+para.relax;
    end;
    w = (0:block-1)/block*(Fs);
    fft_data(p_cnt).fft_w = w;
end;
% except_ch data 0 (local)
for i=1:(info(p_cnt).ad_ch_max/2);
    if info(p_cnt).err_ch(i)==1 & para_p.del_ch ==1;
        if hb_data(p_cnt).calc_flg==2;
            hb_data(p_cnt).fil(1,:,i)=0;
            hb_data(p_cnt).fil(2,:,i)=0;
            hb_data(p_cnt).fil(3,:,i)=0;
        end;
        hb_data(p_cnt).raw(1,:,i)=0;
        hb_data(p_cnt).raw(2,:,i)=0;
        hb_data(p_cnt).raw(3,:,i)=0;
    end;
end;

for ch=1:info(p_cnt).ad_ch_max/2;
    if para.high_flg == 1 | para.low_flg == 1 | para.moveave_flg == 1;
        if hb_data(p_cnt).calc_flg~=2;
            warndlg('Please set and re-calculate a filter.','Warning');
            return;
        end;
        if isfield(hb_data(p_cnt),'fil' ) ~= 1;
            warndlg('Please set and re-calculate a filter.','Warning');
            return;
        end;
        fft_data(p_cnt).fft_fil(1,:,ch) = abs(fft(hb_data(p_cnt).fil(1,:,ch)));
        fft_data(p_cnt).fft_fil(2,:,ch) = abs(fft(hb_data(p_cnt).fil(2,:,ch)));
        fft_data(p_cnt).fft_fil(3,:,ch) = abs(fft(hb_data(p_cnt).fil(3,:,ch)));
    end;
    fft_data(p_cnt).fft_raw(1,:,ch) = abs(fft(hb_data(p_cnt).raw(1,:,ch)));
    fft_data(p_cnt).fft_raw(2,:,ch) = abs(fft(hb_data(p_cnt).raw(2,:,ch)));
    fft_data(p_cnt).fft_raw(3,:,ch) = abs(fft(hb_data(p_cnt).raw(3,:,ch)));
end;

fft_fig = figure(17+(p_cnt-1));
clf;
fft_graph_h(p_cnt).fft_fig = fft_fig;
set(fft_graph_h(p_cnt).fft_fig,'Units','points');
set(fft_fig,'ToolBar','none');
plotedit(fft_fig,'hidetoolsmenu');
fft_posi = get(fft_graph_h(p_cnt).fft_fig,'Position');

% ************ FFT ***************
if hb_data(p_cnt).calc_flg==2;
    set(fft_graph_h(p_cnt).fft_fig,'Name',sprintf('FFT Graph Probe%d (Filter)',p_cnt));
else;
    set(fft_graph_h(p_cnt).fft_fig,'Name',sprintf('FFT Graph Probe%d',p_cnt));
end;

for ch=1:info(p_cnt).ad_ch_max/2;
    gco = axes('Position',hb_graph_h(p_cnt).graph_posi(ch).p);
    set(gco,'Fontsize',para_p.fsize);
    hold on;grid on;
    fft_graph_h(p_cnt).fft_raw(1,ch) = plot(w,fft_data(p_cnt).fft_raw(1,:,ch)','k'); % oxy
    fft_graph_h(p_cnt).fft_raw(2,ch) = plot(w,fft_data(p_cnt).fft_raw(2,:,ch)','k'); % deoxy
    fft_graph_h(p_cnt).fft_raw(3,ch) = plot(w,fft_data(p_cnt).fft_raw(3,:,ch)','k'); % total
    set(fft_graph_h(p_cnt).fft_raw(1,ch),'Visible','on');
    set(fft_graph_h(p_cnt).fft_raw(2,ch),'Visible','off');
    set(fft_graph_h(p_cnt).fft_raw(3,ch),'Visible','off');
    title(['CH',num2str(ch)],'FontSize',para_p.fsize);
    if hb_data(p_cnt).calc_flg==2;
        fft_graph_h(p_cnt).fft_fil(1,ch) = plot(w,fft_data(p_cnt).fft_fil(1,:,ch)','r');  % oxy
        fft_graph_h(p_cnt).fft_fil(2,ch) = plot(w,fft_data(p_cnt).fft_fil(2,:,ch)','b');  % deoxy
        fft_graph_h(p_cnt).fft_fil(3,ch) = plot(w,fft_data(p_cnt).fft_fil(3,:,ch)','g');  % total
        set(fft_graph_h(p_cnt).fft_fil(1,ch),'Visible','on');
        set(fft_graph_h(p_cnt).fft_fil(2,ch),'Visible','off');
        set(fft_graph_h(p_cnt).fft_fil(3,ch),'Visible','off');
    end;
    if hb_data(p_cnt).ana_mode == 1;
        axis([0 ceil(Fs/2) 0 fft_graph_h(p_cnt).y_max ]);
    elseif hb_data(p_cnt).ana_mode == 2;
        axis([0 ceil(Fs/2) 0 fft_graph_h(p_cnt).y_max ]);
    end;
    set(gco,'box','on');
    set(gca,'ytick',[0 fft_graph_h(p_cnt).y_max /2 fft_graph_h(p_cnt).y_max ]);
    set(gca,'yticklabel',[0 fft_graph_h(p_cnt).y_max /2 fft_graph_h(p_cnt).y_max ]);
    label_put(info,hb_graph_h,para,para_p,p_cnt,ch,fft_graph_h(p_cnt).fft_fig,gco);

    hold off;
end;

%************ Renge ***********
%************ min ***********
fft_graph_h(p_cnt).lenge_min = uicontrol('Parent',fft_graph_h(p_cnt).fft_fig,...
    'Units','points',...
    'BackgroundColor',[1 1 1],...
    'Position',[1 fft_posi(4)/2-fft_posi(4)/4 40 14],...
    'Style','edit',...
    'String',fft_graph_h(p_cnt).y_min,...
    'Callback',['Sel_graph=get(gca,''Parent'')-(17-1);',...
    'h=findobj(fft_graph_h(Sel_graph).fft_fig,''type'',''axes'');',...
    'TmpData=str2num(get(fft_graph_h(Sel_graph).lenge_min,''string''));',...% Ver 2.00 ->
    'if length(TmpData) ~= 0;',...
    'ret=strchknum(get(fft_graph_h(Sel_graph).lenge_min,''string''));',...
    'TmpData = round(TmpData*100)/100;',...
    'if ret > 0;',...
    'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
    'elseif TmpData >= fft_graph_h(Sel_graph).y_max;',...
    'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
    'elseif TmpData < 0;',...
    'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
    'else;',...
    'Fs = 1000/info(Sel_graph).smpl_period;',...
    'fft_graph_h(Sel_graph).y_min=TmpData;',...
    'for i=1:(info(Sel_graph).ad_ch_max/2);',...
    'set(h(i),''ylim'',[fft_graph_h(Sel_graph).y_min fft_graph_h(Sel_graph).y_max]);',...
    'set(h(i),''ytick'',[fft_graph_h(Sel_graph).y_min (fft_graph_h(Sel_graph).y_max-fft_graph_h(Sel_graph).y_min)/2 fft_graph_h(Sel_graph).y_max]);',...
    'set(h(i),''yticklabel'',[fft_graph_h(Sel_graph).y_min (fft_graph_h(Sel_graph).y_max-fft_graph_h(Sel_graph).y_min)/2 fft_graph_h(Sel_graph).y_max]);',...
    'axis([0 Fs/2 fft_graph_h(Sel_graph).y_min fft_graph_h(Sel_graph).y_max]);',...
    'set(fft_graph_h(Sel_graph).fft_fig,''CurrentAxes'',h(i));',...
    'label_put(info,hb_graph_h,para,para_p,Sel_graph,(info(Sel_graph).ad_ch_max/2)-(i-1),fft_graph_h(Sel_graph).fft_fig,h(i));',...   % label drow
    'end;',...
    'end;',...
    'set(fft_graph_h(Sel_graph).lenge_min,''string'', fft_graph_h(Sel_graph).y_min);',...
    'clear ret;',...
    'else;',...
    'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
    'set(fft_graph_h(Sel_graph).lenge_min,''string'', fft_graph_h(Sel_graph).y_min);',...
    'end;',...
    'clear TmpData;clear i;clear h;clear Fs;'],...
    'Tag','EditText1');

%************ max Renge ***********
fft_graph_h(p_cnt).y_unit = uicontrol('Parent',fft_graph_h(p_cnt).fft_fig,...
    'Units','points',...
    'Position',[1 fft_posi(4)/2+fft_posi(4)/4+14 40 10],...
    'BackgroundColor',[0.8 0.8 0.8],...
    'Style','text',...
    'String','Frequency',...
    'Tag','tag2');

fft_graph_h(p_cnt).lenge_max = uicontrol('Parent',fft_graph_h(p_cnt).fft_fig,...
    'Units','points',...
    'BackgroundColor',[1 1 1],...
    'Position',[1 fft_posi(4)/2+fft_posi(4)/4 40 14],...
    'Style','edit',...
    'String',fft_graph_h(p_cnt).y_max,...
    'Callback',['Sel_graph=get(gca,''Parent'')-(17-1);',...
    'h=findobj(fft_graph_h(Sel_graph).fft_fig,''type'',''axes'');',...
    'TmpData=str2num(get(fft_graph_h(Sel_graph).lenge_max,''string''));',...
    'if length(TmpData) ~= 0;',...
    'ret=strchknum(get(fft_graph_h(Sel_graph).lenge_max,''string''));',...
    'TmpData = round(TmpData*100)/100;',...
    'if ret > 0;',...
    'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
    'elseif TmpData <= fft_graph_h(Sel_graph).y_min;',...
    'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
    'elseif TmpData > 1000;',...
    'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
    'else;',...
    'Fs = 1000/info(Sel_graph).smpl_period;',...
    'fft_graph_h(Sel_graph).y_max=TmpData;',...
    'for i=1:(info(Sel_graph).ad_ch_max/2);',...
    'set(h(i),''ylim'',[fft_graph_h(Sel_graph).y_min fft_graph_h(Sel_graph).y_max]);',...
    'set(h(i),''ytick'',[fft_graph_h(Sel_graph).y_min (fft_graph_h(Sel_graph).y_max-fft_graph_h(Sel_graph).y_min)/2 fft_graph_h(Sel_graph).y_max]);',...
    'set(h(i),''yticklabel'',[fft_graph_h(Sel_graph).y_min (fft_graph_h(Sel_graph).y_max-fft_graph_h(Sel_graph).y_min)/2 fft_graph_h(Sel_graph).y_max]);',...
    'axis([0 Fs/2 fft_graph_h(Sel_graph).y_min fft_graph_h(Sel_graph).y_max]);',...
    'set(fft_graph_h(Sel_graph).fft_fig,''CurrentAxes'',h(i));',...
    'label_put(info,hb_graph_h,para,para_p,Sel_graph,(info(Sel_graph).ad_ch_max/2)-(i-1),fft_graph_h(Sel_graph).fft_fig,h(i));',...   % label drow
    'end;',...
    'end;',...
    'set(fft_graph_h(Sel_graph).lenge_max,''string'',fft_graph_h(Sel_graph).y_max);',...
    'clear ret;',...
    'else;',...
    'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
    'set(fft_graph_h(Sel_graph).lenge_max,''string'', fft_graph_h(Sel_graph).y_max);',...
    'end;',...
    'clear TmpData;clear h;clear i;clear Fs;'],...
    'Tag','EditText2');

%************** check **************
fft_graph_h(Sel_graph).chk = uicontrol('Parent',fft_graph_h(Sel_graph).fft_fig,...
    'Units','points',...
    'Position',[1 15 41 15], ...
    'BackgroundColor',[1 1 1], ...
    'Style','popupmenu',...
    'String','Oxy  |Deoxy|Total',...
    'Value',fft_graph_h(Sel_graph).chk_val,...
    'Callback',['Sel_graph=get(gca,''Parent'')-(17-1);',...
    'fft_graph_h(Sel_graph).chk_val = get(fft_graph_h(Sel_graph).chk,''value'');',...
    'if fft_graph_h(Sel_graph).chk_val == 1;',...
    'for ch=1:(info(Sel_graph).ad_ch_max/2);',...
    'set(fft_graph_h(Sel_graph).fft_raw(1,ch),''Visible'',''on'');',...
    'set(fft_graph_h(Sel_graph).fft_raw(2,ch),''Visible'',''off'');',...
    'set(fft_graph_h(Sel_graph).fft_raw(3,ch),''Visible'',''off'');',...
    'if para.high_flg == 1 | para.low_flg == 1 | para.moveave_flg == 1;',...
    'if hb_data(Sel_graph).calc_flg==2;',...
    'set(fft_graph_h(Sel_graph).fft_fil(1,ch),''Visible'',''on'');',...
    'set(fft_graph_h(Sel_graph).fft_fil(2,ch),''Visible'',''off'');',...
    'set(fft_graph_h(Sel_graph).fft_fil(3,ch),''Visible'',''off'');',...
    'end;',...
    'end;',...
    'end;',...
    'elseif fft_graph_h(Sel_graph).chk_val == 2;',...
    'for ch=1:(info(Sel_graph).ad_ch_max/2);',...
    'set(fft_graph_h(Sel_graph).fft_raw(1,ch),''Visible'',''off'');',...
    'set(fft_graph_h(Sel_graph).fft_raw(2,ch),''Visible'',''on'');',...
    'set(fft_graph_h(Sel_graph).fft_raw(3,ch),''Visible'',''off'');',...
    'if para.high_flg == 1 | para.low_flg == 1 | para.moveave_flg == 1;',...
    'if hb_data(Sel_graph).calc_flg==2;',...
    'set(fft_graph_h(Sel_graph).fft_fil(1,ch),''Visible'',''off'');',...
    'set(fft_graph_h(Sel_graph).fft_fil(2,ch),''Visible'',''on'');',...
    'set(fft_graph_h(Sel_graph).fft_fil(3,ch),''Visible'',''off'');',...
    'end;',...
    'end;',...
    'end;',...
    'elseif fft_graph_h(Sel_graph).chk_val == 3;',...
    'for ch=1:(info(Sel_graph).ad_ch_max/2);',...
    'set(fft_graph_h(Sel_graph).fft_raw(1,ch),''Visible'',''off'');',...
    'set(fft_graph_h(Sel_graph).fft_raw(2,ch),''Visible'',''off'');',...
    'set(fft_graph_h(Sel_graph).fft_raw(3,ch),''Visible'',''on'');',...
    'if para.high_flg == 1 | para.low_flg == 1 | para.moveave_flg == 1;',...
    'if hb_data(Sel_graph).calc_flg==2;',...
    'set(fft_graph_h(Sel_graph).fft_fil(1,ch),''Visible'',''off'');',...
    'set(fft_graph_h(Sel_graph).fft_fil(2,ch),''Visible'',''off'');',...
    'set(fft_graph_h(Sel_graph).fft_fil(3,ch),''Visible'',''on'');',...
    'end;',...
    'end;',...
    'end;',...
    'end;',...
    'clear ch;',...
    ],...
    'Tag','Checkbox1');

%************** file out **************
fft_graph_h(p_cnt).fout = uicontrol('Parent',fft_graph_h(p_cnt).fft_fig,...
    'Units','points',...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Position',[385 0 35 14],...
    'String','FileOut',...
    'Callback',['if move_stop == 1;',...
    'Sel_graph=get(gca,''Parent'')-(17-1);',...
    'fout_fft(info,para,para_p,fft_data,Sel_graph);',...
    'else;',...
    'warndlg(''Please push a stop button.'',''Warning !!'');',...
    'end;',...
    ],...
    'Tag','Pushbutton1');

%************** refresh **************
fft_graph_h(p_cnt).fft_ref = uicontrol('Parent',fft_graph_h(p_cnt).fft_fig, ...
    'Units','points', ...
    'BackgroundColor',[1.0 0.9 0.1], ...
    'Position',[1 0 35 14], ...
    'String','Refresh',...
    'Callback',['Sel_graph=get(gca,''Parent'')-(17-1);'...
    'fft_posi=get(fft_graph_h(Sel_graph).fft_fig,''Position'');',...
    'set(fft_graph_h(Sel_graph).fout,''Position'',[fft_posi(3)-35 0 35 14]);',...
    'set(fft_graph_h(Sel_graph).y_unit,''Position'',[1 fft_posi(4)/2+fft_posi(4)/4+14 40 10]);',...
    'set(fft_graph_h(Sel_graph).lenge_max,''Position'',[1 fft_posi(4)/2+fft_posi(4)/4 40 14]);',...
    'set(fft_graph_h(Sel_graph).chk,''Position'',[1 15 41 15]);',...
    'clear fft_posi;',...
    ],...
    'Tag','Pushbutton3');
