% hb_graph
%
% Input  : info,mark,para,hb_data,para_p,Sel_graph
% Output : para,hb_data,hb_graph_h,hb_map_h
% Example: [para,hb_data,hb_graph_h,hb_map_h] = hb_graph(info,mark,para,hb_data,para_p,Sel_graph); 

%*******************************************************
%*               Plot Hb Graph Function                *
%*                   Shingo Kawasaki                   *
%*                  HITACHI MECICAL                    *
%*******************************************************
% History:02.11.11 Ver1.01  futahasi  KL conversion function is added
% History:03.05.06 Ver2.00  isawa?@   A display is changed into point->sec.
% History:03.11.07 Ver2.01  Kusabuka  Multi probe 
% History:04.04.28 Ver2.01  Kawasaki  Change function name 
% History:06.03.14 Ver2.03  Kusabuka  FFT,Spect 

function [para,hb_data,hb_graph_h,hb_map_h,fft_data,fft_graph_h] = hb_graph(info,mark,para,hb_data,para_p,Sel_graph); 
%fprintf('hb_graph\n');
%********* Initial value (hb_graph) *********
del_fig(7,16);
del_fig(28,73);
del_fig(17,21);
del_fig(75,79);  % Spect
del_fig(80,80);  % 3D

if para.sel_move == 0;
   add_mark  = find(mark.ave==1);
else;
   if isfield(mark,'move') == 1;
      add_mark  = find(mark.ave==1 & mark.move==0);
   else;
      add_mark  = find(mark.ave==1);
   end;
end;

for p_cnt=1:para_p.max_prb;					% Probe loop
   
   if (p_cnt==1 & para_p.sel_prb1 ~=1) | (p_cnt==2 & para_p.sel_prb2 ~=1) | (p_cnt==3 & para_p.sel_prb3 ~=1) |(p_cnt==4 & para_p.sel_prb4 ~=1) |(p_cnt==5 & para_p.sel_prb5 ~=1);
   elseif (p_cnt==1 & para_p.load_prb1 ~=1 ) | (p_cnt==2 & para_p.load_prb2 ~=1) | (p_cnt==3 & para_p.load_prb3 ~=1) | (p_cnt==4 & para_p.load_prb4 ~=1) | (p_cnt==5 & para_p.load_prb5 ~=1);
   else;
      Sel_graph = p_cnt;
      hb_graph_h(p_cnt).time_min =1;
      [hb_graph_h]=graph_posi(info,hb_graph_h,p_cnt,para_p);
      fft_data(p_cnt).flg=0;
      fft_graph_h(p_cnt).flg=0;
      hb_graph_h(p_cnt).oxy_val=1;
      hb_graph_h(p_cnt).deoxy_val=1;
      hb_graph_h(p_cnt).total_val=1;
      %******** Initial value ********
      if hb_data(p_cnt).ana_mode == 1; %*** Continuous Hb ***
         hb_graph_h(p_cnt).time_max = info(p_cnt).datanum;
         para.sel_point      = (floor((hb_graph_h(p_cnt).time_max-hb_graph_h(p_cnt).time_min)/2)*10)/10; 
         hb_map_h(p_cnt).topo_min   = -1;
         hb_map_h(p_cnt).topo_max   = 1;   
         hb_graph_h(p_cnt).hb_min   = -1;
         hb_graph_h(p_cnt).hb_max   = 1;
      end;

      if hb_data(p_cnt).ana_mode == 2; %*** Integral Hb ***
         if info(p_cnt).measure_mode(1)==1;block = mark.point(add_mark(1),3)-mark.point(add_mark(1),2)+para.pre+para.post+para.relax;end;
         if info(p_cnt).measure_mode(1)==2;block = 1+para.pre+para.post+para.relax;end;
         hb_graph_h(p_cnt).time_max = block;
         para.sel_point      = floor((hb_graph_h(p_cnt).time_max-hb_graph_h(p_cnt).time_min)/2);
         hb_map_h(p_cnt).topo_min   = -0.5;
         hb_map_h(p_cnt).topo_max   = 0.5;
         hb_graph_h(p_cnt).hb_min   = -0.5;
         hb_graph_h(p_cnt).hb_max   = 0.5;

      end;

%******** Plot Graph ********
      hb_graph_h(p_cnt).hb_fig = figure(7+(p_cnt-1));
      set(hb_graph_h(p_cnt).hb_fig,'Units','points');
      reset(hb_graph_h(p_cnt).hb_fig);
      set(0,'CurrentFigure',hb_graph_h(p_cnt).hb_fig);
      clf;
      plotedit(hb_graph_h(p_cnt).hb_fig,'hidetoolsmenu');
      if hb_data(p_cnt).calc_flg==2;  
         set(hb_graph_h(p_cnt).hb_fig,'Name',sprintf('Hb Graph Probe %d(Filter)',p_cnt));
      else;
         set(hb_graph_h(p_cnt).hb_fig,'Name',sprintf('Hb Graph Probe %d',p_cnt));
      end;
      raw_posi = get(hb_graph_h(p_cnt).hb_fig,'Position'); 
      raw_posi(1) = raw_posi(1)+((p_cnt-1)*10);
      set(hb_graph_h(p_cnt).hb_fig,'Position',raw_posi);
      set(hb_graph_h(p_cnt).hb_fig,'Interruptible','off');
      set(hb_graph_h(p_cnt).hb_fig,'CloseRequestFcn','move_stop=1;closereq;');
      
      %************ Button **************
      %************** check **************
      hb_graph_h(p_cnt).oxy_chk = uicontrol('Parent',hb_graph_h(p_cnt).hb_fig, ...
                     'Units','points', ...
                     'Position',[1 48 30 15], ...
                     'BackgroundColor',[0.8 0.8 0.8], ...
                     'Style','checkbox', ...
                     'String','Oxy',...
                     'Value',hb_graph_h(p_cnt).oxy_val,...
                     'Callback',['Sel_graph=get(gca,''Parent'')-(7-1);',...
                                 'hb_graph_h(Sel_graph).oxy_val = get(gcbo,''value'');',...
                                 'if move_stop == 1;',...
                                    'if hb_graph_h(Sel_graph).oxy_val == 1;',... 
                                        'if hb_data(Sel_graph).calc_flg==2;',...  
                                           'set(hb_graph_h(Sel_graph).fil_graph(1,:),''Visible'',''on'');',...
                                         'else;',...
                                           'set(hb_graph_h(Sel_graph).raw_graph(1,:),''Visible'',''on'');',...
                                        'end;',...
                                    'else;',... 
                                        'if hb_data(Sel_graph).calc_flg==2;',...  
                                           'set(hb_graph_h(Sel_graph).fil_graph(1,:),''Visible'',''off'');',...
                                         'else;',...
                                           'set(hb_graph_h(Sel_graph).raw_graph(1,:),''Visible'',''off'');',...
                                        'end;',...
                                     'end;',...
                                 'else;',...
                                    'if hb_graph_h(Sel_graph).oxy_val == 1;',...
                                       'set(hb_graph_h(Sel_graph).oxy_chk,''Value'',0);',...
                                       'hb_graph_h(Sel_graph).oxy_val = 0;',...
                                    'else;',...
                                       'set(hb_graph_h(Sel_graph).oxy_chk,''Value'',1);',...
                                       'hb_graph_h(Sel_graph).oxy_val = 1;',...
                                    'end;',...
                                    'warndlg(''Please push a stop button.'',''Warning !!'');',...
                                 'end;',...
                                ],...
                                'Tag','checkbox1');
      hb_graph_h(p_cnt).deoxy_chk = uicontrol('Parent',hb_graph_h(p_cnt).hb_fig, ...
                     'Units','points', ...
                     'Position',[1 33 40 15], ...
                     'BackgroundColor',[0.8 0.8 0.8], ...
                     'Style','checkbox', ...
                     'String','Deoxy',...
                     'Value',hb_graph_h(p_cnt).deoxy_val,...
                     'Callback',['Sel_graph=get(gca,''Parent'')-(7-1);',...
                                 'hb_graph_h(Sel_graph).deoxy_val = get(gcbo,''value'');',...
                                 'if move_stop == 1;',...
                                    'if hb_graph_h(Sel_graph).deoxy_val == 1;',... 
                                        'if hb_data(Sel_graph).calc_flg==2;',...  
                                           'set(hb_graph_h(Sel_graph).fil_graph(2,:),''Visible'',''on'');',...
                                         'else;',...
                                           'set(hb_graph_h(Sel_graph).raw_graph(2,:),''Visible'',''on'');',...
                                        'end;',...
                                    'else;',... 
                                        'if hb_data(Sel_graph).calc_flg==2;',...  
                                           'set(hb_graph_h(Sel_graph).fil_graph(2,:),''Visible'',''off'');',...
                                         'else;',...
                                           'set(hb_graph_h(Sel_graph).raw_graph(2,:),''Visible'',''off'');',...
                                        'end;',...
                                     'end;',...
                                 'else;',...
                                    'if hb_graph_h(Sel_graph).deoxy_val == 1;',...
                                       'set(hb_graph_h(Sel_graph).deoxy_chk,''Value'',0);',...
                                       'hb_graph_h(Sel_graph).deoxy_val = 0;',...
                                    'else;',...
                                       'set(hb_graph_h(Sel_graph).deoxy_chk,''Value'',1);',...
                                       'hb_graph_h(Sel_graph).deoxy_val = 1;',...
                                    'end;',...
                                    'warndlg(''Please push a stop button.'',''Warning !!'');',...
                                 'end;',...
                                ],...
                                'Tag','checkbox2');
      hb_graph_h(p_cnt).total = uicontrol('Parent',hb_graph_h(p_cnt).hb_fig, ...
                     'Units','points', ...
                     'Position',[1 18 40 15], ...
                     'BackgroundColor',[0.8 0.8 0.8], ...
                     'Style','checkbox', ...
                     'String','Total',...
                     'Value',hb_graph_h(p_cnt).total_val,...
                     'Callback',['Sel_graph=get(gca,''Parent'')-(7-1);',...
                                 'hb_graph_h(Sel_graph).total_val = get(gcbo,''value'');',...
                                 'if move_stop == 1;',...
                                    'if hb_graph_h(Sel_graph).total_val == 1;',... 
                                        'if hb_data(Sel_graph).calc_flg==2;',...  
                                           'set(hb_graph_h(Sel_graph).fil_graph(3,:),''Visible'',''on'');',...
                                         'else;',...
                                           'set(hb_graph_h(Sel_graph).raw_graph(3,:),''Visible'',''on'');',...
                                        'end;',...
                                    'else;',... 
                                        'if hb_data(Sel_graph).calc_flg==2;',...  
                                           'set(hb_graph_h(Sel_graph).fil_graph(3,:),''Visible'',''off'');',...
                                         'else;',...
                                           'set(hb_graph_h(Sel_graph).raw_graph(3,:),''Visible'',''off'');',...
                                        'end;',...
                                     'end;',...
                                 'else;',...
                                    'if hb_graph_h(Sel_graph).total_val == 1;',...
                                       'set(hb_graph_h(Sel_graph).total,''Value'',0);',...
                                       'hb_graph_h(Sel_graph).total_val = 0;',...
                                    'else;',...
                                       'set(hb_graph_h(Sel_graph).total,''Value'',1);',...
                                       'hb_graph_h(Sel_graph).total_val = 1;',...
                                    'end;',...
                                    'warndlg(''Please push a stop button.'',''Warning !!'');',...
                                 'end;',...
                                ],...
                                'Tag','checkbox3');


      %************ min Renge ***********
      hb_graph_h(Sel_graph).raw.y_min = uicontrol('Parent',hb_graph_h(Sel_graph).hb_fig,...
               'Units','points',...
               'BackgroundColor',[1 1 1],...
               'Position',[1 raw_posi(4)/2-raw_posi(4)/4+6 40 14],...
               'Style','edit',...
               'String',hb_graph_h(Sel_graph).hb_min,...
               'Callback',['Sel_graph=get(gca,''Parent'')-(7-1);',...
                           'h=findobj(hb_graph_h(Sel_graph).hb_fig,''type'',''axes'');',...
                           'TmpData=str2num(get(hb_graph_h(Sel_graph).raw.y_min,''string''));',...% Ver 2.00 ->
                           'if length(TmpData) ~= 0;',...
                              'ret=strchknum(get(hb_graph_h(Sel_graph).raw.y_min,''string''));',...
                              'TmpData = round(TmpData*100)/100;',...
                              'if ret > 0;',...
                                  'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                              'elseif TmpData >= hb_graph_h(Sel_graph).hb_max;',...
                                  'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                              'elseif TmpData < -1000;',...
                                  'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                              'else;',...
                                 'hb_graph_h(Sel_graph).hb_min=TmpData;',...% Ver 2.00 <-
                                 'if isfield(hb_graph_h(Sel_graph),''raw_graph'')==1;',...
                                    'set(hb_graph_h(Sel_graph).raw_graph(:,:),''Visible'',''off'');',...
                                 'end;',...
                                 'if isfield(hb_graph_h(Sel_graph),''fil_graph'')==1;',...
                                    'set(hb_graph_h(Sel_graph).fil_graph(:,:),''Visible'',''off'');',...
                                 'end;',...
                                 'for i=1:(info(Sel_graph).ad_ch_max/2);',...
                                    'mark_line(info,para,para_p,mark,hb_data,hb_graph_h,0,0,Sel_graph,i,1);',...  % Mark line
                                    '[hb_graph_h] = drow_graph(info,para,para_p,mark,hb_data,hb_graph_h,Sel_graph,i);',...  % drow graph
                                    'set(hb_graph_h(Sel_graph).hb_fig,''CurrentAxes'',h(info(Sel_graph).ad_ch_max/2-(i-1)));',...
                                    'label_put(info,hb_graph_h,para,para_p,Sel_graph,i,hb_graph_h(Sel_graph).hb_fig,h(info(Sel_graph).ad_ch_max/2-(i-1)) );',...   % label drow
                                 'end;',...
                              'end;',...
                              'set(hb_graph_h(Sel_graph).raw.y_min,''string'', hb_graph_h(Sel_graph).hb_min);',...
                              'clear ret;',...
                           'else;',...
                              'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                              'set(hb_graph_h(Sel_graph).raw.y_min,''string'', hb_graph_h(Sel_graph).hb_min);',...
                           'end;',...
                           'clear TmpData;clear i;clear h;'],...
               'Tag','EditText1');

      %************ max Renge ***********
      hb_graph_h(Sel_graph).raw.y_unit = uicontrol('Parent',hb_graph_h(Sel_graph).hb_fig,...
              'Units','points',...
              'Position',[2 raw_posi(4)/2+raw_posi(4)/4+14 30 10],...
              'BackgroundColor',[0.8 0.8 0.8],...
	           'Style','text',...
              'String','mMmm',...% Ver 2.00 -><-
	          'Tag','tag2');
      hb_graph_h(Sel_graph).raw.y_max = uicontrol('Parent',hb_graph_h(Sel_graph).hb_fig,...
               'Units','points',...
               'BackgroundColor',[1 1 1],...
               'Position',[1 raw_posi(4)/2+raw_posi(4)/4 40 14],...
               'Style','edit',...
               'String',hb_graph_h(Sel_graph).hb_max,...
               'Callback',['Sel_graph=get(gca,''Parent'')-(7-1);',...
                           'h=findobj(hb_graph_h(Sel_graph).hb_fig,''type'',''axes'');',...
                           'TmpData=str2num(get(hb_graph_h(Sel_graph).raw.y_max,''string''));',...% Ver 2.00 ->
                           'if length(TmpData) ~= 0;',...
                              'ret=strchknum(get(hb_graph_h(Sel_graph).raw.y_max,''string''));',...
                              'TmpData = round(TmpData*100)/100;',...
                              'if ret > 0;',...
                                  'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                              'elseif TmpData <= hb_graph_h(Sel_graph).hb_min;',...
                                  'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                              'elseif TmpData > 1000;',...
                                  'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                              'else;',...
                                 'hb_graph_h(Sel_graph).hb_max=TmpData;',...% Ver 2.00 <-
                                 'if isfield(hb_graph_h(Sel_graph),''raw_graph'')==1;',...
                                    'set(hb_graph_h(Sel_graph).raw_graph(:,:),''Visible'',''off'');',...
                                 'end;',...
                                 'if isfield(hb_graph_h(Sel_graph),''fil_graph'')==1;',...
                                    'set(hb_graph_h(Sel_graph).fil_graph(:,:),''Visible'',''off'');',...
                                 'end;',...
                                 'for i=1:(info(Sel_graph).ad_ch_max/2);',...
                                    'mark_line(info,para,para_p,mark,hb_data,hb_graph_h,0,0,Sel_graph,i,1);',...  % Mark line
                                    '[hb_graph_h] = drow_graph(info,para,para_p,mark,hb_data,hb_graph_h,Sel_graph,i);',...  % drow graph
                                    'set(hb_graph_h(Sel_graph).hb_fig,''CurrentAxes'',h(info(Sel_graph).ad_ch_max/2-(i-1)));',...
                                    'label_put(info,hb_graph_h,para,para_p,Sel_graph,i,hb_graph_h(Sel_graph).hb_fig,h(info(Sel_graph).ad_ch_max/2-(i-1)) );',...   % label drow
                                 'end;',...
                              'end;',...
                              'set(hb_graph_h(Sel_graph).raw.y_max,''string'', hb_graph_h(Sel_graph).hb_max);',...
                              'clear ret;',...
                           'else;',...
                              'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                              'set(hb_graph_h(Sel_graph).raw.y_max,''string'', hb_graph_h(Sel_graph).hb_max);',...
                           'end;',...
                           'clear TmpData;clear h;clear i;'],...
               'Tag','EditText2');
            
      %************ Graph Feeld Renge min sec ***********
      hb_graph_h(Sel_graph).raw.t_min = uicontrol('Parent',hb_graph_h(Sel_graph).hb_fig,...
               'Units','points',...
               'BackgroundColor',[1 1 1],...
               'Position',[raw_posi(3)/2-raw_posi(3)/4-40 1 40 14],...
               'Style','edit',...
               'String',hb_graph_h(Sel_graph).time_min*info(Sel_graph).smpl_period/1000,...
               'Callback',['Sel_graph=get(gca,''Parent'')-(7-1);',...
                           'h=findobj(hb_graph_h(Sel_graph).hb_fig,''type'',''axes'');',...
                           'TmpData=str2num(get(hb_graph_h(Sel_graph).raw.t_min,''string''));',...% Ver 2.00 ->
                           'if length(TmpData) ~= 0;',...
                              'ret=strchknum(get(hb_graph_h(Sel_graph).raw.t_min,''string''));',...
                              'TmpData = round(TmpData*10)/10;',...
                              'TmpData=round(TmpData/(info(Sel_graph).smpl_period/1000)*10)/10;',...
                              'if ret > 0;',...
                                 'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                              'elseif TmpData >= hb_graph_h(Sel_graph).time_max | TmpData < 1;',...
                                 'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                              'else;',...
                                 'hb_graph_h(Sel_graph).time_min=TmpData;',...
                                 'TimeMin = round(hb_graph_h(Sel_graph).time_min*(info(Sel_graph).smpl_period/1000)*10)/10;',...
                                 'TimeMax = round(hb_graph_h(Sel_graph).time_max*(info(Sel_graph).smpl_period/1000)*10)/10;',...
                                 'TimeStep = round((((hb_graph_h(Sel_graph).time_max-hb_graph_h(Sel_graph).time_min)*(info(Sel_graph).smpl_period/1000))/2)*10)/10;',...
                                 'lab(1)=TimeMin; lab(2)=TimeMin+TimeStep; lab(3)=TimeMax;',...
                                 'for i=1:(info(Sel_graph).ad_ch_max/2);',...
                                    'set(h(i),''XLim'',[hb_graph_h(Sel_graph).time_min hb_graph_h(Sel_graph).time_max]);',...
                                    'set(h(i),''xtick'',hb_graph_h(Sel_graph).time_min:(hb_graph_h(Sel_graph).time_max-hb_graph_h(Sel_graph).time_min)/2:hb_graph_h(Sel_graph).time_max);',...
                                    'set(h(i),''xticklabel'',lab);',...
                                    'set(h(i),''fontsize'',para_p.fsize);',...
                                    'set(hb_graph_h(Sel_graph).hb_fig,''CurrentAxes'',h(i));',...
                                    'label_put(info,hb_graph_h,para,para_p,Sel_graph,(info(Sel_graph).ad_ch_max/2)-(i-1),hb_graph_h(Sel_graph).hb_fig,h(i));',...   % label drow
                                 'end;',...
                              'end;',...
                              'set(hb_graph_h(Sel_graph).raw.t_min,''string'', round(hb_graph_h(Sel_graph).time_min*info(Sel_graph).smpl_period/1000*10)/10);',...
                              'clear ret;',...
                           'else;',...
                              'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                              'set(hb_graph_h(Sel_graph).raw.t_min,''string'', hb_graph_h(Sel_graph).time_min*info(Sel_graph).smpl_period/1000);',...
                           'end;',...
                           'clear h;clear i;clear TimeMax; clear TimeMin; clear TimeStep; clear lab; clear TmpData;'],...% Ver 2.00 <-
               'Tag','EditText3');

      %************ Graph Feeld Renge max sec ***********
      hb_graph_h(Sel_graph).raw.t_max = uicontrol('Parent',hb_graph_h(Sel_graph).hb_fig,...
               'Units','points',...
               'BackgroundColor',[1 1 1],...
               'Position',[raw_posi(3)/2+raw_posi(3)/4 1 40 14],...
               'Style','edit',...
               'String',hb_graph_h(Sel_graph).time_max*info(Sel_graph).smpl_period/1000,...
               'Callback',['Sel_graph=get(gca,''Parent'')-(7-1);',...
                           'h=findobj(hb_graph_h(Sel_graph).hb_fig,''type'',''axes'');',...
                           'TmpData=str2num(get(hb_graph_h(Sel_graph).raw.t_max,''string''));',...% Ver 2.00 ->
                           'if length(TmpData) ~= 0;',...
                              'if hb_data(Sel_graph).ana_mode == 2;',...    % integral
                                 'if info(Sel_graph).measure_mode(1)==1;',...
                                    'max_t = mark.point(1,3)-mark.point(1,2)+para.pre+para.post+para.relax;',...
                                 'elseif info(Sel_graph).measure_mode(1)==2;',...
                                    'max_t = 1+para.pre+para.post+para.relax;',...
                                 'end;',...
                              'else;',...
                                 'max_t=info(Sel_graph).datanum;',...
                              'end;',...
                              'ret=strchknum(get(gcbo,''string''));',...
                              'TmpData = round(TmpData*10)/10;',...
                              'TmpData=round(TmpData/(info(Sel_graph).smpl_period/1000)*10)/10;',...
                              'if ret > 0;',...
                                 'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                              'elseif TmpData <= hb_graph_h(Sel_graph).time_min | TmpData > max_t;',...
                                 'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                              'else;',...
                                 'hb_graph_h(Sel_graph).time_max=TmpData;',...
                                 'TimeMin = round(hb_graph_h(Sel_graph).time_min*(info(Sel_graph).smpl_period/1000)*10)/10;',...
                                 'TimeMax = round(hb_graph_h(Sel_graph).time_max*(info(Sel_graph).smpl_period/1000)*10)/10;',...
                                 'TimeStep = round((((hb_graph_h(Sel_graph).time_max-hb_graph_h(Sel_graph).time_min)*(info(Sel_graph).smpl_period/1000))/2)*10)/10;',...
                                 'lab(1)=TimeMin; lab(2)=TimeMin+TimeStep; lab(3)=TimeMax;',...
                                 'for i=1:(info(Sel_graph).ad_ch_max/2);',...
                                    'set(h(i),''XLim'',[hb_graph_h(Sel_graph).time_min hb_graph_h(Sel_graph).time_max]);',...
                                    'set(h(i),''xtick'',hb_graph_h(Sel_graph).time_min:(hb_graph_h(Sel_graph).time_max-hb_graph_h(Sel_graph).time_min)/2:hb_graph_h(Sel_graph).time_max);',...
                                    'set(h(i),''xticklabel'',lab);',...
                                    'set(h(i),''fontsize'',para_p.fsize);',...
                                    'set(hb_graph_h(Sel_graph).hb_fig,''CurrentAxes'',h(i));',...
                                    'label_put(info,hb_graph_h,para,para_p,Sel_graph,(info(Sel_graph).ad_ch_max/2)-(i-1),hb_graph_h(Sel_graph).hb_fig,h(i));',...   % label drow
                                 'end;',...
                              'end;',...
                              'set(hb_graph_h(Sel_graph).raw.t_max,''string'', round(hb_graph_h(Sel_graph).time_max*(info(Sel_graph).smpl_period/1000)*10)/10);',...
                              'clear ret;',...
                           'else;',...
                              'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                              'set(hb_graph_h(Sel_graph).raw.t_max,''string'', hb_graph_h(Sel_graph).time_max*info(Sel_graph).smpl_period/1000);',...
                           'end;',...
                           'clear h;clear i;clear TimeMax; clear TimeMin; clear TimeStep; clear lab; clear TmpData; clear max_t;'],...% Ver 2.00 <-
               'Tag','EditText4');
           
      hb_graph_h(Sel_graph).raw.t_unit = uicontrol('Parent',hb_graph_h(Sel_graph).hb_fig,...
               'Units','points',...
               'Position',[raw_posi(3)/2-40 15 40 10],...
               'BackgroundColor',[0.8 0.8 0.8],...
               'Style','text',...
               'String','sec',...
               'Tag','tag2');
      hb_graph_h(Sel_graph).raw.time = uicontrol('Parent',hb_graph_h(Sel_graph).hb_fig,...
                          'Units','points',...
                          'Position',[raw_posi(3)/2 15 40 10],...
                          'BackgroundColor',[0.8 0.8 0.8],...
                          'Style','text',...
                          'String',para.sel_point*info(Sel_graph).smpl_period/1000,...% Ver 2.00 -><-
                          'Tag','tag2');                 
      %************ Slider ***********
      hb_graph_h(Sel_graph).raw.sl1 = uicontrol('Parent',hb_graph_h(Sel_graph).hb_fig,...
                           'Units','points',...
                           'Position',[raw_posi(3)/4+15 2 raw_posi(3)/2-45 12],...
                           'Style','slider',...
                           'Min',hb_graph_h(Sel_graph).time_min,...
                           'Max',hb_graph_h(Sel_graph).time_max,...
                           'Interruptible','off',...
                           'Sliderstep',[1/((hb_graph_h(Sel_graph).time_max-hb_graph_h(Sel_graph).time_min)) 10/((hb_graph_h(Sel_graph).time_max-hb_graph_h(Sel_graph).time_min))],...
                           'Value',floor((hb_graph_h(Sel_graph).time_max-hb_graph_h(Sel_graph).time_min))/2,...
                           'Tag','sl_bar',...
                           'Callback',['if move_stop == 1;',...
                                          'Sel_graph=get(gca,''Parent'')-(7-1);',...
                                          '[hb_graph_h]=graph_posi(info,hb_graph_h,Sel_graph, para_p);',...
                                          'para.sel_point=floor(get(hb_graph_h(Sel_graph).raw.sl1,''Value''));',...
                                          'if para.sel_point < 1;para.sel_point = 1;end;',...				  
                                          'h = findobj(hb_graph_h(Sel_graph).hb_fig,''Color'',''m'');',...
                                          'delete(h);',...
                                          'if isfield(hb_graph_h(Sel_graph),''raw_graph'')==1;',...
                                             'set(hb_graph_h(Sel_graph).raw_graph(:,:),''Visible'',''off'');',...
                                          'end;',...
                                          'if isfield(hb_graph_h(Sel_graph),''fil_graph'')==1;',...
                                             'set(hb_graph_h(Sel_graph).fil_graph(:,:),''Visible'',''off'');',...
                                          'end;',...
                                          'if isfield(hb_graph_h(Sel_graph),''raw_graph'')==1;',...
                                             'set(hb_graph_h(Sel_graph).raw_graph(:,:),''Visible'',''off'');',...
                                          'end;',...
                                          'if isfield(hb_graph_h(Sel_graph),''fil_graph'')==1;',...
                                              'set(hb_graph_h(Sel_graph).fil_graph(:,:),''Visible'',''off'');',...
                                          'end;',...
                                          'for i=1:(info(Sel_graph).ad_ch_max/2);',...
                                              'mark_line(info,para,para_p,mark,hb_data,hb_graph_h,0,0,Sel_graph,i,1);',...  % Mark line
                                              '[hb_graph_h] = drow_graph(info,para,para_p,mark,hb_data,hb_graph_h,Sel_graph,i);',...  % drow graph
                                              'label_put(info,hb_graph_h,para,para_p,Sel_graph,i,hb_graph_h(Sel_graph).hb_fig,hb_graph_h(Sel_graph).map_gco(i));',...   % label drow
                                          'end;',...
                                          'set(hb_graph_h(Sel_graph).raw.time,''String'',para.sel_point*info(Sel_graph).smpl_period/1000);',...  
                                          'if para.sel_topo==1 & info(Sel_graph).probe_mode==1;[hb_map_h] = hb_map33(para,info,para_p,hb_data,hb_graph_h,hb_map_h,Sel_graph,move_stop);end;',...
                                          'if para.sel_topo==1 & info(Sel_graph).probe_mode==2;[hb_map_h] = hb_map44(para,info,para_p,hb_data,hb_graph_h,hb_map_h,Sel_graph,move_stop);end;',...
                                          'if para.sel_topo==1 & info(Sel_graph).probe_mode==3;[hb_map_h] = hb_map35(para,info,para_p,hb_data,hb_graph_h,hb_map_h,Sel_graph,move_stop);end;',...
                                          'if para.sel_topo==1 & info(Sel_graph).probe_mode==4;[hb_map_h] = hb_map311(para,info,para_p,hb_data,hb_graph_h,hb_map_h,Sel_graph,move_stop);end;',...
                                          'if para.sel_topo==1 & info(Sel_graph).probe_mode==5;[hb_map_h] = hb_map310(para,info,para_p,hb_data,hb_graph_h,hb_map_h,Sel_graph,move_stop);end;',...
                                          'h = findobj(''type'',''figure'');',...
                                          'for i=1:length(h);',...
                                              'if h(i) == 80;',...
                                                 '[hb_map_h] = map_3d(para,info,para_p,hb_data,hb_graph_h,hb_map_h,Sel_graph,move_stop,pos,1);',...
                                              'end;',...
                                          'end;',...
                                          'clear h;clear i;',...
                                       'else;',...
                                          'warndlg(''Please push a stop button.'',''Warning !!'');',...
                                       'end;',...
                                       ]);

      % A/D Fitting Ch
      hb_graph_h(Sel_graph).raw.unit_ch= uicontrol('Parent',hb_graph_h(Sel_graph).hb_fig,...
               'Units','points',...
               'Position',[raw_posi(3)-45 45 15 10],...
               'BackgroundColor',[0.8 0.8 0.8],...
               'Style','text',...
               'String','CH',...
               'Tag','tag2');     
   
      hb_graph_h(Sel_graph).raw.ch = uicontrol('Parent',hb_graph_h(Sel_graph).hb_fig,...
               'Units','points',...
               'BackgroundColor',[1 1 1],...
               'Position',[raw_posi(3)-25 45 25 14],...
               'Style','edit',...
               'String',info(Sel_graph).sel_ch,...
               'Callback',['Sel_graph=get(gca,''Parent'')-(7-1);',...
                           'val=str2num(get(gcbo,''string''));',...
                           'if length(val) ~= 0;',...
                              'ret=strchknum(get(gcbo,''string''));',...
                              'if ret > 0;',...
                                 'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                                 'set(gcbo,''string'', info(Sel_graph).sel_ch);',...
                              'elseif val <= 0 | val > info(Sel_graph).ad_ch_max/2;',...
                                 'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                                 'set(gcbo,''string'', info(Sel_graph).sel_ch);',...
                              'else;',...
                                 'info(Sel_graph).sel_ch=val;',...
                              'end;',...
                              'clear ret;',...
                           'else;',...
                              'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                              'set(gcbo,''string'', info(Sel_graph).sel_ch);',...
                           'end;',...
                           'clear val;'],...
               'Tag','EditText5');   

      % Spectgram Button
      hb_graph_h(Sel_graph).raw.spct = uicontrol('Parent',hb_graph_h(Sel_graph).hb_fig,...
               'Units','points',...
               'BackgroundColor',[0.75 0.75 0.75], ...
               'Position',[raw_posi(3)-45 0 46 14],...
               'String','Spectgram',...
               'Callback',['if move_stop == 1;',...
                              'Sel_graph=get(gca,''Parent'')-(7-1);',...
                              'hb_graph_h(Sel_graph).spect_chk_val = 1;',...
                              '[hb_graph_h] = hb_spect(info,para,para_p,mark,hb_data,hb_graph_h,Sel_graph);',...
                           'else;',...
                              'warndlg(''Please push a stop button.'',''Warning !!'');',...
                           'end;',...
                          ],... 
               'Tag','Pushbutton1');
           
      hb_graph_h(Sel_graph).raw.fft = uicontrol('Parent',hb_graph_h(Sel_graph).hb_fig,...
               'Units','points',...
               'BackgroundColor',[0.75 0.75 0.75], ...
               'Position',[raw_posi(3)-45 15 46 14],...
               'String','FFT',...
               'Callback',['if move_stop == 1;',...
                              'Sel_graph=get(gca,''Parent'')-(7-1);',...
                              '[fft_data,fft_graph_h]=hb_fft_graph(info,mark,para,para_p,hb_data,hb_graph_h,Sel_graph);',...
                           'else;',...
                              'warndlg(''Please push a stop button.'',''Warning !!'');',...
                           'end;',...
                          ],... 
               'Tag','Pushbutton1');
            
      hb_graph_h(Sel_graph).raw.adf= uicontrol('Parent',hb_graph_h(Sel_graph).hb_fig,...
               'Units','points',...
               'BackgroundColor',[0.75 0.75 0.75], ...
               'Position',[raw_posi(3)-45 30 46 14],...
               'String','A/D Fitting',...
               'Callback',['if move_stop == 1;',...
                              'Sel_graph=get(gca,''Parent'')-(7-1);',...
                              'if hb_data(Sel_graph).ana_mode==2;ad_fit_graph(info,ad_data,mark,para,para_p,Sel_graph);end;',...
                              'if hb_data(Sel_graph).ana_mode==1;',...
                                  'warndlg(''Please Select Integral Mode!'',''Warning'');',...
                              'end;',...
                           'else;',...
                              'warndlg(''Please push a stop button.'',''Warning !!'');',...
                           'end;',...
                          ],...
               'Tag','Pushbutton2');

      %****** Range & Point plotting using mouse ************
      mouse = ['if move_stop == 1;',...
                  'Sel_graph=get(gca,''Parent'')-(7-1);',...
                  'if para.high_flg == 1 | para.low_flg == 1 | para.moveave_flg == 1;',...
                     'if hb_data(Sel_graph).calc_flg~=2;',...
                        'warndlg(''Please set and re-calculate a filter.'',''Warning'');',...
                        'return;',...
                     'end;',...
                     'if isfield(hb_data(Sel_graph),''fil'' ) ~= 1;',...
                        'warndlg(''Please set and re-calculate a filter.'',''Warning'');',...
                        'return;',...
                     'end;',...
                  'end;',...
                  'if strcmp(get(hb_graph_h(Sel_graph).hb_fig,''SelectionType''),''normal'');',...
                     '[hb_graph_h]=graph_posi(info,hb_graph_h,Sel_graph,para_p);',...
                     'pt=get(gca,''currentpoint'');',...
                     'MousePointData = floor(pt(1,1));',...                 % Ver 2.00 -><-A mouse click position is judged and, in besides graph, it does not update.
                     'if MousePointData > hb_graph_h(Sel_graph).time_min & MousePointData<= hb_graph_h(Sel_graph).time_max;',...	
                        'para.sel_point = MousePointData;',...
                        'set(hb_graph_h(Sel_graph).raw.sl1,''Value'',para.sel_point);',...
                        'h = findobj(hb_graph_h(Sel_graph).hb_fig,''Color'',''m'');',...
                        'delete(h);',...
                        'if isfield(hb_graph_h(Sel_graph),''raw_graph'')==1;',...
                           'set(hb_graph_h(Sel_graph).raw_graph(:,:),''Visible'',''off'');',...
                        'end;',...
                        'if isfield(hb_graph_h(Sel_graph),''fil_graph'')==1;',...
                           'set(hb_graph_h(Sel_graph).fil_graph(:,:),''Visible'',''off'');',...
                        'end;',...
                        'for i=1:(info(Sel_graph).ad_ch_max/2);',...
                           'mark_line(info,para,para_p,mark,hb_data,hb_graph_h,0,0,Sel_graph,i,1);',...  % Mark line
                           '[hb_graph_h] = drow_graph(info,para,para_p,mark,hb_data,hb_graph_h,Sel_graph,i);',...  % graph drow
                           'label_put(info,hb_graph_h,para,para_p,Sel_graph,i,hb_graph_h(Sel_graph).hb_fig,hb_graph_h(Sel_graph).map_gco(i));',...   % label drow
                        'end;',...
                        'set(hb_graph_h(Sel_graph).raw.time,''String'',para.sel_point*info(Sel_graph).smpl_period/1000);',...% Ver 2.00 -><-
                        'clear h;',...
                        'if para.sel_topo==1 & info(Sel_graph).probe_mode==1;[hb_map_h] = hb_map33(para,info,para_p,hb_data,hb_graph_h,hb_map_h,Sel_graph,move_stop);end;',...   
                        'if para.sel_topo==1 & info(Sel_graph).probe_mode==2;[hb_map_h] = hb_map44(para,info,para_p,hb_data,hb_graph_h,hb_map_h,Sel_graph,move_stop);end;',...
                        'if para.sel_topo==1 & info(Sel_graph).probe_mode==3;[hb_map_h] = hb_map35(para,info,para_p,hb_data,hb_graph_h,hb_map_h,Sel_graph,move_stop);end;',...
                        'if para.sel_topo==1 & info(Sel_graph).probe_mode==4;[hb_map_h] = hb_map311(para,info,para_p,hb_data,hb_graph_h,hb_map_h,Sel_graph,move_stop);end;',...
                        'if para.sel_topo==1 & info(Sel_graph).probe_mode==5;[hb_map_h] = hb_map310(para,info,para_p,hb_data,hb_graph_h,hb_map_h,Sel_graph,move_stop);end;',...
                        'h = findobj(''type'',''figure'');',...
                        'for i=1:length(h);',...
                            'if h(i) == 80;',...
                               '[hb_map_h] = map_3d(para,info,para_p,hb_data,hb_graph_h,hb_map_h,Sel_graph,move_stop,pos,1);',...
                            'end;',...
                        'end;',...
                     'end;',...
                     'clear i;clear pt;clear h;clear MousePointData;',...
                  'end;',...
               'else;',...
                  'warndlg(''Please push a stop button.'',''Warning !!'');',...
               'end;'];

            set(gcf,'WindowButtonDownFcn',mouse,'BusyAction','queue','Interruptible','off');

      %************** zoom **************
      hb_graph_h(Sel_graph).raw.zoom = uicontrol('Parent',hb_graph_h(Sel_graph).hb_fig,...
          'Units','points',...
          'BackgroundColor',[0.75 0.75 0.75], ...
          'Position',[raw_posi(3)-35 59 35 14],...
          'String','Zoom',...
          'Callback',['if move_stop == 1;',...
                        'figure;',... 
                        'ch = str2num(get(hb_graph_h(Sel_graph).raw.ch, ''String''));',...
                        'try;',...
                        'plot(hb_data(Sel_graph).fil(1,:, ch), ''r''); hold on;', ...
                        'plot(hb_data(Sel_graph).fil(2,:, ch), ''b''); hold on;', ...
                        'plot(hb_data(Sel_graph).fil(3,:, ch), ''g''); hold on;', ...                        
                        'catch;',...
                        'plot(hb_data(Sel_graph).raw(1,:, ch), ''r''); hold on;', ...
                        'plot(hb_data(Sel_graph).raw(2,:, ch), ''b''); hold on;', ...
                        'plot(hb_data(Sel_graph).raw(3,:, ch), ''g''); hold on;', ...                        
                        'end;',...
                        'a = gca; h = hb_graph_h; h(Sel_graph).map_gco(ch) = a; mark_line(info,para,para_p,mark,hb_data,h,0,0,Sel_graph,ch,1); ', ...                                                
                      'else;',...
                        'warndlg(''Please push a stop button.'',''Warning !!'');',...
                      'end;',...
          ],...
          'Tag','Pushbutton1');
      
      %************** file out **************
      hb_graph_h(Sel_graph).raw.fout = uicontrol('Parent',hb_graph_h(Sel_graph).hb_fig,...
          'Units','points',...
          'BackgroundColor',[0.75 0.75 0.75], ...
          'Position',[raw_posi(3)-35 75 35 14],...
          'String','FileOut',...
          'Callback',['if move_stop == 1;',...
                        'Sel_graph=get(gca,''Parent'')-(7-1);',...
                        'fout_raw(info,para,para_p,hb_data,mark,ad_data,Sel_graph);',...
                      'else;',...
                        'warndlg(''Please push a stop button.'',''Warning !!'');',...
                      'end;',...
          ],...
          'Tag','Pushbutton1');
      
      %************** refresh **************
      hb_graph_h(Sel_graph).raw.ad_ref = uicontrol('Parent',hb_graph_h(Sel_graph).hb_fig, ...
               'Units','points', ...
               'BackgroundColor',[1.0 0.9 0.1], ...
               'Position',[1 0 35 14], ...
               'String','Refresh',...
               'Callback',['Sel_graph=get(gca,''Parent'')-(7-1);'...
                           'raw_posi=get(hb_graph_h(Sel_graph).hb_fig,''Position'');',...
                           'set(hb_graph_h(Sel_graph).raw.y_min,''Position'',[1 raw_posi(4)/2-raw_posi(4)/4 40 14]);',...
                           'set(hb_graph_h(Sel_graph).raw.y_max,''Position'',[1 raw_posi(4)/2+raw_posi(4)/4 40 14]);',...
                           'set(hb_graph_h(Sel_graph).raw.y_unit,''Position'',[2 raw_posi(4)/2+raw_posi(4)/4+14 30 10]);',...
                           'set(hb_graph_h(Sel_graph).raw.t_min,''Position'',[raw_posi(3)/2-raw_posi(3)/4-40 1 40 14]);',...
                           'set(hb_graph_h(Sel_graph).raw.t_max,''Position'',[raw_posi(3)/2+raw_posi(3)/4 1 40 14]);',...
                           'set(hb_graph_h(Sel_graph).raw.t_unit,''Position'',[raw_posi(3)/2-40 15 40 10]);',...
                           'set(hb_graph_h(Sel_graph).raw.time,''Position'',[raw_posi(3)/2 15 40 10]);',...
                           'set(hb_graph_h(Sel_graph).raw.sl1,''Position'',[raw_posi(3)/4+15 2 raw_posi(3)/2-45 12]);',...
                           'set(hb_graph_h(Sel_graph).raw.unit_ch,''Position'',[raw_posi(3)-45 45 15 10]);',...
                           'set(hb_graph_h(Sel_graph).raw.ch,''Position'',[raw_posi(3)-25 45 25 14]);',...
                           'set(hb_graph_h(Sel_graph).raw.fft,''Position'',[raw_posi(3)-45 15 46 14]);',...
                           'set(hb_graph_h(Sel_graph).raw.adf,''Position'',[raw_posi(3)-45 30 46 14]);',...
                           'set(hb_graph_h(Sel_graph).raw.spct,''Position'',[raw_posi(3)-45 0 46 14]);',...
                           'set(hb_graph_h(Sel_graph).raw.fout,''Position'',[raw_posi(3)-35 59 35 14]);',...
                           'clear raw_posi;',...
                          ],...
                          'tag','Pushbutton3');
                       
      %para
      for i=1:(info(p_cnt).ad_ch_max/2);
         set(0,'CurrentFigure',hb_graph_h(p_cnt).hb_fig);
         hb_graph_h(p_cnt).map_gco(i) = axes('Position',hb_graph_h(p_cnt).graph_posi(i).p);
         box on;
         title(['CH',int2str(i)],'Fontsize',para_p.fsize);

         if info(p_cnt).err_ch(i)==1 & para_p.del_ch ==1;set(findobj(gca,'type','axes'),'color',[0.8 0.8 0.8]);end;
         % Ver 2.00 <-
         % It tags a graph, and it is put.
          set(hb_graph_h(p_cnt).map_gco(i),'Tag','axes');
       	 hold on;
          plot([0 hb_graph_h(p_cnt).time_max-1],[0 0],':','Color',[0.1 0.1 0.1]);
          mark_line(info,para,para_p,mark,hb_data,hb_graph_h,0,0,p_cnt,i,1);  % Mark line
%           if isfield(hb_graph_h(p_cnt),'raw_graph')==1;
%              set(hb_graph_h(p_cnt).raw_graph(:,i),'Visible','off');
%           end;
          [hb_graph_h] = drow_graph(info,para,para_p,mark,hb_data,hb_graph_h,p_cnt,i);  % graph drow
          % label drow
          label_put(info,hb_graph_h,para,para_p,p_cnt,i,hb_graph_h(p_cnt).hb_fig,hb_graph_h(p_cnt).map_gco(i));
          hold off;
       end;
   end;
end;
clear raw_posi;
