% kl_int
%
% Input  : info,Sel_graph
% Output : none
% Example: kl_int(info,Sel_graph)

%*********************************************************
%*             PCA Data Integral Function                *
%*                   Shingo Kawasaki                     *
%*                  HITACHI MECICAL                      *
%*********************************************************
% history : 06.06.28 Ver 2.05 Kusabuka    mark check bugu

function [kl_graph_h,hb_data] = kl_int(info,Sel_graph,mark,para,kl_graph_h,hb_data,para_p);

clear hb_data2;
kl_graph_h(Sel_graph).int.oxy_val =1;
kl_graph_h(Sel_graph).int.deoxy_val =1;
kl_graph_h(Sel_graph).int.total_val =1;
%*********** Find Add Mark ***********
if para.sel_move == 0;
   add_mark  = find(mark.ave==1);
else;
   add_mark  = find(mark.ave==1 & mark.move==0);
end;
if isempty(add_mark)==1;
   warndlg('Please Select Mark!','Warning');
   return;
end;

ret = inttmchk(info,para,mark,hb_data,Sel_graph,para.pre,para.post,para.relax);
if ret == 3;
   warndlg('Please Select Mark!','Warning');
   err_flg=1;
   return;
elseif ret == 1;
   warndlg('Input analyze time is too long !','Warning');
   err_flg=1;
   return;
elseif ret == 2;
   warndlg('Mark over laps !','Warning');
   err_flg=1;
   return;
end;

if info(Sel_graph).measure_mode == 1;       % Stim 
   block = mark.point(add_mark(1),3)-mark.point(add_mark(1),2)+para.pre+para.post+para.relax;
else;                                       % Event
   block = para.pre+para.post+para.relax;
end;
last_mark = add_mark(length(add_mark));

TimeMin = round(1*(info(Sel_graph).smpl_period/1000)*10)/10;
TimeMax = round(block*info(Sel_graph).smpl_period/1000*10)/10;
TimeStep = round((TimeMax-TimeMin)/2*10)/10;
lab(1)=TimeMin;
lab(2)=TimeMin+TimeStep;
lab(3)=TimeMax;
for hb=1:3;
   for j = 1:last_mark;
      if info(Sel_graph).probe_mode == 3;            % 3X5
        hb_data2.seg(hb,:,:,j) = squeeze(hb_data(Sel_graph).const(hb,[mark.point(j,2)-para.pre:mark.point(j,2)+block-para.pre-1],[1:22]));
      elseif info(Sel_graph).probe_mode == 4;        % 3X11
        hb_data2.seg(hb,:,:,j) = squeeze(hb_data(Sel_graph).const(hb,[mark.point(j,2)-para.pre:mark.point(j,2)+block-para.pre-1],[1:52]));
      elseif info(Sel_graph).probe_mode == 5;        % 3X10
        hb_data2.seg(hb,:,:,j) = squeeze(hb_data(Sel_graph).const(hb,[mark.point(j,2)-para.pre:mark.point(j,2)+block-para.pre-1],[1:47]));
      else;                                         % 3X3,4x4
        hb_data2.seg(hb,:,:,j) = squeeze(hb_data(Sel_graph).const(hb,[mark.point(j,2)-para.pre:mark.point(j,2)+block-para.pre-1],[1:24]));
      end;     
   end;
   
   %*********** Initialization ***********
   hb_data2.ana_mode = 2;
   hb_data2.calc_flg = 1;
   
   %******** Calc polyfit using Pre and Post ************
   block_time = [1:block]';
   for ad_ch = 1:info(Sel_graph).ad_ch_max/2;     % ch
      for sg = 1:last_mark;
         mark_fit(1:para.pre)                          = hb_data2.seg(hb,1:para.pre,ad_ch,sg);
         mark_fit(para.pre+1:para.pre+para.post)       = hb_data2.seg(hb,block-para.post+1:block,ad_ch,sg);
         mark_fit_block(1:para.pre)                    = 1:para.pre;
         mark_fit_block(para.pre+1:para.pre+para.post) = block-para.post+1:block;
         hb_data2.fit(hb,:,ad_ch,sg)                   = polyval(polyfit(mark_fit_block,mark_fit,para.fit_val),block_time);
      end;
   end;
   
   %********** Calc Integral Hb Data **********
   for sg = 1:last_mark;
      for ch=1:info(Sel_graph).ad_ch_max/2;
         hb_data2.seg2(hb,:,ch,sg)=hb_data2.seg(hb,:,ch,sg)-hb_data2.fit(hb,:,ch,sg);
      end;
   end;
end;

%***************** Calc Average *******************
hb_data2.raw(1,:,:) = (sum(hb_data2.seg2(1,:,:,add_mark),4)/length(add_mark));
hb_data2.raw(2,:,:) = (sum(hb_data2.seg2(2,:,:,add_mark),4)/length(add_mark));
hb_data2.raw(3,:,:) = (sum(hb_data2.seg2(3,:,:,add_mark),4)/length(add_mark));


%********* Initial value (hb_graph) *********

hbing_fig=figure(68+(Sel_graph-1));
set(hbing_fig,'Units','points');
clf;
figure_title = sprintf('Recontruct integral from Continuous Probe %d',Sel_graph);
set(hbing_fig,'Name',figure_title,'ToolBar','none');    
plotedit(hbing_fig,'hidetoolsmenu');
int_posi = get(hbing_fig,'Position'); 

min_v=min(min(min(hb_data2.raw(:,:,:))));
if min_v > 0;
    min_v = min_v+min_v*(-1.2);
elseif min_v < 0;
    min_v = min_v*1.2;
else;
    min_v = -0.2;
end;
max_v=max(max(max(hb_data2.raw(:,:,:))));
if max_v > 0;
    max_v = max_v*1.2;
elseif max_v < 0;
    max_v = max_v+max_v*(-1.2);
else;
    max_v = 0.2;
end;
for ch=1:info(Sel_graph).ad_ch_max/2;
%   	axes(hb_graph_h(Sel_graph).hb_y,hb_graph_h(Sel_graph).hb_x,hb_graph_h(Sel_graph).graph_posi(ch));
   	gco=axes('Position',kl_graph_h(Sel_graph).graph_posi(ch).p);
      if info(Sel_graph).err_ch(ch)==1 & para_p.del_ch ==1;set(gco,'color',[0.8 0.8 0.8]);end;
    box on;
    hold on;
    title(['CH',int2str(ch)],'Fontsize',para_p.fsize);

    kl_graph_h(Sel_graph).int.graph(1,ch) = plot(hb_data2.raw(1,:,ch),'r');
    kl_graph_h(Sel_graph).int.graph(2,ch) = plot(hb_data2.raw(2,:,ch),'b');
    kl_graph_h(Sel_graph).int.graph(3,ch) = plot(hb_data2.raw(3,:,ch),'g');

    plot([para.pre para.pre],[-10 10],':k');
    plot([block-para.relax-para.post block-para.relax-para.post],[-10 10],':k');
    plot([1 block],[0 0],':k');
    axis([1 length(hb_data2.raw(1,:,1)) min_v max_v]);
    set(gco,'YLim',[min_v max_v]);
    set(gco,'XLim',[1 length(hb_data2.raw(1,:,1))]);
    set(gco,'xtick',1:(length(hb_data2.raw(1,:,1))-1)/2:length(hb_data2.raw(1,:,1)));
    set(gca,'fontsize',para_p.fsize)
    set(gca,'xticklabel',lab);
    % label drow
    label_put(info,kl_graph_h,para,para_p,Sel_graph,ch,hbing_fig,gco);
end;
if kl_graph_h(Sel_graph).int.oxy_val == 1;
   set(kl_graph_h(Sel_graph).int.graph(1,:),'Visible','on');
end;
if kl_graph_h(Sel_graph).int.deoxy_val == 1;
   set(kl_graph_h(Sel_graph).int.graph(2,:),'Visible','on');
end;
if kl_graph_h(Sel_graph).int.total_val == 1;
   set(kl_graph_h(Sel_graph).int.graph(3,:),'Visible','on');
end;
%************ Button **************
%************** check **************
kl_graph_h(Sel_graph).int.oxy_chk = uicontrol('Parent',hbing_fig, ...
                     'Units','points', ...
                     'Position',[1 48 40 15], ...
                     'BackgroundColor',[0.8 0.8 0.8], ...
                     'Style','checkbox', ...
                     'String','Oxy',...
                     'Value',kl_graph_h(Sel_graph).int.oxy_val,...
                     'Callback',['Sel_graph=get(gca,''Parent'')-(68-1);',...
                                 'kl_graph_h(Sel_graph).int.oxy_val = get(gcbo,''value'');',...
                                 'if move_stop == 1;',...
                                    'if kl_graph_h(Sel_graph).int.oxy_val == 1;',... 
                                          'set(kl_graph_h(Sel_graph).int.graph(1,:),''Visible'',''on'');',...
                                    'else;',... 
                                          'set(kl_graph_h(Sel_graph).int.graph(1,:),''Visible'',''off'');',...
                                    'end;',...
                                 'else;',...
                                    'if kl_graph_h(Sel_graph).int.oxy_val == 1;',...
                                       'set(kl_graph_h(Sel_graph).int.oxy_chk,''Value'',0);',...
                                       'kl_graph_h(Sel_graph).int.oxy_val  = 0;',...
                                    'else;',...
                                       'set(kl_graph_h(Sel_graph).int.oxy_chk,''Value'',1);',...
                                       'kl_graph_h(Sel_graph).int.oxy_val  = 1;',...
                                    'end;',...
                                    'warndlg(''Please push a stop button.'',''Warning !!'');',...
                                 'end;',...
                               ]);
kl_graph_h(Sel_graph).int.deoxy_chk = uicontrol('Parent',hbing_fig, ...
                     'Units','points', ...
                     'Position',[1 33 40 15], ...
                     'BackgroundColor',[0.8 0.8 0.8], ...
                     'Style','checkbox', ...
                     'String','Deoxy',...
                     'Value',kl_graph_h(Sel_graph).int.deoxy_val,...
                     'Callback',['Sel_graph=get(gca,''Parent'')-(68-1);',...
                                 'kl_graph_h(Sel_graph).int.deoxy_val = get(gcbo,''value'');',...
                                 'if move_stop == 1;',...
                                    'if kl_graph_h(Sel_graph).int.deoxy_val == 1;',... 
                                          'set(kl_graph_h(Sel_graph).int.graph(2,:),''Visible'',''on'');',...
                                    'else;',... 
                                          'set(kl_graph_h(Sel_graph).int.graph(2,:),''Visible'',''off'');',...
                                    'end;',...
                                 'else;',...
                                    'if kl_graph_h(Sel_graph).int.deoxy_val == 1;',...
                                       'set(kl_graph_h(Sel_graph).int.deoxy_chk,''Value'',0);',...
                                       'kl_graph_h(Sel_graph).int.deoxy_val  = 0;',...
                                    'else;',...
                                       'set(kl_graph_h(Sel_graph).int.deoxy_chk,''Value'',1);',...
                                       'kl_graph_h(Sel_graph).int.deoxy_val  = 1;',...
                                    'end;',...
                                    'warndlg(''Please push a stop button.'',''Warning !!'');',...
                                 'end;',...
                               ]);
kl_graph_h(Sel_graph).int.total_chk = uicontrol('Parent',hbing_fig, ...
                     'Units','points', ...
                     'Position',[1 18 40 15], ...
                     'BackgroundColor',[0.8 0.8 0.8], ...
                     'Style','checkbox', ...
                     'String','Total',...
                     'Value',kl_graph_h(Sel_graph).int.total_val,...
                     'Callback',['Sel_graph=get(gca,''Parent'')-(68-1);',...
                                 'kl_graph_h(Sel_graph).int.total_val = get(gcbo,''value'');',...
                                 'if move_stop == 1;',...
                                    'if kl_graph_h(Sel_graph).int.total_val == 1;',... 
                                          'set(kl_graph_h(Sel_graph).int.graph(3,:),''Visible'',''on'');',...
                                    'else;',... 
                                          'set(kl_graph_h(Sel_graph).int.graph(3,:),''Visible'',''off'');',...
                                    'end;',...
                                 'else;',...
                                    'if kl_graph_h(Sel_graph).int.total_val == 1;',...
                                       'set(kl_graph_h(Sel_graph).int.total_chk,''Value'',0);',...
                                       'kl_graph_h(Sel_graph).int.total_val  = 0;',...
                                    'else;',...
                                       'set(kl_graph_h(Sel_graph).int.total_chk,''Value'',1);',...
                                       'kl_graph_h(Sel_graph).int.total_val  = 1;',...
                                    'end;',...
                                    'warndlg(''Please push a stop button.'',''Warning !!'');',...
                                 'end;',...
                               ]);

      %************** file out **************
      kl_graph_h(Sel_graph).int.fout = uicontrol('Parent',hbing_fig,...
          'Units','points',...
          'BackgroundColor',[0.75 0.75 0.75], ...
          'Position',[int_posi(3)-35 16 35 14],...
          'String','FileOut',...
          'Callback',['if move_stop == 1;',...
                        'Sel_graph=get(gca,''Parent'')-(68-1);',...
                        'fout_klint(info,para,para_p,hb_data,mark,ad_data,Sel_graph);',...
                      'else;',...
                        'warndlg(''Please push a stop button.'',''Warning !!'');',...
                      'end;',...
          ],...
          'Tag','Pushbutton1');

   %************** refresh **************
   kl_graph_h(Sel_graph).int.ref = uicontrol('Parent',hbing_fig, ...
               'Units','points', ...
               'BackgroundColor',[1.0 0.9 0.1], ...
               'Position',[1 0 35 14], ...
               'String','Refresh',...
               'Callback',['int_posi=get(gcf,''Position'');',...
                           'Sel_graph=get(gca,''Parent'')-(68-1);'...
                           'set(kl_graph_h(Sel_graph).int.fout,''Position'',[int_posi(3)-35 16 35 14]);',...
                           'clear int_posi;',...
                          ],...
                          'tag','Pushbutton3');
          
hb_data(Sel_graph).klint = hb_data2.raw;
                               
 clear figure_title;
 clear block;
 clear add_mark;
 clear last_mark;
 clear sg;
 clear ch;
 clear j;
 clear ad_ch;
 clear hb;
 clear max_v;
 clear min_v;
 
