% kl_map_w
%
% Input  : sParaKL,kl_data,p_cnt,hb,iis,info
% Output : none
% Example: kl_map_w(sParaKL,kl_data,p_cnt,hb,iis,info);

%*******************************************************
%*                   KL Map Weight                     *
%*                  Shingo Kawasaki                    *
%*                  HITACHI MEDICAL                    *
%*******************************************************
% HistoryF02.11.11 Ver1.01  futahashi KL conversion function is added
% HistoryF02.11.27 Ver1.01  Kawasaki  4*4 Mode Add
% HistoryF03.11.06 Ver2.01  Kusabuka@multi probe

function [kl_map_h] = kl_map_w(sParaKL,kl_data,p_cnt,hb,info,para_p,kl_map_h);

%% kl_map_w
[map] = kl_posi(info,para_p,p_cnt);

% A setup of a figure and a title
figure_no    = 0;
figure_title = '';

% Selection of a figure No and a title
figure_no = 33+(p_cnt-1);
figure_title = sprintf('Weight Topography Probe %d',p_cnt);
kl_map_h(p_cnt).chk_val=1;

% Creation
figure_h = figure(figure_no);
clf reset;

set(figure_h,'Name',figure_title,'ToolBar','none');
plotedit(figure_h,'hidetoolsmenu');
posi = get(figure_h,'Position');
clear figure_no;
clear figure_title;

%************** check **************
kl_map_h(p_cnt).pca.chk = uicontrol('Parent',(p_cnt+33-1), ...
    'Units','points', ...
    'Position',[1 15 40 15], ...
    'BackgroundColor',[1 1 1], ...
    'Style','popupmenu', ...
    'String','Oxy  |Deoxy|Total',...
    'Value',kl_map_h(p_cnt).chk_val,...
    'Callback',['if move_stop == 1;',...
    'Sel_graph=get(gca,''Parent'')-(33-1);',...
    'kl_map_h(Sel_graph).chk_val = get(kl_map_h(Sel_graph).pca.chk,''value'');',...
    'if kl_map_h(Sel_graph).chk_val == 1;',...
    'set(kl_map_h(Sel_graph).map_plot(1,:,1),''Visible'',''on'');',...  % oxy
    'set(kl_map_h(Sel_graph).map_plot(2,:,:),''Visible'',''off'');',... % deoxy
    'set(kl_map_h(Sel_graph).map_plot(3,:,:),''Visible'',''off'');',... % total
    'if info(Sel_graph).probe_mode == 1; ',... % 3x3
    'set(kl_map_h(Sel_graph).map_plot(1,:,2),''Visible'',''on'');',...
    'end;',...
    'elseif kl_map_h(Sel_graph).chk_val == 2;',...
    'set(kl_map_h(Sel_graph).map_plot(1,:,:),''Visible'',''off'');',... % oxy
    'set(kl_map_h(Sel_graph).map_plot(2,:,1),''Visible'',''on'');',...  % deoxy
    'set(kl_map_h(Sel_graph).map_plot(3,:,:),''Visible'',''off'');',... % total
    'if info(Sel_graph).probe_mode == 1; ',... % 3x3
    'set(kl_map_h(Sel_graph).map_plot(2,:,2),''Visible'',''on'');',...
    'end;',...
    'elseif kl_map_h(Sel_graph).chk_val == 3;',...
    'set(kl_map_h(Sel_graph).map_plot(1,:,:),''Visible'',''off'');',... % oxy
    'set(kl_map_h(Sel_graph).map_plot(2,:,:),''Visible'',''off'');',... % deoxy
    'set(kl_map_h(Sel_graph).map_plot(3,:,1),''Visible'',''on'');',...  % total
    'if info(Sel_graph).probe_mode == 1; ',... % 3x3
    'set(kl_map_h(Sel_graph).map_plot(2,:,2),''Visible'',''on'');',...
    'end;',...
    'end;',...
    'else;',...
    'warndlg(''Please push a stop button.'',''Warning !!'');',...
    'end;',...
    ],...
    'tag','Checkbox1');


kl_map_h(p_cnt).pca.lab = uicontrol('Parent',(p_cnt+33-1), ...
    'Units','points', ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Position',[posi(3)/1.35-posi(3)/10/1.35 15 30 10], ...
    'String','mMmm', ...
    'Style','text');
%************** refresh **************
kl_map_h(p_cnt).pca.w_ref = uicontrol('Parent',(p_cnt+33-1), ...
    'Units','points', ...
    'BackgroundColor',[1.0 0.9 0.1], ...
    'Position',[1 0 35 14], ...
    'String','Refresh',...
    'Callback',['Sel_graph=get(gca,''Parent'')-(33-1);'...
    'w_posi=get(Sel_graph+(33)-1,''Position'');',...
    'set(kl_map_h(Sel_graph).pca.lab,''Position'',[w_posi(3)/1.35-w_posi(3)/10/1.35 15 30 10]);',...
    'clear w_posi;',...
    ],...
    'tag','Pushbutton3');
%***** 3*3 Mode *****
if info(p_cnt).probe_mode == 1;
    topo_range(1)= -0.5;

    topo_range(2)= 0.5;
    [x,y]        = meshgrid(1:1:4);
    [xi,yi]      = meshgrid(1:0.1:4);
    data_pos    = length(kl_data(p_cnt).weight)+1;;

    for hb=1:3;
        for i=1:6;             % 5->6
            %***************** left plate ********************
            %******* 45 degrees rotates to the circumference of a clock *******
            %      if i<=data_pos-iis;
            ml(1,1) =(kl_data(p_cnt).weight(hb,3,data_pos-i)+kl_data(p_cnt).weight(hb,8,data_pos-i))/2;
            ml(1,2) = kl_data(p_cnt).weight(hb,3,data_pos-i);
            ml(1,3) = kl_data(p_cnt).weight(hb,1,data_pos-i);
            ml(1,4) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i))/2;
            ml(2,1) = kl_data(p_cnt).weight(hb,8,data_pos-i);
            ml(2,2) = kl_data(p_cnt).weight(hb,6,data_pos-i);
            ml(2,3) = kl_data(p_cnt).weight(hb,4,data_pos-i);
            ml(2,4) = kl_data(p_cnt).weight(hb,2,data_pos-i);
            ml(3,1) = kl_data(p_cnt).weight(hb,11,data_pos-i);
            ml(3,2) = kl_data(p_cnt).weight(hb,9,data_pos-i);
            ml(3,3) = kl_data(p_cnt).weight(hb,7,data_pos-i);
            ml(3,4) = kl_data(p_cnt).weight(hb,5,data_pos-i);
            ml(4,1) =(kl_data(p_cnt).weight(hb,11,data_pos-i)+kl_data(p_cnt).weight(hb,12,data_pos-i))/2;
            ml(4,2) = kl_data(p_cnt).weight(hb,12,data_pos-i);
            ml(4,3) = kl_data(p_cnt).weight(hb,10,data_pos-i);
            ml(4,4) =(kl_data(p_cnt).weight(hb,5,data_pos-i)+kl_data(p_cnt).weight(hb,10,data_pos-i))/2;

            pol_l = interp2(x,y,ml,xi,yi,'spline');

            for a=1:size(pol_l,1);
                for b=1:size(pol_l,2);
                    if a<11 & b<(-a+11);pol_l(a,b)=NaN;end;
                    if a<11 & b>(a+21);pol_l(a,b)=NaN;end;
                    if a>21 & b<(a-21);pol_l(a,b)=NaN;end;
                    if a>21 & b>(-a+53);pol_l(a,b)=NaN;end;
                end;
            end;
            %******* It returns and draws  *******
            set(0,'CurrentFigure',figure_h);
            %      axes(6,2,2*i-1);         % 5->6
            axes('Position',map(i).wl);
            kl_map_h(p_cnt).map_plot(hb,i,1) = pcolor(pol_l);

            hold on;
            axis square;
            axis ij;
            axis off;
            shading interp;
            caxis([topo_range(1) topo_range(2)]);
            if para_p.angle(p_cnt).angle1==1;
                view(-45,90);
            elseif para_p.angle(p_cnt).angle1==2;
                view(45,90);
            elseif para_p.angle(p_cnt).angle1==3;
                view(135,90);
            elseif para_p.angle(p_cnt).angle1==4;
                view(225,90);
            end;
            if hb == 1;
                if para_p.angle(p_cnt).angle1==1;
                    if i==1 text(17,-7,'Topo A(C1)');end;
                    if i==2 text(17,-7,'Topo A(C2)');end;
                    if i==3 text(17,-7,'Topo A(C3)');end;
                    if i==4 text(17,-7,'Topo A(C4)');end;
                    if i==5 text(17,-7,'Topo A(C5)');end;
                    if i==6 text(17,-7,'Topo A(C6)');end;
                elseif para_p.angle(p_cnt).angle1==2;
                    if i==1 text(-10,15,'Topo A(C1)');end;
                    if i==2 text(-10,15,'Topo A(C2)');end;
                    if i==3 text(-10,15,'Topo A(C3)');end;
                    if i==4 text(-10,15,'Topo A(C4)');end;
                    if i==5 text(-10,15,'Topo A(C5)');end;
                    if i==6 text(-10,15,'Topo A(C6)');end;
                elseif para_p.angle(p_cnt).angle1==3;
                    if i==1 text(15,40,'Topo A(C1)');end;
                    if i==2 text(15,40,'Topo A(C2)');end;
                    if i==3 text(15,40,'Topo A(C3)');end;
                    if i==4 text(15,40,'Topo A(C4)');end;
                    if i==5 text(15,40,'Topo A(C5)');end;
                    if i==6 text(15,40,'Topo A(C6)');end;
                elseif para_p.angle(p_cnt).angle1==4;
                    if i==1 text(40,17,'Topo A(C1)');end;
                    if i==2 text(40,17,'Topo A(C2)');end;
                    if i==3 text(40,17,'Topo A(C3)');end;
                    if i==4 text(40,17,'Topo A(C4)');end;
                    if i==5 text(40,17,'Topo A(C5)');end;
                    if i==6 text(40,17,'Topo A(C6)');end;
                end;
                plot3(16.0,-4.0,0,'ok','MarkerSize',3,'MarkerFaceColor','r');       % left up
                plot3(-4.0,16.0,0,'o','MarkerSize',1,'Color',[0.8 0.8 0.8]);        % left down
                plot3(16.0,36.0,0,'o','MarkerSize',1,'Color',[0.8 0.8 0.8]);        % right down
                plot3(36.0,16.0,0,'o','MarkerSize',1,'Color',[0.8 0.8 0.8]);        % right up
            end;
            zoom(1.5);
            hold off;
            %***************** right plate ********************
            %******* 45 degrees rotates to the circumference of a clock *******
            %         if i<=data_pos-iis;
            mr(1,1) =(kl_data(p_cnt).weight(hb,15,data_pos-i)+kl_data(p_cnt).weight(hb,20,data_pos-i))/2;
            mr(1,2) = kl_data(p_cnt).weight(hb,15,data_pos-i);
            mr(1,3) = kl_data(p_cnt).weight(hb,13,data_pos-i);
            mr(1,4) =(kl_data(p_cnt).weight(hb,13,data_pos-i)+kl_data(p_cnt).weight(hb,14,data_pos-i))/2;
            mr(2,1) = kl_data(p_cnt).weight(hb,20,data_pos-i);
            mr(2,2) = kl_data(p_cnt).weight(hb,18,data_pos-i);
            mr(2,3) = kl_data(p_cnt).weight(hb,16,data_pos-i);
            mr(2,4) = kl_data(p_cnt).weight(hb,14,data_pos-i);
            mr(3,1) = kl_data(p_cnt).weight(hb,23,data_pos-i);
            mr(3,2) = kl_data(p_cnt).weight(hb,21,data_pos-i);
            mr(3,3) = kl_data(p_cnt).weight(hb,19,data_pos-i);
            mr(3,4) = kl_data(p_cnt).weight(hb,17,data_pos-i);
            mr(4,1) =(kl_data(p_cnt).weight(hb,23,data_pos-i)+kl_data(p_cnt).weight(hb,24,data_pos-i))/2;
            mr(4,2) = kl_data(p_cnt).weight(hb,24,data_pos-i);
            mr(4,3) = kl_data(p_cnt).weight(hb,22,data_pos-i);
            mr(4,4) =(kl_data(p_cnt).weight(hb,17,data_pos-i) +kl_data(p_cnt).weight(hb,22,data_pos-i))/2;
            %         end;
            %         if i>data_pos-iis;mr=zeros(4,4);end;

            pol_r = interp2(x,y,mr,xi,yi,'spline');

            for a=1:size(pol_r,1);
                for b=1:size(pol_r,2);
                    if a<11 & b<(-a+11);pol_r(a,b)=NaN;end;
                    if a<11 & b>(a+21);pol_r(a,b)=NaN;end;
                    if a>21 & b<(a-21);pol_r(a,b)=NaN;end;
                    if a>21 & b>(-a+53);pol_r(a,b)=NaN;end;
                end;
            end;
            %******* It returns and draws *******
            set(0,'CurrentFigure',figure_h);
            axes('Position',map(i).wr);
            kl_map_h(p_cnt).map_plot(hb,i,2) = pcolor(pol_r);

            hold on;
            axis square;
            axis ij;
            axis off;
            shading interp;
            caxis([topo_range(1) topo_range(2)]);
            if para_p.angle(p_cnt).angle2==1;
                view(-45,90);
            elseif para_p.angle(p_cnt).angle2==2;
                view(45,90);
            elseif para_p.angle(p_cnt).angle2==3;
                view(135,90);
            elseif para_p.angle(p_cnt).angle2==4;
                view(225,90);
            end;
            if hb == 1;
                if para_p.angle(p_cnt).angle2==1;
                    if i==1 text(17,-7,'Topo B(C1)');end;
                    if i==2 text(17,-7,'Topo B(C2)');end;
                    if i==3 text(17,-7,'Topo B(C3)');end;
                    if i==4 text(17,-7,'Topo B(C4)');end;
                    if i==5 text(17,-7,'Topo B(C5)');end;
                    if i==6 text(17,-7,'Topo B(C6)');end;
                elseif para_p.angle(p_cnt).angle2==2;
                    if i==1 text(-10,15,'Topo B(C1)');end;
                    if i==2 text(-10,15,'Topo B(C2)');end;
                    if i==3 text(-10,15,'Topo B(C3)');end;
                    if i==4 text(-10,15,'Topo B(C4)');end;
                    if i==5 text(-10,15,'Topo B(C5)');end;
                    if i==6 text(-10,15,'Topo B(C6)');end;
                elseif para_p.angle(p_cnt).angle2==3;
                    if i==1 text(15,40,'Topo B(C1)');end;
                    if i==2 text(15,40,'Topo B(C2)');end;
                    if i==3 text(15,40,'Topo B(C3)');end;
                    if i==4 text(15,40,'Topo B(C4)');end;
                    if i==5 text(15,40,'Topo B(C5)');end;
                    if i==6 text(15,40,'Topo B(C6)');end;
                elseif para_p.angle(p_cnt).angle2==4;
                    if i==1 text(40,17,'Topo B(C1)');end;
                    if i==2 text(40,17,'Topo B(C2)');end;
                    if i==3 text(40,17,'Topo B(C3)');end;
                    if i==4 text(40,17,'Topo B(C4)');end;
                    if i==5 text(40,17,'Topo B(C5)');end;
                    if i==6 text(40,17,'Topo B(C6)');end;
                end;

                plot3(16.0,-4.0,0,'ok','MarkerSize',3,'MarkerFaceColor','r');       % left up
                plot3(-4.0,16.0,0,'o','MarkerSize',1,'Color',[0.8 0.8 0.8]);        % left down
                plot3(16.0,36.0,0,'o','MarkerSize',1,'Color',[0.8 0.8 0.8]);        % right down
                plot3(36.0,16.0,0,'o','MarkerSize',1,'Color',[0.8 0.8 0.8]);        % right up
            end;
            if i==6;                % 5->6
                buff=colorbar;
                set(buff,'Position',[0.89 0.1 0.03 0.4]);
            end;
            zoom(1.5);
            hold off;

            if hb == 1;
                if kl_map_h(p_cnt).chk_val == 1;
                    set(kl_map_h(p_cnt).map_plot(hb,:,1),'Visible','on');   % left
                    set(kl_map_h(p_cnt).map_plot(hb,:,2),'Visible','on');   % rigth
                else;
                    set(kl_map_h(p_cnt).map_plot(hb,:,1),'Visible','off');   % left
                    set(kl_map_h(p_cnt).map_plot(hb,:,2),'Visible','off');   % rigth
                end;
            end;
            if hb == 2;
                if kl_map_h(p_cnt).chk_val == 2;
                    set(kl_map_h(p_cnt).map_plot(hb,:,1),'Visible','on');   % left
                    set(kl_map_h(p_cnt).map_plot(hb,:,2),'Visible','on');   % rigth
                else;
                    set(kl_map_h(p_cnt).map_plot(hb,:,1),'Visible','off');   % left
                    set(kl_map_h(p_cnt).map_plot(hb,:,2),'Visible','off');   % rigth
                end;
            end;
            if hb == 3;
                if kl_map_h(p_cnt).chk_val == 3;
                    set(kl_map_h(p_cnt).map_plot(hb,:,1),'Visible','on');   % left
                    set(kl_map_h(p_cnt).map_plot(hb,:,2),'Visible','on');   % rigth
                else;
                    set(kl_map_h(p_cnt).map_plot(hb,:,1),'Visible','off');   % left
                    set(kl_map_h(p_cnt).map_plot(hb,:,2),'Visible','off');   % rigth
                end;
            end;
            if hb == 4;
                if kl_map_h(p_cnt).chk_val == 4;
                    set(kl_map_h(p_cnt).map_plot(hb,:,1),'Visible','on');   % left
                    set(kl_map_h(p_cnt).map_plot(hb,:,2),'Visible','on');   % rigth
                else;
                    set(kl_map_h(p_cnt).map_plot(hb,:,1),'Visible','off');   % left
                    set(kl_map_h(p_cnt).map_plot(hb,:,2),'Visible','off');   % rigth
                end;
            end;
        end;  % i

    end;     % hb
end;        % probe mode

%***** 4*4 Mode *****
if info(p_cnt).probe_mode == 2;
    topo_range(1)= -0.5;
    topo_range(2)= 0.5;
    [x,y]        = meshgrid(1:1:6);
    [xi,yi]      = meshgrid(1:0.1:6);
    data_pos    = length(kl_data(p_cnt).weight)+1;;

    for hb=1:3;
        %************ Topo View **************
        for i=1:6;                 % 5->6
            %******* 45 degrees rotates to the circumference of a clock *******
            %        if i<=data_pos-iis;
            m(1,1) =(kl_data(p_cnt).weight(hb,4,data_pos-i)+kl_data(p_cnt).weight(hb,11,data_pos-i)*2+kl_data(p_cnt).weight(hb,18,data_pos-i))/4;
            m(1,2) =(kl_data(p_cnt).weight(hb,4,data_pos-i)+kl_data(p_cnt).weight(hb,11,data_pos-i))/2;
            m(1,3) = kl_data(p_cnt).weight(hb,4,data_pos-i);
            m(1,4) = kl_data(p_cnt).weight(hb,1,data_pos-i);
            m(1,5) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i))/2;
            m(1,6) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i)*2+kl_data(p_cnt).weight(hb,3,data_pos-i))/4;

            m(2,1) =(kl_data(p_cnt).weight(hb,11,data_pos-i)+kl_data(p_cnt).weight(hb,18,data_pos-i))/2;
            m(2,2) = kl_data(p_cnt).weight(hb,11,data_pos-i);
            m(2,3) = kl_data(p_cnt).weight(hb,8,data_pos-i);
            m(2,4) = kl_data(p_cnt).weight(hb,5,data_pos-i);
            m(2,5) = kl_data(p_cnt).weight(hb,2,data_pos-i);
            m(2,6) =(kl_data(p_cnt).weight(hb,2,data_pos-i)+kl_data(p_cnt).weight(hb,3,data_pos-i))/2;

            m(3,1) = kl_data(p_cnt).weight(hb,18,data_pos-i);
            m(3,2) = kl_data(p_cnt).weight(hb,15,data_pos-i);
            m(3,3) = kl_data(p_cnt).weight(hb,12,data_pos-i);
            m(3,4) = kl_data(p_cnt).weight(hb,9,data_pos-i);
            m(3,5) = kl_data(p_cnt).weight(hb,6,data_pos-i);
            m(3,6) = kl_data(p_cnt).weight(hb,3,data_pos-i);

            m(4,1) = kl_data(p_cnt).weight(hb,22,data_pos-i);
            m(4,2) = kl_data(p_cnt).weight(hb,19,data_pos-i);
            m(4,3) = kl_data(p_cnt).weight(hb,16,data_pos-i);
            m(4,4) = kl_data(p_cnt).weight(hb,13,data_pos-i);
            m(4,5) = kl_data(p_cnt).weight(hb,10,data_pos-i);
            m(4,6) = kl_data(p_cnt).weight(hb,7,data_pos-i);

            m(5,1) =(kl_data(p_cnt).weight(hb,22,data_pos-i)+kl_data(p_cnt).weight(hb,23,data_pos-i))/2;
            m(5,2) = kl_data(p_cnt).weight(hb,23,data_pos-i);
            m(5,3) = kl_data(p_cnt).weight(hb,20,data_pos-i);
            m(5,4) = kl_data(p_cnt).weight(hb,17,data_pos-i);
            m(5,5) = kl_data(p_cnt).weight(hb,14,data_pos-i);
            m(5,6) =(kl_data(p_cnt).weight(hb,7,data_pos-i) +kl_data(p_cnt).weight(hb,14,data_pos-i))/2;

            m(6,1) =(kl_data(p_cnt).weight(hb,22,data_pos-i)+kl_data(p_cnt).weight(hb,23,data_pos-i)*2+kl_data(p_cnt).weight(hb,24,data_pos-i))/4;
            m(6,2) =(kl_data(p_cnt).weight(hb,23,data_pos-i)+kl_data(p_cnt).weight(hb,24,data_pos-i))/2;
            m(6,3) = kl_data(p_cnt).weight(hb,24,data_pos-i);
            m(6,4) = kl_data(p_cnt).weight(hb,21,data_pos-i);
            m(6,5) =(kl_data(p_cnt).weight(hb,14,data_pos-i)+kl_data(p_cnt).weight(hb,21,data_pos-i))/2;
            m(6,6) =(kl_data(p_cnt).weight(hb,7,data_pos-i)+kl_data(p_cnt).weight(hb,14,data_pos-i)*2+kl_data(p_cnt).weight(hb,21,data_pos-i))/4;

            pol = interp2(x,y,m,xi,yi,'spline');

            for a=1:size(pol,1);
                for b=1:size(pol,2);
                    if a<21 & b<(-a+21);pol(a,b)=NaN;end;
                    if a<21 & b>(a+31);pol(a,b)=NaN;end;
                    if a>31 & b<(a-31);pol(a,b)=NaN;end;
                    if a>31 & b>(-a+83);pol(a,b)=NaN;end;
                end;
            end;
            %*******It returns and draws  *******
            set(0,'CurrentFigure',figure_h);
            axes('Position',map(i).w);
            kl_map_h(p_cnt).map_plot(hb,i,1) = pcolor(pol);

            hold on;
            axis square;
            axis ij;
            axis off;
            shading interp;
            caxis([topo_range(1) topo_range(2)]);
            if para_p.angle(p_cnt).angle1==1;
                view(-45,90);
            elseif para_p.angle(p_cnt).angle1==2;
                view(45,90);
            elseif para_p.angle(p_cnt).angle1==3;
                view(135,90);
            elseif para_p.angle(p_cnt).angle1==4;
                view(225,90);
            end;
            if hb == 1;
                if para_p.angle(p_cnt).angle1==1;
                    if i==1 text(30,-10,'Topo(C1)');end;
                    if i==2 text(30,-10,'Topo(C2)');end;
                    if i==3 text(30,-10,'Topo(C3)');end;
                    if i==4 text(30,-10,'Topo(C4)');end;
                    if i==5 text(30,-10,'Topo(C5)');end;
                    if i==6 text(30,-10,'Topo(C6)');end;
                elseif para_p.angle(p_cnt).angle1==2;
                    if i==1 text(-15,25,'Topo(C1)');end;
                    if i==2 text(-15,25,'Topo(C2)');end;
                    if i==3 text(-15,25,'Topo(C3)');end;
                    if i==4 text(-15,25,'Topo(C4)');end;
                    if i==5 text(-15,25,'Topo(C5)');end;
                    if i==6 text(-15,25,'Topo(C6)');end;
                elseif para_p.angle(p_cnt).angle1==3;
                    if i==1 text(25,65,'Topo(C1)');end;
                    if i==2 text(25,65,'Topo(C2)');end;
                    if i==3 text(25,65,'Topo(C3)');end;
                    if i==4 text(25,65,'Topo(C4)');end;
                    if i==5 text(25,65,'Topo(C5)');end;
                    if i==6 text(25,65,'Topo(C6)');end;
                elseif para_p.angle(p_cnt).angle1==4;
                    if i==1 text(60,30,'Topo(C1)');end;
                    if i==2 text(60,30,'Topo(C2)');end;
                    if i==3 text(60,30,'Topo(C3)');end;
                    if i==4 text(60,30,'Topo(C4)');end;
                    if i==5 text(60,30,'Topo(C5)');end;
                    if i==6 text(60,30,'Topo(C6)');end;
                end;
                plot3(25.0,-5.0,0,'ok','MarkerSize',3,'MarkerFaceColor','r');       % left up
                plot3(-5.0,25.0,0,'o','MarkerSize',3,'Color',[0.8 0.8 0.8]);        % left down
                plot3(25.0,55.0,0,'o','MarkerSize',3,'Color',[0.8 0.8 0.8]);        % right down
                plot3(55.0,25.0,0,'o','MarkerSize',3,'Color',[0.8 0.8 0.8]);        % right up
            end;
            if i==6;                      % 5->6
                buff=colorbar;
                set(buff,'Position',[0.89 0.1 0.03 0.4]);
            end;
            zoom(1.5);
            hold off;
        end;
        if hb == 1;
            if kl_map_h(p_cnt).chk_val == 1;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','on');
                %            set(kl_map_h(p_cnt).map_plot(hb,i,1),'Visible','on');
            else;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','off');
            end;
        end;
        if hb == 2;
            if kl_map_h(p_cnt).chk_val == 2;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','on');
            else;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','off');
            end;
        end;
        if hb == 3;
            if kl_map_h(p_cnt).chk_val == 3;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','on');
            else;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','off');
            end;
        end;
        if hb == 4;
            if kl_map_h(p_cnt).chk_val == 4;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','on');
            else;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','off');
            end;
        end;
    end;
end;

%%%%%%%%%%%%

%***** 3*5 Mode *****
if info(p_cnt).probe_mode == 3;
    topo_range(1)= -0.5;
    topo_range(2)= 0.5;
    [x,y]        = meshgrid(1:1:6);
    [xi,yi]      = meshgrid(1:0.1:6);
    data_pos    = length(kl_data(p_cnt).weight)+1;

    for hb=1:3;
        %************ Topo View **************
        for i=1:6;
            %******* 45 degrees rotates to the circumference of a clock *******
            m(1,1) =(kl_data(p_cnt).weight(hb,5,data_pos-i)+kl_data(p_cnt).weight(hb,14,data_pos-i))/2;
            m(1,2) = kl_data(p_cnt).weight(hb,5,data_pos-i);
            m(1,3) = kl_data(p_cnt).weight(hb,1,data_pos-i);
            m(1,4) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i))/2;
            m(1,5) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i)*2+kl_data(p_cnt).weight(hb,3,data_pos-i))/4;
            m(1,6) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i)*3+kl_data(p_cnt).weight(hb,3,data_pos-i)+kl_data(p_cnt).weight(hb,4,data_pos-i))/8;

            m(2,1) = kl_data(p_cnt).weight(hb,14,data_pos-i);
            m(2,2) = kl_data(p_cnt).weight(hb,10,data_pos-i);
            m(2,3) = kl_data(p_cnt).weight(hb,6,data_pos-i);
            m(2,4) = kl_data(p_cnt).weight(hb,2,data_pos-i);
            m(2,5) =(kl_data(p_cnt).weight(hb,2,data_pos-i)+kl_data(p_cnt).weight(hb,3,data_pos-i))/2;
            m(2,6) =(kl_data(p_cnt).weight(hb,2,data_pos-i)+kl_data(p_cnt).weight(hb,3,data_pos-i)*2+kl_data(p_cnt).weight(hb,4,data_pos-i))/2;

            m(3,1) = kl_data(p_cnt).weight(hb,19,data_pos-i);
            m(3,2) = kl_data(p_cnt).weight(hb,15,data_pos-i);
            m(3,3) = kl_data(p_cnt).weight(hb,11,data_pos-i);
            m(3,4) = kl_data(p_cnt).weight(hb,7,data_pos-i);
            m(3,5) = kl_data(p_cnt).weight(hb,3,data_pos-i);
            m(3,6) = (kl_data(p_cnt).weight(hb,3,data_pos-i)+kl_data(p_cnt).weight(hb,4,data_pos-i))/2;

            m(4,1) =(kl_data(p_cnt).weight(hb,19,data_pos-i)+kl_data(p_cnt).weight(hb,20,data_pos-i))/2;
            m(4,2) = kl_data(p_cnt).weight(hb,20,data_pos-i);
            m(4,3) = kl_data(p_cnt).weight(hb,16,data_pos-i);
            m(4,4) = kl_data(p_cnt).weight(hb,12,data_pos-i);
            m(4,5) = kl_data(p_cnt).weight(hb,8,data_pos-i);
            m(4,6) = kl_data(p_cnt).weight(hb,4,data_pos-i);

            m(5,1) =(kl_data(p_cnt).weight(hb,19,data_pos-i)+kl_data(p_cnt).weight(hb,20,data_pos-i)*2+kl_data(p_cnt).weight(hb,21,data_pos-i))/4;
            m(5,2) =(kl_data(p_cnt).weight(hb,20,data_pos-i)+kl_data(p_cnt).weight(hb,21,data_pos-i))/2;
            m(5,3) = kl_data(p_cnt).weight(hb,21,data_pos-i);
            m(5,4) = kl_data(p_cnt).weight(hb,17,data_pos-i);
            m(5,5) = kl_data(p_cnt).weight(hb,13,data_pos-i);
            m(5,6) = kl_data(p_cnt).weight(hb,9,data_pos-i);

            m(6,1) =(kl_data(p_cnt).weight(hb,19,data_pos-i)+kl_data(p_cnt).weight(hb,20,data_pos-i)*3+kl_data(p_cnt).weight(hb,21,data_pos-i)*3+kl_data(p_cnt).weight(hb,22,data_pos-i))/8;
            m(6,2) =(kl_data(p_cnt).weight(hb,20,data_pos-i)+kl_data(p_cnt).weight(hb,21,data_pos-i)*2+kl_data(p_cnt).weight(hb,22,data_pos-i))/4;
            m(6,3) =(kl_data(p_cnt).weight(hb,21,data_pos-i)+kl_data(p_cnt).weight(hb,22,data_pos-i))/2;
            m(6,4) = kl_data(p_cnt).weight(hb,22,data_pos-i);
            m(6,5) = kl_data(p_cnt).weight(hb,18,data_pos-i);
            m(6,6) =(kl_data(p_cnt).weight(hb,9,data_pos-i)+kl_data(p_cnt).weight(hb,18,data_pos-i))/2;

            pol = interp2(x,y,m,xi,yi,'spline');

            for a=1:size(pol,1);
                for b=1:size(pol,2);
                    if a<11 & b<(-a+11);pol(a,b)=NaN;end;
                    if a<31 & b>(a+21);pol(a,b)=NaN;end;
                    if a>21 & b<(a-21);pol(a,b)=NaN;end;
                    if a>41 & b>(-a+93);pol(a,b)=NaN;end;
                end ;
            end;
            %*******It returns and draws  *******
            set(0,'CurrentFigure',figure_h);
            axes('Position',map(i).w);
            kl_map_h(p_cnt).map_plot(hb,i,1) = pcolor(pol);
            hold on;
            axis square;
            axis ij;
            axis off;
            shading interp;
            caxis([topo_range(1) topo_range(2)]);
            if para_p.angle(p_cnt).angle1==1;
                view(-45,90);
            elseif para_p.angle(p_cnt).angle1==2;
                view(45,90);
            elseif para_p.angle(p_cnt).angle1==3;
                view(135,90);
            elseif para_p.angle(p_cnt).angle1==4;
                view(225,90);
            end;
            if hb == 1;
                if para_p.angle(p_cnt).angle1==1;
                    if i==1 text(27,-1,'Topo(C1)');end;
                    if i==2 text(27,-1,'Topo(C2)');end;
                    if i==3 text(27,-1,'Topo(C3)');end;
                    if i==4 text(27,-1,'Topo(C4)');end;
                    if i==5 text(27,-1,'Topo(C5)');end;
                    if i==6 text(27,-1,'Topo(C6)');end;
                elseif para_p.angle(p_cnt).angle1==2;
                    if i==1 text(-7,13,'Topo(C1)');end;
                    if i==2 text(-7,13,'Topo(C2)');end;
                    if i==3 text(-7,13,'Topo(C3)');end;
                    if i==4 text(-7,13,'Topo(C4)');end;
                    if i==5 text(-7,13,'Topo(C5)');end;
                    if i==6 text(-7,13,'Topo(C6)');end;
                elseif para_p.angle(p_cnt).angle1==3;
                    if i==1 text(75,75,'Topo(C1)');end;
                    if i==2 text(70,75,'Topo(C2)');end;
                    if i==3 text(75,75,'Topo(C3)');end;
                    if i==4 text(75,75,'Topo(C4)');end;
                    if i==5 text(75,75,'Topo(C5)');end;
                    if i==6 text(75,75,'Topo(C6)');end;
                elseif para_p.angle(p_cnt).angle1==4;
                    if i==1 text(60,40,'Topo(C1)');end;
                    if i==2 text(60,40,'Topo(C2)');end;
                    if i==3 text(60,40,'Topo(C3)');end;
                    if i==4 text(60,40,'Topo(C4)');end;
                    if i==5 text(60,40,'Topo(C5)');end;
                    if i==6 text(60,40,'Topo(C6)');end;
                end;

                plot3(15.0,-5.0,0,'ok','MarkerSize',3,'MarkerFaceColor','r');       % left up
                plot3(-5.0,15.0,0,'o','MarkerSize',1,'Color',[0.8 0.8 0.8]);        % left down
                plot3(35.0,55.0,0,'o','MarkerSize',1,'Color',[0.8 0.8 0.8]);        % right down
                plot3(55.0,35.0,0,'o','MarkerSize',1,'Color',[0.8 0.8 0.8]);        % right up
            end;
            if i==6;
                buff=colorbar;
                set(buff,'Position',[0.89 0.1 0.03 0.4]);
            end;
            zoom(2.0);
            hold off;
        end;
        if hb == 1;
            if kl_map_h(p_cnt).chk_val == 1;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','on');
            else;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','off');
            end;
        end;
        if hb == 2;
            if kl_map_h(p_cnt).chk_val == 2;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','on');
            else;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','off');
            end;
        end;
        if hb == 3;
            if kl_map_h(p_cnt).chk_val == 3;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','on');
            else;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','off');
            end;
        end;
        if hb == 4;
            if kl_map_h(p_cnt).chk_val == 3;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','on');
            else;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','off');
            end;
        end;
    end;
end;

%***** 3x11 Mode *****
if info(p_cnt).probe_mode == 4;
    topo_range(1)= -0.5;
    topo_range(2)= 0.5;
    [x,y]     = meshgrid(1:1:12);
    [xi,yi]   = meshgrid(1:0.1:12);
    data_pos    = length(kl_data(p_cnt).weight)+1;
    for hb=1:3;
        %************ Topo View **************
        for i=1:6;                 % 5->6   m(1,1) =(hb_map(i,11)+hb_map(i,32))/2;
            m(1,1) = (kl_data(p_cnt).weight(hb,11,data_pos-i)+kl_data(p_cnt).weight(hb,32,data_pos-i))/2;
            m(1,2) = kl_data(p_cnt).weight(hb,11,data_pos-i);
            m(1,3) = kl_data(p_cnt).weight(hb,1,data_pos-i);
            m(1,4) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i))/2;
            m(1,5) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i)*2+kl_data(p_cnt).weight(hb,3,data_pos-i))/4;
            m(1,6) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i)*3+kl_data(p_cnt).weight(hb,3,data_pos-i)*3+kl_data(p_cnt).weight(hb,4,data_pos-i))/8;
            m(1,7) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i)*4+kl_data(p_cnt).weight(hb,3,data_pos-i)*6+kl_data(p_cnt).weight(hb,4,data_pos-i)*4+kl_data(p_cnt).weight(hb,5,data_pos-i))/16; %
            m(1,8) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i)*5+kl_data(p_cnt).weight(hb,3,data_pos-i)*10+kl_data(p_cnt).weight(hb,4,data_pos-i)*10+kl_data(p_cnt).weight(hb,5,data_pos-i)*5+kl_data(p_cnt).weight(hb,6,data_pos-i))/32; %
            m(1,9) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i)*6+kl_data(p_cnt).weight(hb,3,data_pos-i)*15+kl_data(p_cnt).weight(hb,4,data_pos-i)*20+kl_data(p_cnt).weight(hb,5,data_pos-i)*15+kl_data(p_cnt).weight(hb,6,data_pos-i)*6+kl_data(p_cnt).weight(hb,7,data_pos-i))/64; %
            m(1,10) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i)*7+kl_data(p_cnt).weight(hb,3,data_pos-i)*21+kl_data(p_cnt).weight(hb,4,data_pos-i)*35+kl_data(p_cnt).weight(hb,5,data_pos-i)*35+kl_data(p_cnt).weight(hb,6,data_pos-i)*21+kl_data(p_cnt).weight(hb,7,data_pos-i)*7+kl_data(p_cnt).weight(hb,8,data_pos-i))/128; %
            m(1,11) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i)*8+kl_data(p_cnt).weight(hb,3,data_pos-i)*28+kl_data(p_cnt).weight(hb,4,data_pos-i)*56+kl_data(p_cnt).weight(hb,5,data_pos-i)*70+kl_data(p_cnt).weight(hb,6,data_pos-i)*56+kl_data(p_cnt).weight(hb,7,data_pos-i)*28+kl_data(p_cnt).weight(hb,8,data_pos-i)*8+kl_data(p_cnt).weight(hb,9,data_pos-i))/256; %
            m(1,12) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i)*9+kl_data(p_cnt).weight(hb,3,data_pos-i)*36+kl_data(p_cnt).weight(hb,4,data_pos-i)*84+kl_data(p_cnt).weight(hb,5,data_pos-i)*126+kl_data(p_cnt).weight(hb,6,data_pos-i)*126+kl_data(p_cnt).weight(hb,7,data_pos-i)*84+kl_data(p_cnt).weight(hb,8,data_pos-i)*36+kl_data(p_cnt).weight(hb,9,data_pos-i)*9+kl_data(p_cnt).weight(hb,10,data_pos-i))/512; %

            m(2,1) =(kl_data(p_cnt).weight(hb,32,data_pos-i));
            m(2,2) = kl_data(p_cnt).weight(hb,22,data_pos-i);
            m(2,3) = kl_data(p_cnt).weight(hb,12,data_pos-i);
            m(2,4) = kl_data(p_cnt).weight(hb,2,data_pos-i);
            m(2,5) =(kl_data(p_cnt).weight(hb,2,data_pos-i)+kl_data(p_cnt).weight(hb,3,data_pos-i))/2;
            m(2,6) =(kl_data(p_cnt).weight(hb,2,data_pos-i)+kl_data(p_cnt).weight(hb,3,data_pos-i)*2+kl_data(p_cnt).weight(hb,4,data_pos-i))/4;
            m(2,7) =(kl_data(p_cnt).weight(hb,2,data_pos-i)+kl_data(p_cnt).weight(hb,3,data_pos-i)*3+kl_data(p_cnt).weight(hb,4,data_pos-i)*3+kl_data(p_cnt).weight(hb,5,data_pos-i))/8;
            m(2,8) =(kl_data(p_cnt).weight(hb,2,data_pos-i)+kl_data(p_cnt).weight(hb,3,data_pos-i)*4+kl_data(p_cnt).weight(hb,4,data_pos-i)*6+kl_data(p_cnt).weight(hb,5,data_pos-i)*4+kl_data(p_cnt).weight(hb,6,data_pos-i))/16; %
            m(2,9) =(kl_data(p_cnt).weight(hb,2,data_pos-i)+kl_data(p_cnt).weight(hb,3,data_pos-i)*5+kl_data(p_cnt).weight(hb,4,data_pos-i)*10+kl_data(p_cnt).weight(hb,5,data_pos-i)*10+kl_data(p_cnt).weight(hb,6,data_pos-i)*5+kl_data(p_cnt).weight(hb,7,data_pos-i))/32; %
            m(2,10) =(kl_data(p_cnt).weight(hb,2,data_pos-i)+kl_data(p_cnt).weight(hb,3,data_pos-i)*6+kl_data(p_cnt).weight(hb,4,data_pos-i)*15+kl_data(p_cnt).weight(hb,5,data_pos-i)*20+kl_data(p_cnt).weight(hb,6,data_pos-i)*15+kl_data(p_cnt).weight(hb,7,data_pos-i)*6+kl_data(p_cnt).weight(hb,8,data_pos-i))/64; %
            m(2,11) =(kl_data(p_cnt).weight(hb,2,data_pos-i)+kl_data(p_cnt).weight(hb,3,data_pos-i)*7+kl_data(p_cnt).weight(hb,4,data_pos-i)*21+kl_data(p_cnt).weight(hb,5,data_pos-i)*35+kl_data(p_cnt).weight(hb,6,data_pos-i)*35+kl_data(p_cnt).weight(hb,7,data_pos-i)*21+kl_data(p_cnt).weight(hb,8,data_pos-i)*7+kl_data(p_cnt).weight(hb,9,data_pos-i))/128; %
            m(2,12) =(kl_data(p_cnt).weight(hb,2,data_pos-i)+kl_data(p_cnt).weight(hb,3,data_pos-i)*8+kl_data(p_cnt).weight(hb,4,data_pos-i)*28+kl_data(p_cnt).weight(hb,5,data_pos-i)*56+kl_data(p_cnt).weight(hb,6,data_pos-i)*70+kl_data(p_cnt).weight(hb,7,data_pos-i)*56+kl_data(p_cnt).weight(hb,8,data_pos-i)*28+kl_data(p_cnt).weight(hb,9,data_pos-i)*8+kl_data(p_cnt).weight(hb,10,data_pos-i))/256; %

            m(3,1) =(kl_data(p_cnt).weight(hb,43,data_pos-i));
            m(3,2) = kl_data(p_cnt).weight(hb,33,data_pos-i);
            m(3,3) = kl_data(p_cnt).weight(hb,23,data_pos-i);
            m(3,4) = kl_data(p_cnt).weight(hb,13,data_pos-i);
            m(3,5) = kl_data(p_cnt).weight(hb,3,data_pos-i);
            m(3,6) =(kl_data(p_cnt).weight(hb,3,data_pos-i)+kl_data(p_cnt).weight(hb,4,data_pos-i))/2;
            m(3,7) =(kl_data(p_cnt).weight(hb,3,data_pos-i)+kl_data(p_cnt).weight(hb,4,data_pos-i)*2+kl_data(p_cnt).weight(hb,5,data_pos-i))/4;
            m(3,8) =(kl_data(p_cnt).weight(hb,3,data_pos-i)+kl_data(p_cnt).weight(hb,4,data_pos-i)*3+kl_data(p_cnt).weight(hb,5,data_pos-i)*3+kl_data(p_cnt).weight(hb,6,data_pos-i))/8;
            m(3,9) =(kl_data(p_cnt).weight(hb,3,data_pos-i)+kl_data(p_cnt).weight(hb,4,data_pos-i)*4+kl_data(p_cnt).weight(hb,5,data_pos-i)*6+kl_data(p_cnt).weight(hb,6,data_pos-i)*4+kl_data(p_cnt).weight(hb,7,data_pos-i))/16; %
            m(3,10) =(kl_data(p_cnt).weight(hb,3,data_pos-i)+kl_data(p_cnt).weight(hb,4,data_pos-i)*5+kl_data(p_cnt).weight(hb,5,data_pos-i)*10+kl_data(p_cnt).weight(hb,6,data_pos-i)*10+kl_data(p_cnt).weight(hb,7,data_pos-i)*5+kl_data(p_cnt).weight(hb,8,data_pos-i))/32; %
            m(3,11) =(kl_data(p_cnt).weight(hb,3,data_pos-i)+kl_data(p_cnt).weight(hb,4,data_pos-i)*6+kl_data(p_cnt).weight(hb,5,data_pos-i)*15+kl_data(p_cnt).weight(hb,6,data_pos-i)*20+kl_data(p_cnt).weight(hb,7,data_pos-i)*15+kl_data(p_cnt).weight(hb,8,data_pos-i)*6+kl_data(p_cnt).weight(hb,9,data_pos-i))/64; %
            m(3,12) =(kl_data(p_cnt).weight(hb,3,data_pos-i)+kl_data(p_cnt).weight(hb,4,data_pos-i)*7+kl_data(p_cnt).weight(hb,5,data_pos-i)*21+kl_data(p_cnt).weight(hb,6,data_pos-i)*35+kl_data(p_cnt).weight(hb,7,data_pos-i)*35+kl_data(p_cnt).weight(hb,8,data_pos-i)*21+kl_data(p_cnt).weight(hb,9,data_pos-i)*7+kl_data(p_cnt).weight(hb,10,data_pos-i))/128; %

            m(4,1) =(kl_data(p_cnt).weight(hb,43,data_pos-i)+kl_data(p_cnt).weight(hb,44,data_pos-i))/2;
            m(4,2) =(kl_data(p_cnt).weight(hb,44,data_pos-i));
            m(4,3) = kl_data(p_cnt).weight(hb,34,data_pos-i);
            m(4,4) = kl_data(p_cnt).weight(hb,24,data_pos-i);
            m(4,5) = kl_data(p_cnt).weight(hb,14,data_pos-i);
            m(4,6) = kl_data(p_cnt).weight(hb,4,data_pos-i);
            m(4,7) =(kl_data(p_cnt).weight(hb,4,data_pos-i)+kl_data(p_cnt).weight(hb,5,data_pos-i))/2;
            m(4,8) =(kl_data(p_cnt).weight(hb,4,data_pos-i)+kl_data(p_cnt).weight(hb,5,data_pos-i)*2+kl_data(p_cnt).weight(hb,6,data_pos-i))/4;
            m(4,9) =(kl_data(p_cnt).weight(hb,4,data_pos-i)+kl_data(p_cnt).weight(hb,5,data_pos-i)*3+kl_data(p_cnt).weight(hb,6,data_pos-i)*3+kl_data(p_cnt).weight(hb,7,data_pos-i))/8;
            m(4,10) =(kl_data(p_cnt).weight(hb,4,data_pos-i)+kl_data(p_cnt).weight(hb,5,data_pos-i)*4+kl_data(p_cnt).weight(hb,6,data_pos-i)*6+kl_data(p_cnt).weight(hb,7,data_pos-i)*4+kl_data(p_cnt).weight(hb,8,data_pos-i))/16; %
            m(4,11) =(kl_data(p_cnt).weight(hb,4,data_pos-i)+kl_data(p_cnt).weight(hb,5,data_pos-i)*5+kl_data(p_cnt).weight(hb,6,data_pos-i)*10+kl_data(p_cnt).weight(hb,7,data_pos-i)*10+kl_data(p_cnt).weight(hb,8,data_pos-i)*5+kl_data(p_cnt).weight(hb,9,data_pos-i))/32;
            m(4,12) =(kl_data(p_cnt).weight(hb,4,data_pos-i)+kl_data(p_cnt).weight(hb,5,data_pos-i)*6+kl_data(p_cnt).weight(hb,6,data_pos-i)*15+kl_data(p_cnt).weight(hb,7,data_pos-i)*20+kl_data(p_cnt).weight(hb,8,data_pos-i)*15+kl_data(p_cnt).weight(hb,9,data_pos-i)*3+kl_data(p_cnt).weight(hb,10,data_pos-i))/64; %

            m(5,1) =(kl_data(p_cnt).weight(hb,43,data_pos-i)+kl_data(p_cnt).weight(hb,44,data_pos-i)*2+kl_data(p_cnt).weight(hb,45,data_pos-i))/4;
            m(5,2) =(kl_data(p_cnt).weight(hb,44,data_pos-i)+kl_data(p_cnt).weight(hb,45,data_pos-i))/2;
            m(5,3) =(kl_data(p_cnt).weight(hb,45,data_pos-i));
            m(5,4) = kl_data(p_cnt).weight(hb,35,data_pos-i);
            m(5,5) = kl_data(p_cnt).weight(hb,25,data_pos-i);
            m(5,6) = kl_data(p_cnt).weight(hb,15,data_pos-i);
            m(5,7) = kl_data(p_cnt).weight(hb,5,data_pos-i);
            m(5,8) =(kl_data(p_cnt).weight(hb,5,data_pos-i)+kl_data(p_cnt).weight(hb,6,data_pos-i))/2;
            m(5,9) =(kl_data(p_cnt).weight(hb,5,data_pos-i)+kl_data(p_cnt).weight(hb,6,data_pos-i)*2+kl_data(p_cnt).weight(hb,7,data_pos-i))/4;
            m(5,10) =(kl_data(p_cnt).weight(hb,5,data_pos-i)+kl_data(p_cnt).weight(hb,6,data_pos-i)*3+kl_data(p_cnt).weight(hb,7,data_pos-i)*3+kl_data(p_cnt).weight(hb,8,data_pos-i))/8;
            m(5,11) =(kl_data(p_cnt).weight(hb,5,data_pos-i)+kl_data(p_cnt).weight(hb,6,data_pos-i)*4+kl_data(p_cnt).weight(hb,7,data_pos-i)*6+kl_data(p_cnt).weight(hb,8,data_pos-i)*4+kl_data(p_cnt).weight(hb,9,data_pos-i))/16; %
            m(5,12) =(kl_data(p_cnt).weight(hb,5,data_pos-i)+kl_data(p_cnt).weight(hb,6,data_pos-i)*5+kl_data(p_cnt).weight(hb,7,data_pos-i)*10+kl_data(p_cnt).weight(hb,8,data_pos-i)*10+kl_data(p_cnt).weight(hb,9,data_pos-i)*5+kl_data(p_cnt).weight(hb,10,data_pos-i))/32; %

            m(6,1) =(kl_data(p_cnt).weight(hb,43,data_pos-i)+kl_data(p_cnt).weight(hb,44,data_pos-i)*3+kl_data(p_cnt).weight(hb,45,data_pos-i)*3+kl_data(p_cnt).weight(hb,46,data_pos-i))/8;
            m(6,2) =(kl_data(p_cnt).weight(hb,44,data_pos-i)+kl_data(p_cnt).weight(hb,45,data_pos-i)*2+kl_data(p_cnt).weight(hb,46,data_pos-i))/4;
            m(6,3) =(kl_data(p_cnt).weight(hb,45,data_pos-i)+kl_data(p_cnt).weight(hb,46,data_pos-i))/2;
            m(6,4) =(kl_data(p_cnt).weight(hb,46,data_pos-i));
            m(6,5) = kl_data(p_cnt).weight(hb,36,data_pos-i);
            m(6,6) = kl_data(p_cnt).weight(hb,26,data_pos-i);
            m(6,7) = kl_data(p_cnt).weight(hb,16,data_pos-i);
            m(6,8) = kl_data(p_cnt).weight(hb,6,data_pos-i);
            m(6,9) =(kl_data(p_cnt).weight(hb,6,data_pos-i)+kl_data(p_cnt).weight(hb,7,data_pos-i))/2;
            m(6,10) =(kl_data(p_cnt).weight(hb,6,data_pos-i)+kl_data(p_cnt).weight(hb,7,data_pos-i)*2+kl_data(p_cnt).weight(hb,8,data_pos-i))/4;
            m(6,11) =(kl_data(p_cnt).weight(hb,6,data_pos-i)+kl_data(p_cnt).weight(hb,7,data_pos-i)*3+kl_data(p_cnt).weight(hb,8,data_pos-i)*3+kl_data(p_cnt).weight(hb,9,data_pos-i))/8;
            m(6,12) =(kl_data(p_cnt).weight(hb,6,data_pos-i)+kl_data(p_cnt).weight(hb,7,data_pos-i)*4+kl_data(p_cnt).weight(hb,8,data_pos-i)*6+kl_data(p_cnt).weight(hb,9,data_pos-i)*4+kl_data(p_cnt).weight(hb,10,data_pos-i))/16; %

            m(7,1) =(kl_data(p_cnt).weight(hb,43,data_pos-i)+kl_data(p_cnt).weight(hb,44,data_pos-i)*4+kl_data(p_cnt).weight(hb,45,data_pos-i)*6+kl_data(p_cnt).weight(hb,46,data_pos-i)*4+kl_data(p_cnt).weight(hb,47,data_pos-i))/16; %
            m(7,2) =(kl_data(p_cnt).weight(hb,44,data_pos-i)+kl_data(p_cnt).weight(hb,45,data_pos-i)*3+kl_data(p_cnt).weight(hb,46,data_pos-i)*3+kl_data(p_cnt).weight(hb,47,data_pos-i))/8;
            m(7,3) =(kl_data(p_cnt).weight(hb,45,data_pos-i)+kl_data(p_cnt).weight(hb,46,data_pos-i)*2+kl_data(p_cnt).weight(hb,47,data_pos-i))/4;
            m(7,4) =(kl_data(p_cnt).weight(hb,46,data_pos-i)+kl_data(p_cnt).weight(hb,47,data_pos-i))/2;
            m(7,5) =(kl_data(p_cnt).weight(hb,47,data_pos-i));
            m(7,6) = kl_data(p_cnt).weight(hb,37,data_pos-i);
            m(7,7) = kl_data(p_cnt).weight(hb,27,data_pos-i);
            m(7,8) = kl_data(p_cnt).weight(hb,17,data_pos-i);
            m(7,9) = kl_data(p_cnt).weight(hb,7,data_pos-i);
            m(7,10) =(kl_data(p_cnt).weight(hb,7,data_pos-i)+kl_data(p_cnt).weight(hb,8,data_pos-i))/2;
            m(7,11) =(kl_data(p_cnt).weight(hb,7,data_pos-i)+kl_data(p_cnt).weight(hb,8,data_pos-i)*2+kl_data(p_cnt).weight(hb,9,data_pos-i))/4;
            m(7,12) =(kl_data(p_cnt).weight(hb,7,data_pos-i)+kl_data(p_cnt).weight(hb,8,data_pos-i)*3+kl_data(p_cnt).weight(hb,9,data_pos-i)*3+kl_data(p_cnt).weight(hb,10,data_pos-i))/8;

            m(8,1) =(kl_data(p_cnt).weight(hb,43,data_pos-i)+kl_data(p_cnt).weight(hb,44,data_pos-i)*5+kl_data(p_cnt).weight(hb,45,data_pos-i)*10+kl_data(p_cnt).weight(hb,46,data_pos-i)*10+kl_data(p_cnt).weight(hb,47,data_pos-i)*5+kl_data(p_cnt).weight(hb,48,data_pos-i))/32; %
            m(8,2) =(kl_data(p_cnt).weight(hb,44,data_pos-i)+kl_data(p_cnt).weight(hb,45,data_pos-i)*4+kl_data(p_cnt).weight(hb,46,data_pos-i)*6+kl_data(p_cnt).weight(hb,47,data_pos-i)*4+kl_data(p_cnt).weight(hb,48,data_pos-i))/16; %
            m(8,3) =(kl_data(p_cnt).weight(hb,45,data_pos-i)+kl_data(p_cnt).weight(hb,46,data_pos-i)*3+kl_data(p_cnt).weight(hb,47,data_pos-i)*3+kl_data(p_cnt).weight(hb,48,data_pos-i))/8;
            m(8,4) =(kl_data(p_cnt).weight(hb,46,data_pos-i)+kl_data(p_cnt).weight(hb,47,data_pos-i)*2+kl_data(p_cnt).weight(hb,48,data_pos-i))/4;
            m(8,5) =(kl_data(p_cnt).weight(hb,47,data_pos-i)+kl_data(p_cnt).weight(hb,48,data_pos-i))/2;
            m(8,6) =(kl_data(p_cnt).weight(hb,48,data_pos-i));
            m(8,7) = kl_data(p_cnt).weight(hb,38,data_pos-i);
            m(8,8) = kl_data(p_cnt).weight(hb,28,data_pos-i);
            m(8,9) = kl_data(p_cnt).weight(hb,18,data_pos-i);
            m(8,10) = kl_data(p_cnt).weight(hb,8,data_pos-i);
            m(8,11) =(kl_data(p_cnt).weight(hb,8,data_pos-i)+kl_data(p_cnt).weight(hb,9,data_pos-i))/2;
            m(8,12) =(kl_data(p_cnt).weight(hb,8,data_pos-i)+kl_data(p_cnt).weight(hb,9,data_pos-i)*2+kl_data(p_cnt).weight(hb,10,data_pos-i))/4;

            m(9,1) =(kl_data(p_cnt).weight(hb,43,data_pos-i)+kl_data(p_cnt).weight(hb,44,data_pos-i)*6+kl_data(p_cnt).weight(hb,45,data_pos-i)*15+kl_data(p_cnt).weight(hb,46,data_pos-i)*20+kl_data(p_cnt).weight(hb,47,data_pos-i)*15+kl_data(p_cnt).weight(hb,48,data_pos-i)*6+kl_data(p_cnt).weight(hb,49,data_pos-i))/64; %
            m(9,2) =(kl_data(p_cnt).weight(hb,44,data_pos-i)+kl_data(p_cnt).weight(hb,45,data_pos-i)*5+kl_data(p_cnt).weight(hb,46,data_pos-i)*10+kl_data(p_cnt).weight(hb,47,data_pos-i)*10+kl_data(p_cnt).weight(hb,48,data_pos-i)*5+kl_data(p_cnt).weight(hb,49,data_pos-i))/32; %
            m(9,3) =(kl_data(p_cnt).weight(hb,45,data_pos-i)+kl_data(p_cnt).weight(hb,46,data_pos-i)*4+kl_data(p_cnt).weight(hb,47,data_pos-i)*6+kl_data(p_cnt).weight(hb,48,data_pos-i)*4+kl_data(p_cnt).weight(hb,49,data_pos-i))/16; %
            m(9,4) =(kl_data(p_cnt).weight(hb,46,data_pos-i)+kl_data(p_cnt).weight(hb,47,data_pos-i)*3+kl_data(p_cnt).weight(hb,48,data_pos-i)*3+kl_data(p_cnt).weight(hb,49,data_pos-i))/8;
            m(9,5) =(kl_data(p_cnt).weight(hb,47,data_pos-i)+kl_data(p_cnt).weight(hb,48,data_pos-i)*2+kl_data(p_cnt).weight(hb,49,data_pos-i))/4;
            m(9,6) =(kl_data(p_cnt).weight(hb,48,data_pos-i)+kl_data(p_cnt).weight(hb,49,data_pos-i))/2;
            m(9,7) =(kl_data(p_cnt).weight(hb,49,data_pos-i));
            m(9,8) = kl_data(p_cnt).weight(hb,39,data_pos-i);
            m(9,9) = kl_data(p_cnt).weight(hb,29,data_pos-i);
            m(9,10) = kl_data(p_cnt).weight(hb,19,data_pos-i);
            m(9,11) = kl_data(p_cnt).weight(hb,9,data_pos-i);
            m(9,12) =(kl_data(p_cnt).weight(hb,9,data_pos-i)+kl_data(p_cnt).weight(hb,10,data_pos-i))/2;

            m(10,1) =(kl_data(p_cnt).weight(hb,43,data_pos-i)+kl_data(p_cnt).weight(hb,44,data_pos-i)*7+kl_data(p_cnt).weight(hb,45,data_pos-i)*21+kl_data(p_cnt).weight(hb,46,data_pos-i)*35+kl_data(p_cnt).weight(hb,47,data_pos-i)*35+kl_data(p_cnt).weight(hb,48,data_pos-i)*21+kl_data(p_cnt).weight(hb,49,data_pos-i)*7+kl_data(p_cnt).weight(hb,50,data_pos-i))/128; %
            m(10,2) =(kl_data(p_cnt).weight(hb,44,data_pos-i)+kl_data(p_cnt).weight(hb,45,data_pos-i)*6+kl_data(p_cnt).weight(hb,46,data_pos-i)*15+kl_data(p_cnt).weight(hb,47,data_pos-i)*20+kl_data(p_cnt).weight(hb,48,data_pos-i)*15+kl_data(p_cnt).weight(hb,49,data_pos-i)*6+kl_data(p_cnt).weight(hb,50,data_pos-i))/32; %
            m(10,3) =(kl_data(p_cnt).weight(hb,45,data_pos-i)+kl_data(p_cnt).weight(hb,46,data_pos-i)*5+kl_data(p_cnt).weight(hb,47,data_pos-i)*10+kl_data(p_cnt).weight(hb,48,data_pos-i)*10+kl_data(p_cnt).weight(hb,49,data_pos-i)*5+kl_data(p_cnt).weight(hb,50,data_pos-i))/24; %
            m(10,4) =(kl_data(p_cnt).weight(hb,46,data_pos-i)+kl_data(p_cnt).weight(hb,47,data_pos-i)*4+kl_data(p_cnt).weight(hb,48,data_pos-i)*6+kl_data(p_cnt).weight(hb,49,data_pos-i)*4+kl_data(p_cnt).weight(hb,50,data_pos-i))/16; %
            m(10,5) =(kl_data(p_cnt).weight(hb,47,data_pos-i)+kl_data(p_cnt).weight(hb,48,data_pos-i)*3+kl_data(p_cnt).weight(hb,49,data_pos-i)*3+kl_data(p_cnt).weight(hb,50,data_pos-i))/8;
            m(10,6) =(kl_data(p_cnt).weight(hb,48,data_pos-i)+kl_data(p_cnt).weight(hb,49,data_pos-i)*2+kl_data(p_cnt).weight(hb,50,data_pos-i))/4;
            m(10,7) =(kl_data(p_cnt).weight(hb,49,data_pos-i)+kl_data(p_cnt).weight(hb,50,data_pos-i))/2;
            m(10,8) =(kl_data(p_cnt).weight(hb,50,data_pos-i));
            m(10,9) = kl_data(p_cnt).weight(hb,40,data_pos-i);
            m(10,10) = kl_data(p_cnt).weight(hb,30,data_pos-i);
            m(10,11) = kl_data(p_cnt).weight(hb,20,data_pos-i);
            m(10,12) = kl_data(p_cnt).weight(hb,10,data_pos-i);

            m(11,1) =(kl_data(p_cnt).weight(hb,43,data_pos-i)+kl_data(p_cnt).weight(hb,44,data_pos-i)*8+kl_data(p_cnt).weight(hb,45,data_pos-i)*28+kl_data(p_cnt).weight(hb,46,data_pos-i)*56+kl_data(p_cnt).weight(hb,47,data_pos-i)*70+kl_data(p_cnt).weight(hb,48,data_pos-i)*56+kl_data(p_cnt).weight(hb,49,data_pos-i)*28+kl_data(p_cnt).weight(hb,50,data_pos-i)*8+kl_data(p_cnt).weight(hb,51,data_pos-i))/256; %
            m(11,2) =(kl_data(p_cnt).weight(hb,44,data_pos-i)+kl_data(p_cnt).weight(hb,45,data_pos-i)*7+kl_data(p_cnt).weight(hb,46,data_pos-i)*21+kl_data(p_cnt).weight(hb,47,data_pos-i)*35+kl_data(p_cnt).weight(hb,48,data_pos-i)*35+kl_data(p_cnt).weight(hb,49,data_pos-i)*21+kl_data(p_cnt).weight(hb,50,data_pos-i)*7+kl_data(p_cnt).weight(hb,51,data_pos-i))/128; %
            m(11,3) =(kl_data(p_cnt).weight(hb,45,data_pos-i)+kl_data(p_cnt).weight(hb,46,data_pos-i)*6+kl_data(p_cnt).weight(hb,47,data_pos-i)*15+kl_data(p_cnt).weight(hb,48,data_pos-i)*20+kl_data(p_cnt).weight(hb,49,data_pos-i)*15+kl_data(p_cnt).weight(hb,50,data_pos-i)*6+kl_data(p_cnt).weight(hb,51,data_pos-i))/64; %
            m(11,4) =(kl_data(p_cnt).weight(hb,46,data_pos-i)+kl_data(p_cnt).weight(hb,47,data_pos-i)*5+kl_data(p_cnt).weight(hb,48,data_pos-i)*10+kl_data(p_cnt).weight(hb,49,data_pos-i)*10+kl_data(p_cnt).weight(hb,50,data_pos-i)*5+kl_data(p_cnt).weight(hb,51,data_pos-i))/32; %
            m(11,5) =(kl_data(p_cnt).weight(hb,47,data_pos-i)+kl_data(p_cnt).weight(hb,48,data_pos-i)*4+kl_data(p_cnt).weight(hb,49,data_pos-i)*6+kl_data(p_cnt).weight(hb,50,data_pos-i)*4+kl_data(p_cnt).weight(hb,51,data_pos-i))/16; %
            m(11,6) =(kl_data(p_cnt).weight(hb,48,data_pos-i)+kl_data(p_cnt).weight(hb,49,data_pos-i)*3+kl_data(p_cnt).weight(hb,50,data_pos-i)*3+kl_data(p_cnt).weight(hb,51,data_pos-i))/8;
            m(11,7) =(kl_data(p_cnt).weight(hb,49,data_pos-i)+kl_data(p_cnt).weight(hb,50,data_pos-i)*2+kl_data(p_cnt).weight(hb,51,data_pos-i))/4;
            m(11,8) =(kl_data(p_cnt).weight(hb,50,data_pos-i)+kl_data(p_cnt).weight(hb,51-1))/2;
            m(11,9) =(kl_data(p_cnt).weight(hb,51,data_pos-i));
            m(11,10) = kl_data(p_cnt).weight(hb,41,data_pos-i);
            m(11,11) = kl_data(p_cnt).weight(hb,31,data_pos-i);
            m(11,12) = kl_data(p_cnt).weight(hb,21,data_pos-i);

            m(12,1) =(kl_data(p_cnt).weight(hb,43,data_pos-i)+kl_data(p_cnt).weight(hb,44,data_pos-i)*9+kl_data(p_cnt).weight(hb,45,data_pos-i)*36+kl_data(p_cnt).weight(hb,46,data_pos-i)*84+kl_data(p_cnt).weight(hb,47,data_pos-i)*126+kl_data(p_cnt).weight(hb,48,data_pos-i)*126+kl_data(p_cnt).weight(hb,49,data_pos-i)*84+kl_data(p_cnt).weight(hb,50,data_pos-i)*36+kl_data(p_cnt).weight(hb,51,data_pos-i)*9+kl_data(p_cnt).weight(hb,52,data_pos-i))/512; %
            m(12,2) =(kl_data(p_cnt).weight(hb,44,data_pos-i)+kl_data(p_cnt).weight(hb,45,data_pos-i)*8+kl_data(p_cnt).weight(hb,46,data_pos-i)*28+kl_data(p_cnt).weight(hb,47,data_pos-i)*56+kl_data(p_cnt).weight(hb,48,data_pos-i)*70+kl_data(p_cnt).weight(hb,49,data_pos-i)*56+kl_data(p_cnt).weight(hb,50,data_pos-i)*28+kl_data(p_cnt).weight(hb,51,data_pos-i)*8+kl_data(p_cnt).weight(hb,52,data_pos-i))/256; %
            m(12,3) =(kl_data(p_cnt).weight(hb,45,data_pos-i)+kl_data(p_cnt).weight(hb,46,data_pos-i)*7+kl_data(p_cnt).weight(hb,47,data_pos-i)*21+kl_data(p_cnt).weight(hb,48,data_pos-i)*35+kl_data(p_cnt).weight(hb,49,data_pos-i)*35+kl_data(p_cnt).weight(hb,50,data_pos-i)*21+kl_data(p_cnt).weight(hb,51,data_pos-i)*7+kl_data(p_cnt).weight(hb,52,data_pos-i))/128; %
            m(12,4) =(kl_data(p_cnt).weight(hb,46,data_pos-i)+kl_data(p_cnt).weight(hb,47,data_pos-i)*6+kl_data(p_cnt).weight(hb,48,data_pos-i)*15+kl_data(p_cnt).weight(hb,49,data_pos-i)*20+kl_data(p_cnt).weight(hb,50,data_pos-i)*15+kl_data(p_cnt).weight(hb,51,data_pos-i)*6+kl_data(p_cnt).weight(hb,52,data_pos-i))/64; %
            m(12,5) =(kl_data(p_cnt).weight(hb,47,data_pos-i)+kl_data(p_cnt).weight(hb,48,data_pos-i)*5+kl_data(p_cnt).weight(hb,49,data_pos-i)*10+kl_data(p_cnt).weight(hb,50,data_pos-i)*10+kl_data(p_cnt).weight(hb,51,data_pos-i)*5+kl_data(p_cnt).weight(hb,52,data_pos-i))/32; %
            m(12,6) =(kl_data(p_cnt).weight(hb,48,data_pos-i)+kl_data(p_cnt).weight(hb,49,data_pos-i)*4+kl_data(p_cnt).weight(hb,50,data_pos-i)*6+kl_data(p_cnt).weight(hb,51,data_pos-i)*4+kl_data(p_cnt).weight(hb,52,data_pos-i))/16; %
            m(12,7) =(kl_data(p_cnt).weight(hb,49,data_pos-i)+kl_data(p_cnt).weight(hb,50,data_pos-i)*3+kl_data(p_cnt).weight(hb,51,data_pos-i)*3+kl_data(p_cnt).weight(hb,52,data_pos-i))/8;
            m(12,8) =(kl_data(p_cnt).weight(hb,50,data_pos-i)+kl_data(p_cnt).weight(hb,51,data_pos-i)*2+kl_data(p_cnt).weight(hb,52,data_pos-i))/4;
            m(12,9) =(kl_data(p_cnt).weight(hb,51,data_pos-i)+kl_data(p_cnt).weight(hb,52,data_pos-i))/2;
            m(12,10) =(kl_data(p_cnt).weight(hb,52,data_pos-i));
            m(12,11) = kl_data(p_cnt).weight(hb,42,data_pos-i);
            m(12,12) =(kl_data(p_cnt).weight(hb,21,data_pos-i)+kl_data(p_cnt).weight(hb,42,data_pos-i))/2;

            pol = interp2(x,y,m,xi,yi,'spline');

            for a=1:size(pol,1);
                for b=1:size(pol,2);
                    if a<11  & b<(-a+11);pol(a,b)=NaN;end;  % left
                    if a<101 & b>(a+21);pol(a,b)=NaN;end;   % upper
                    if a>21  & b<(a-21);pol(a,b)=NaN;end;   % under
                    if a>104 & b>(-a+215);pol(a,b)=NaN;end; % right
                end;
            end;
            %*******It returns and draws  *******
            set(0,'CurrentFigure',figure_h);
            axes('Position',map(i).w);
            kl_map_h(p_cnt).map_plot(hb,i,1) = pcolor(pol);

            hold on;
            axis square;
            axis ij;
            axis off;
            shading interp;
            caxis([topo_range(1) topo_range(2)]);
            if para_p.angle(p_cnt).angle1==1;
                view(-45,90);
            elseif para_p.angle(p_cnt).angle1==2;
                view(45,90);
            elseif para_p.angle(p_cnt).angle1==3;
                view(135,90);
            elseif para_p.angle(p_cnt).angle1==4;
                view(225,90);
            end;
            if para_p.angle(p_cnt).angle1==1;
                if hb == 1;
                    if i==1 text(50,15,'Topo(C1)');end;
                    if i==2 text(50,15,'Topo(C2)');end;
                    if i==3 text(50,15,'Topo(C3)');end;
                    if i==4 text(50,15,'Topo(C4)');end;
                    if i==5 text(50,15,'Topo(C5)');end;
                    if i==6 text(50,15,'Topo(C6)');end;
                end;
            elseif para_p.angle(p_cnt).angle1==2;
                if hb == 1;
                    if i==1 text(-15,10,'Topo(C1)');end;
                    if i==2 text(-15,10,'Topo(C2)');end;
                    if i==3 text(-15,10,'Topo(C3)');end;
                    if i==4 text(-15,10,'Topo(C4)');end;
                    if i==5 text(-15,10,'Topo(C5)');end;
                    if i==6 text(-15,10,'Topo(C6)');end;
                end;
            elseif para_p.angle(p_cnt).angle1==3;
                if hb == 1;
                    if i==1 text(55,90,'Topo(C1)');end;
                    if i==2 text(55,90,'Topo(C2)');end;
                    if i==3 text(55,90,'Topo(C3)');end;
                    if i==4 text(55,90,'Topo(C4)');end;
                    if i==5 text(55,90,'Topo(C5)');end;
                    if i==6 text(55,90,'Topo(C6)');end;
                end;
            elseif para_p.angle(p_cnt).angle1==4;
                if hb == 1;
                    if i==1 text(125,100,'Topo(C1)');end;
                    if i==2 text(125,100,'Topo(C2)');end;
                    if i==3 text(125,100,'Topo(C3)');end;
                    if i==4 text(125,100,'Topo(C4)');end;
                    if i==5 text(125,100,'Topo(C5)');end;
                    if i==6 text(125,100,'Topo(C6)');end;
                end;
            end;
            if hb == 1;
                plot3(15.0,-5.0,0,'ok','MarkerSize',3,'MarkerFaceColor','r');       % left up
                plot3(-5.0,15.0,0,'o','MarkerSize',1,'Color',[0.8 0.8 0.8]);        % left down
                plot3(95.0,115.0,0,'o','MarkerSize',1,'Color',[0.8 0.8 0.8]);       % right down
                plot3(153.0,60.0,0,'o','MarkerSize',1,'Color',[0.8 0.8 0.8]);       % right up
            end;
            if i==6;                      % 5->6
                buff=colorbar;
                set(buff,'Position',[0.89 0.1 0.03 0.4]);
            end;
            zoom(3);
            hold off;
        end;
        if hb == 1;
            if kl_map_h(p_cnt).chk_val == 1;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','on');
            else;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','off');
            end;
        end;
        if hb == 2;
            if kl_map_h(p_cnt).chk_val == 2;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','on');
            else;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','off');
            end;
        end;
        if hb == 3;
            if kl_map_h(p_cnt).chk_val == 3;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','on');
            else;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','off');
            end;
        end;
        if hb == 4;
            if kl_map_h(p_cnt).chk_val == 4;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','on');
            else;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','off');
            end;
        end;
    end;
end;

%***** 3x10 Mode *****
if info(p_cnt).probe_mode == 5;
    topo_range(1)= -0.5;
    topo_range(2)= 0.5;
    [x,y]     = meshgrid(1:1:11);
    [xi,yi]   = meshgrid(1:0.1:11);
    data_pos    = length(kl_data(p_cnt).weight)+1;

    for hb=1:3;
        %************ Topo View **************
        for i=1:6;                 % 5->6   m(1,1) =(hb_map(i,11)+hb_map(i,32))/2;

            m(1,1) = (kl_data(p_cnt).weight(hb,10,data_pos-i)+kl_data(p_cnt).weight(hb,29,data_pos-i))/2;
            m(1,2) = kl_data(p_cnt).weight(hb,10,data_pos-i);
            m(1,3) = kl_data(p_cnt).weight(hb,1,data_pos-i);
            m(1,4) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i))/2;
            m(1,5) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i)*2+kl_data(p_cnt).weight(hb,3,data_pos-i))/4;
            m(1,6) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i)*3+kl_data(p_cnt).weight(hb,3,data_pos-i)*3+kl_data(p_cnt).weight(hb,4,data_pos-i))/8;
            m(1,7) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i)*4+kl_data(p_cnt).weight(hb,3,data_pos-i)*6+kl_data(p_cnt).weight(hb,4,data_pos-i)*4+kl_data(p_cnt).weight(hb,5,data_pos-i))/16; %
            m(1,8) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i)*5+kl_data(p_cnt).weight(hb,3,data_pos-i)*10+kl_data(p_cnt).weight(hb,4,data_pos-i)*10+kl_data(p_cnt).weight(hb,5,data_pos-i)*5+kl_data(p_cnt).weight(hb,6,data_pos-i))/32; %
            m(1,9) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i)*6+kl_data(p_cnt).weight(hb,3,data_pos-i)*15+kl_data(p_cnt).weight(hb,4,data_pos-i)*20+kl_data(p_cnt).weight(hb,5,data_pos-i)*15+kl_data(p_cnt).weight(hb,6,data_pos-i)*6+kl_data(p_cnt).weight(hb,7,data_pos-i))/64; %
            m(1,10) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i)*7+kl_data(p_cnt).weight(hb,3,data_pos-i)*21+kl_data(p_cnt).weight(hb,4,data_pos-i)*35+kl_data(p_cnt).weight(hb,5,data_pos-i)*35+kl_data(p_cnt).weight(hb,6,data_pos-i)*21+kl_data(p_cnt).weight(hb,7,data_pos-i)*7+kl_data(p_cnt).weight(hb,8,data_pos-i))/128; %
            m(1,11) =(kl_data(p_cnt).weight(hb,1,data_pos-i)+kl_data(p_cnt).weight(hb,2,data_pos-i)*8+kl_data(p_cnt).weight(hb,3,data_pos-i)*28+kl_data(p_cnt).weight(hb,4,data_pos-i)*56+kl_data(p_cnt).weight(hb,5,data_pos-i)*70+kl_data(p_cnt).weight(hb,6,data_pos-i)*56+kl_data(p_cnt).weight(hb,7,data_pos-i)*28+kl_data(p_cnt).weight(hb,8,data_pos-i)*8+kl_data(p_cnt).weight(hb,9,data_pos-i))/256; %

            m(2,1) =(kl_data(p_cnt).weight(hb,29,data_pos-i));
            m(2,2) = kl_data(p_cnt).weight(hb,20,data_pos-i);
            m(2,3) = kl_data(p_cnt).weight(hb,11,data_pos-i);
            m(2,4) = kl_data(p_cnt).weight(hb,2,data_pos-i);
            m(2,5) =(kl_data(p_cnt).weight(hb,2,data_pos-i)+kl_data(p_cnt).weight(hb,3,data_pos-i))/2;
            m(2,6) =(kl_data(p_cnt).weight(hb,2,data_pos-i)+kl_data(p_cnt).weight(hb,3,data_pos-i)*2+kl_data(p_cnt).weight(hb,4,data_pos-i))/4;
            m(2,7) =(kl_data(p_cnt).weight(hb,2,data_pos-i)+kl_data(p_cnt).weight(hb,3,data_pos-i)*3+kl_data(p_cnt).weight(hb,4,data_pos-i)*3+kl_data(p_cnt).weight(hb,5,data_pos-i))/8;
            m(2,8) =(kl_data(p_cnt).weight(hb,2,data_pos-i)+kl_data(p_cnt).weight(hb,3,data_pos-i)*4+kl_data(p_cnt).weight(hb,4,data_pos-i)*6+kl_data(p_cnt).weight(hb,5,data_pos-i)*4+kl_data(p_cnt).weight(hb,6,data_pos-i))/16; %
            m(2,9) =(kl_data(p_cnt).weight(hb,2,data_pos-i)+kl_data(p_cnt).weight(hb,3,data_pos-i)*5+kl_data(p_cnt).weight(hb,4,data_pos-i)*10+kl_data(p_cnt).weight(hb,5,data_pos-i)*10+kl_data(p_cnt).weight(hb,6,data_pos-i)*5+kl_data(p_cnt).weight(hb,7,data_pos-i))/32; %
            m(2,10) =(kl_data(p_cnt).weight(hb,2,data_pos-i)+kl_data(p_cnt).weight(hb,3,data_pos-i)*6+kl_data(p_cnt).weight(hb,4,data_pos-i)*15+kl_data(p_cnt).weight(hb,5,data_pos-i)*20+kl_data(p_cnt).weight(hb,6,data_pos-i)*15+kl_data(p_cnt).weight(hb,7,data_pos-i)*6+kl_data(p_cnt).weight(hb,8,data_pos-i))/64; %
            m(2,11) =(kl_data(p_cnt).weight(hb,2,data_pos-i)+kl_data(p_cnt).weight(hb,3,data_pos-i)*7+kl_data(p_cnt).weight(hb,4,data_pos-i)*21+kl_data(p_cnt).weight(hb,5,data_pos-i)*35+kl_data(p_cnt).weight(hb,6,data_pos-i)*35+kl_data(p_cnt).weight(hb,7,data_pos-i)*21+kl_data(p_cnt).weight(hb,8,data_pos-i)*7+kl_data(p_cnt).weight(hb,9,data_pos-i))/128; %

            m(3,1) =(kl_data(p_cnt).weight(hb,39,data_pos-i));
            m(3,2) = kl_data(p_cnt).weight(hb,30,data_pos-i);
            m(3,3) = kl_data(p_cnt).weight(hb,21,data_pos-i);
            m(3,4) = kl_data(p_cnt).weight(hb,12,data_pos-i);
            m(3,5) = kl_data(p_cnt).weight(hb,3,data_pos-i);
            m(3,6) =(kl_data(p_cnt).weight(hb,3,data_pos-i)+kl_data(p_cnt).weight(hb,4,data_pos-i))/2;
            m(3,7) =(kl_data(p_cnt).weight(hb,3,data_pos-i)+kl_data(p_cnt).weight(hb,4,data_pos-i)*2+kl_data(p_cnt).weight(hb,5,data_pos-i))/4;
            m(3,8) =(kl_data(p_cnt).weight(hb,3,data_pos-i)+kl_data(p_cnt).weight(hb,4,data_pos-i)*3+kl_data(p_cnt).weight(hb,5,data_pos-i)*3+kl_data(p_cnt).weight(hb,6,data_pos-i))/8;
            m(3,9) =(kl_data(p_cnt).weight(hb,3,data_pos-i)+kl_data(p_cnt).weight(hb,4,data_pos-i)*4+kl_data(p_cnt).weight(hb,5,data_pos-i)*6+kl_data(p_cnt).weight(hb,6,data_pos-i)*4+kl_data(p_cnt).weight(hb,7,data_pos-i))/16; %
            m(3,10) =(kl_data(p_cnt).weight(hb,3,data_pos-i)+kl_data(p_cnt).weight(hb,4,data_pos-i)*5+kl_data(p_cnt).weight(hb,5,data_pos-i)*10+kl_data(p_cnt).weight(hb,6,data_pos-i)*10+kl_data(p_cnt).weight(hb,7,data_pos-i)*5+kl_data(p_cnt).weight(hb,8,data_pos-i))/32; %
            m(3,11) =(kl_data(p_cnt).weight(hb,3,data_pos-i)+kl_data(p_cnt).weight(hb,4,data_pos-i)*6+kl_data(p_cnt).weight(hb,5,data_pos-i)*15+kl_data(p_cnt).weight(hb,6,data_pos-i)*20+kl_data(p_cnt).weight(hb,7,data_pos-i)*15+kl_data(p_cnt).weight(hb,8,data_pos-i)*6+kl_data(p_cnt).weight(hb,9,data_pos-i))/64; %

            m(4,1) =(kl_data(p_cnt).weight(hb,39,data_pos-i)+kl_data(p_cnt).weight(hb,40,data_pos-i))/2;
            m(4,2) =(kl_data(p_cnt).weight(hb,40,data_pos-i));
            m(4,3) = kl_data(p_cnt).weight(hb,31,data_pos-i);
            m(4,4) = kl_data(p_cnt).weight(hb,22,data_pos-i);
            m(4,5) = kl_data(p_cnt).weight(hb,13,data_pos-i);
            m(4,6) = kl_data(p_cnt).weight(hb,4,data_pos-i);
            m(4,7) =(kl_data(p_cnt).weight(hb,4,data_pos-i)+kl_data(p_cnt).weight(hb,5,data_pos-i))/2;
            m(4,8) =(kl_data(p_cnt).weight(hb,4,data_pos-i)+kl_data(p_cnt).weight(hb,5,data_pos-i)*2+kl_data(p_cnt).weight(hb,6,data_pos-i))/4;
            m(4,9) =(kl_data(p_cnt).weight(hb,4,data_pos-i)+kl_data(p_cnt).weight(hb,5,data_pos-i)*3+kl_data(p_cnt).weight(hb,6,data_pos-i)*3+kl_data(p_cnt).weight(hb,7,data_pos-i))/8;
            m(4,10) =(kl_data(p_cnt).weight(hb,4,data_pos-i)+kl_data(p_cnt).weight(hb,5,data_pos-i)*4+kl_data(p_cnt).weight(hb,6,data_pos-i)*6+kl_data(p_cnt).weight(hb,7,data_pos-i)*4+kl_data(p_cnt).weight(hb,8,data_pos-i))/16; %
            m(4,11) =(kl_data(p_cnt).weight(hb,4,data_pos-i)+kl_data(p_cnt).weight(hb,5,data_pos-i)*5+kl_data(p_cnt).weight(hb,6,data_pos-i)*10+kl_data(p_cnt).weight(hb,7,data_pos-i)*10+kl_data(p_cnt).weight(hb,8,data_pos-i)*5+kl_data(p_cnt).weight(hb,9,data_pos-i))/32;

            m(5,1) =(kl_data(p_cnt).weight(hb,39,data_pos-i)+kl_data(p_cnt).weight(hb,40,data_pos-i)*2+kl_data(p_cnt).weight(hb,41,data_pos-i))/4;
            m(5,2) =(kl_data(p_cnt).weight(hb,40,data_pos-i)+kl_data(p_cnt).weight(hb,41,data_pos-i))/2;
            m(5,3) =(kl_data(p_cnt).weight(hb,41,data_pos-i));
            m(5,4) = kl_data(p_cnt).weight(hb,32,data_pos-i);
            m(5,5) = kl_data(p_cnt).weight(hb,23,data_pos-i);
            m(5,6) = kl_data(p_cnt).weight(hb,14,data_pos-i);
            m(5,7) = kl_data(p_cnt).weight(hb,5,data_pos-i);
            m(5,8) =(kl_data(p_cnt).weight(hb,5,data_pos-i)+kl_data(p_cnt).weight(hb,6,data_pos-i))/2;
            m(5,9) =(kl_data(p_cnt).weight(hb,5,data_pos-i)+kl_data(p_cnt).weight(hb,6,data_pos-i)*2+kl_data(p_cnt).weight(hb,7,data_pos-i))/4;
            m(5,10) =(kl_data(p_cnt).weight(hb,5,data_pos-i)+kl_data(p_cnt).weight(hb,6,data_pos-i)*3+kl_data(p_cnt).weight(hb,7,data_pos-i)*3+kl_data(p_cnt).weight(hb,8,data_pos-i))/8;
            m(5,11) =(kl_data(p_cnt).weight(hb,5,data_pos-i)+kl_data(p_cnt).weight(hb,6,data_pos-i)*4+kl_data(p_cnt).weight(hb,7,data_pos-i)*6+kl_data(p_cnt).weight(hb,8,data_pos-i)*4+kl_data(p_cnt).weight(hb,9,data_pos-i))/16; %

            m(6,1) =(kl_data(p_cnt).weight(hb,39,data_pos-i)+kl_data(p_cnt).weight(hb,40,data_pos-i)*3+kl_data(p_cnt).weight(hb,41,data_pos-i)*3+kl_data(p_cnt).weight(hb,42,data_pos-i))/8;
            m(6,2) =(kl_data(p_cnt).weight(hb,40,data_pos-i)+kl_data(p_cnt).weight(hb,41,data_pos-i)*2+kl_data(p_cnt).weight(hb,42,data_pos-i))/4;
            m(6,3) =(kl_data(p_cnt).weight(hb,41,data_pos-i)+kl_data(p_cnt).weight(hb,42,data_pos-i))/2;
            m(6,4) =(kl_data(p_cnt).weight(hb,42,data_pos-i));
            m(6,5) = kl_data(p_cnt).weight(hb,33,data_pos-i);
            m(6,6) = kl_data(p_cnt).weight(hb,24,data_pos-i);
            m(6,7) = kl_data(p_cnt).weight(hb,15,data_pos-i);
            m(6,8) = kl_data(p_cnt).weight(hb,6,data_pos-i);
            m(6,9) =(kl_data(p_cnt).weight(hb,6,data_pos-i)+kl_data(p_cnt).weight(hb,7,data_pos-i))/2;
            m(6,10) =(kl_data(p_cnt).weight(hb,6,data_pos-i)+kl_data(p_cnt).weight(hb,7,data_pos-i)*2+kl_data(p_cnt).weight(hb,8,data_pos-i))/4;
            m(6,11) =(kl_data(p_cnt).weight(hb,6,data_pos-i)+kl_data(p_cnt).weight(hb,7,data_pos-i)*3+kl_data(p_cnt).weight(hb,8,data_pos-i)*3+kl_data(p_cnt).weight(hb,9,data_pos-i))/8;

            m(7,1) =(kl_data(p_cnt).weight(hb,39,data_pos-i)+kl_data(p_cnt).weight(hb,40,data_pos-i)*4+kl_data(p_cnt).weight(hb,41,data_pos-i)*6+kl_data(p_cnt).weight(hb,42,data_pos-i)*4+kl_data(p_cnt).weight(hb,43,data_pos-i))/16; %
            m(7,2) =(kl_data(p_cnt).weight(hb,40,data_pos-i)+kl_data(p_cnt).weight(hb,41,data_pos-i)*3+kl_data(p_cnt).weight(hb,42,data_pos-i)*3+kl_data(p_cnt).weight(hb,43,data_pos-i))/8;
            m(7,3) =(kl_data(p_cnt).weight(hb,41,data_pos-i)+kl_data(p_cnt).weight(hb,42,data_pos-i)*2+kl_data(p_cnt).weight(hb,43,data_pos-i))/4;
            m(7,4) =(kl_data(p_cnt).weight(hb,42,data_pos-i)+kl_data(p_cnt).weight(hb,43,data_pos-i))/2;
            m(7,5) =(kl_data(p_cnt).weight(hb,43,data_pos-i));
            m(7,6) = kl_data(p_cnt).weight(hb,34,data_pos-i);
            m(7,7) = kl_data(p_cnt).weight(hb,25,data_pos-i);
            m(7,8) = kl_data(p_cnt).weight(hb,16,data_pos-i);
            m(7,9) = kl_data(p_cnt).weight(hb,7,data_pos-i);
            m(7,10) =(kl_data(p_cnt).weight(hb,7,data_pos-i)+kl_data(p_cnt).weight(hb,8,data_pos-i))/2;
            m(7,11) =(kl_data(p_cnt).weight(hb,7,data_pos-i)+kl_data(p_cnt).weight(hb,8,data_pos-i)*2+kl_data(p_cnt).weight(hb,9,data_pos-i))/4;

            m(8,1) =(kl_data(p_cnt).weight(hb,39,data_pos-i)+kl_data(p_cnt).weight(hb,40,data_pos-i)*5+kl_data(p_cnt).weight(hb,41,data_pos-i)*10+kl_data(p_cnt).weight(hb,42,data_pos-i)*10+kl_data(p_cnt).weight(hb,43,data_pos-i)*5+kl_data(p_cnt).weight(hb,44,data_pos-i))/32; %
            m(8,2) =(kl_data(p_cnt).weight(hb,40,data_pos-i)+kl_data(p_cnt).weight(hb,41,data_pos-i)*4+kl_data(p_cnt).weight(hb,42,data_pos-i)*6+kl_data(p_cnt).weight(hb,43,data_pos-i)*4+kl_data(p_cnt).weight(hb,44,data_pos-i))/16; %
            m(8,3) =(kl_data(p_cnt).weight(hb,41,data_pos-i)+kl_data(p_cnt).weight(hb,42,data_pos-i)*3+kl_data(p_cnt).weight(hb,43,data_pos-i)*3+kl_data(p_cnt).weight(hb,44,data_pos-i))/8;
            m(8,4) =(kl_data(p_cnt).weight(hb,42,data_pos-i)+kl_data(p_cnt).weight(hb,43,data_pos-i)*2+kl_data(p_cnt).weight(hb,44,data_pos-i))/4;
            m(8,5) =(kl_data(p_cnt).weight(hb,43,data_pos-i)+kl_data(p_cnt).weight(hb,44,data_pos-i))/2;
            m(8,6) =(kl_data(p_cnt).weight(hb,44,data_pos-i));
            m(8,7) = kl_data(p_cnt).weight(hb,35,data_pos-i);
            m(8,8) = kl_data(p_cnt).weight(hb,26,data_pos-i);
            m(8,9) = kl_data(p_cnt).weight(hb,17,data_pos-i);
            m(8,10) = kl_data(p_cnt).weight(hb,8,data_pos-i);
            m(8,11) =(kl_data(p_cnt).weight(hb,8,data_pos-i)+kl_data(p_cnt).weight(hb,9,data_pos-i))/2;

            m(9,1) =(kl_data(p_cnt).weight(hb,39,data_pos-i)+kl_data(p_cnt).weight(hb,40,data_pos-i)*6+kl_data(p_cnt).weight(hb,41,data_pos-i)*15+kl_data(p_cnt).weight(hb,42,data_pos-i)*20+kl_data(p_cnt).weight(hb,43,data_pos-i)*15+kl_data(p_cnt).weight(hb,44,data_pos-i)*6+kl_data(p_cnt).weight(hb,45,data_pos-i))/64; %
            m(9,2) =(kl_data(p_cnt).weight(hb,40,data_pos-i)+kl_data(p_cnt).weight(hb,41,data_pos-i)*5+kl_data(p_cnt).weight(hb,42,data_pos-i)*10+kl_data(p_cnt).weight(hb,43,data_pos-i)*10+kl_data(p_cnt).weight(hb,44,data_pos-i)*5+kl_data(p_cnt).weight(hb,45,data_pos-i))/32; %
            m(9,3) =(kl_data(p_cnt).weight(hb,41,data_pos-i)+kl_data(p_cnt).weight(hb,42,data_pos-i)*4+kl_data(p_cnt).weight(hb,43,data_pos-i)*6+kl_data(p_cnt).weight(hb,44,data_pos-i)*4+kl_data(p_cnt).weight(hb,45,data_pos-i))/16; %
            m(9,4) =(kl_data(p_cnt).weight(hb,42,data_pos-i)+kl_data(p_cnt).weight(hb,43,data_pos-i)*3+kl_data(p_cnt).weight(hb,44,data_pos-i)*3+kl_data(p_cnt).weight(hb,45,data_pos-i))/8;
            m(9,5) =(kl_data(p_cnt).weight(hb,43,data_pos-i)+kl_data(p_cnt).weight(hb,44,data_pos-i)*2+kl_data(p_cnt).weight(hb,45,data_pos-i))/4;
            m(9,6) =(kl_data(p_cnt).weight(hb,44,data_pos-i)+kl_data(p_cnt).weight(hb,45,data_pos-i))/2;
            m(9,7) =(kl_data(p_cnt).weight(hb,45,data_pos-i));
            m(9,8) = kl_data(p_cnt).weight(hb,36,data_pos-i);
            m(9,9) = kl_data(p_cnt).weight(hb,27,data_pos-i);
            m(9,10) = kl_data(p_cnt).weight(hb,18,data_pos-i);
            m(9,11) = kl_data(p_cnt).weight(hb,9,data_pos-i);

            m(10,1) =(kl_data(p_cnt).weight(hb,39,data_pos-i)+kl_data(p_cnt).weight(hb,40,data_pos-i)*7+kl_data(p_cnt).weight(hb,41,data_pos-i)*21+kl_data(p_cnt).weight(hb,42,data_pos-i)*35+kl_data(p_cnt).weight(hb,43,data_pos-i)*35+kl_data(p_cnt).weight(hb,44,data_pos-i)*21+kl_data(p_cnt).weight(hb,45,data_pos-i)*7+kl_data(p_cnt).weight(hb,46,data_pos-i))/128; %
            m(10,2) =(kl_data(p_cnt).weight(hb,40,data_pos-i)+kl_data(p_cnt).weight(hb,41,data_pos-i)*6+kl_data(p_cnt).weight(hb,42,data_pos-i)*15+kl_data(p_cnt).weight(hb,43,data_pos-i)*20+kl_data(p_cnt).weight(hb,44,data_pos-i)*15+kl_data(p_cnt).weight(hb,45,data_pos-i)*6+kl_data(p_cnt).weight(hb,46,data_pos-i))/32; %
            m(10,3) =(kl_data(p_cnt).weight(hb,41,data_pos-i)+kl_data(p_cnt).weight(hb,42,data_pos-i)*5+kl_data(p_cnt).weight(hb,43,data_pos-i)*10+kl_data(p_cnt).weight(hb,44,data_pos-i)*10+kl_data(p_cnt).weight(hb,45,data_pos-i)*5+kl_data(p_cnt).weight(hb,46,data_pos-i))/24; %
            m(10,4) =(kl_data(p_cnt).weight(hb,42,data_pos-i)+kl_data(p_cnt).weight(hb,43,data_pos-i)*4+kl_data(p_cnt).weight(hb,44,data_pos-i)*6+kl_data(p_cnt).weight(hb,45,data_pos-i)*4+kl_data(p_cnt).weight(hb,46,data_pos-i))/16; %
            m(10,5) =(kl_data(p_cnt).weight(hb,43,data_pos-i)+kl_data(p_cnt).weight(hb,44,data_pos-i)*3+kl_data(p_cnt).weight(hb,45,data_pos-i)*3+kl_data(p_cnt).weight(hb,46,data_pos-i))/8;
            m(10,6) =(kl_data(p_cnt).weight(hb,44,data_pos-i)+kl_data(p_cnt).weight(hb,45,data_pos-i)*2+kl_data(p_cnt).weight(hb,46,data_pos-i))/4;
            m(10,7) =(kl_data(p_cnt).weight(hb,45,data_pos-i)+kl_data(p_cnt).weight(hb,46,data_pos-i))/2;
            m(10,8) =(kl_data(p_cnt).weight(hb,46,data_pos-i));
            m(10,9) = kl_data(p_cnt).weight(hb,37,data_pos-i);
            m(10,10) = kl_data(p_cnt).weight(hb,28,data_pos-i);
            m(10,11) = kl_data(p_cnt).weight(hb,19,data_pos-i);

            m(11,1) =(kl_data(p_cnt).weight(hb,39,data_pos-i)+kl_data(p_cnt).weight(hb,40,data_pos-i)*8+kl_data(p_cnt).weight(hb,41,data_pos-i)*28+kl_data(p_cnt).weight(hb,42,data_pos-i)*56+kl_data(p_cnt).weight(hb,43,data_pos-i)*70+kl_data(p_cnt).weight(hb,44,data_pos-i)*56+kl_data(p_cnt).weight(hb,45,data_pos-i)*28+kl_data(p_cnt).weight(hb,46,data_pos-i)*8+kl_data(p_cnt).weight(hb,47,data_pos-i))/256; %
            m(11,2) =(kl_data(p_cnt).weight(hb,40,data_pos-i)+kl_data(p_cnt).weight(hb,41,data_pos-i)*7+kl_data(p_cnt).weight(hb,42,data_pos-i)*21+kl_data(p_cnt).weight(hb,43,data_pos-i)*35+kl_data(p_cnt).weight(hb,44,data_pos-i)*35+kl_data(p_cnt).weight(hb,45,data_pos-i)*21+kl_data(p_cnt).weight(hb,46,data_pos-i)*7+kl_data(p_cnt).weight(hb,47,data_pos-i))/128; %
            m(11,3) =(kl_data(p_cnt).weight(hb,41,data_pos-i)+kl_data(p_cnt).weight(hb,42,data_pos-i)*6+kl_data(p_cnt).weight(hb,43,data_pos-i)*15+kl_data(p_cnt).weight(hb,44,data_pos-i)*20+kl_data(p_cnt).weight(hb,45,data_pos-i)*15+kl_data(p_cnt).weight(hb,46,data_pos-i)*6+kl_data(p_cnt).weight(hb,47,data_pos-i))/64; %
            m(11,4) =(kl_data(p_cnt).weight(hb,42,data_pos-i)+kl_data(p_cnt).weight(hb,43,data_pos-i)*5+kl_data(p_cnt).weight(hb,44,data_pos-i)*10+kl_data(p_cnt).weight(hb,45,data_pos-i)*10+kl_data(p_cnt).weight(hb,46,data_pos-i)*5+kl_data(p_cnt).weight(hb,47,data_pos-i))/32; %
            m(11,5) =(kl_data(p_cnt).weight(hb,43,data_pos-i)+kl_data(p_cnt).weight(hb,44,data_pos-i)*4+kl_data(p_cnt).weight(hb,45,data_pos-i)*6+kl_data(p_cnt).weight(hb,46,data_pos-i)*4+kl_data(p_cnt).weight(hb,47,data_pos-i))/16; %
            m(11,6) =(kl_data(p_cnt).weight(hb,44,data_pos-i)+kl_data(p_cnt).weight(hb,45,data_pos-i)*3+kl_data(p_cnt).weight(hb,46,data_pos-i)*3+kl_data(p_cnt).weight(hb,47,data_pos-i))/8;
            m(11,7) =(kl_data(p_cnt).weight(hb,45,data_pos-i)+kl_data(p_cnt).weight(hb,46,data_pos-i)*2+kl_data(p_cnt).weight(hb,47,data_pos-i))/4;
            m(11,8) =(kl_data(p_cnt).weight(hb,46,data_pos-i)+kl_data(p_cnt).weight(hb,47,48-1))/2;
            m(11,9) =(kl_data(p_cnt).weight(hb,47,data_pos-i));
            m(11,10) = kl_data(p_cnt).weight(hb,38,data_pos-i);
            m(11,11) =(kl_data(p_cnt).weight(hb,38,data_pos-i)+kl_data(p_cnt).weight(hb,19,data_pos-i))/2;

            pol = interp2(x,y,m,xi,yi,'spline');

            for a=1:size(pol,1);
                for b=1:size(pol,2);
                    if a<11  & b<(-a+11);pol(a,b)=NaN;end;  % left
                    if a<101 & b>(a+21);pol(a,b)=NaN;end;   % upper
                    if a>21  & b<(a-21);pol(a,b)=NaN;end;   % under
                    if a>90 & b>(-a+195);pol(a,b)=NaN;end; % right
                end;
            end;
            %*******It returns and draws  *******
            set(0,'CurrentFigure',figure_h);
            axes('Position',map(i).w);
            kl_map_h(p_cnt).map_plot(hb,i,1) = pcolor(pol);
            hold on;
            axis square;
            axis ij;
            axis off;
            shading interp;
            caxis([topo_range(1) topo_range(2)]);

            if para_p.angle(p_cnt).angle1==1;
                view(-45,90);
            elseif para_p.angle(p_cnt).angle1==2;
                view(45,90);
            elseif para_p.angle(p_cnt).angle1==3;
                view(135,90);
            elseif para_p.angle(p_cnt).angle1==4;
                view(225,90);
            end;
            if hb == 1;
                if para_p.angle(p_cnt).angle1==1;
                    if i==1 text(50,15,'Topo(C1)');end;
                    if i==2 text(50,15,'Topo(C2)');end;
                    if i==3 text(50,15,'Topo(C3)');end;
                    if i==4 text(50,15,'Topo(C4)');end;
                    if i==5 text(50,15,'Topo(C5)');end;
                    if i==6 text(50,15,'Topo(C6)');end;
                elseif para_p.angle(p_cnt).angle1==2;
                    if i==1 text(-15,10,'Topo(C1)');end;
                    if i==2 text(-15,10,'Topo(C2)');end;
                    if i==3 text(-15,10,'Topo(C3)');end;
                    if i==4 text(-15,10,'Topo(C4)');end;
                    if i==5 text(-15,10,'Topo(C5)');end;
                    if i==6 text(-15,10,'Topo(C6)');end;
                elseif para_p.angle(p_cnt).angle1==3;
                    if i==1 text(55,90,'Topo(C1)');end;
                    if i==2 text(55,90,'Topo(C2)');end;
                    if i==3 text(55,90,'Topo(C3)');end;
                    if i==4 text(55,90,'Topo(C4)');end;
                    if i==5 text(55,90,'Topo(C5)');end;
                    if i==6 text(55,90,'Topo(C6)');end;
                elseif para_p.angle(p_cnt).angle1==4;
                    if i==1 text(125,100,'Topo(C1)');end;
                    if i==2 text(125,100,'Topo(C2)');end;
                    if i==3 text(125,100,'Topo(C3)');end;
                    if i==4 text(125,100,'Topo(C4)');end;
                    if i==5 text(125,100,'Topo(C5)');end;
                    if i==6 text(125,100,'Topo(C6)');end;
                end;
                plot3(15.0,-5.0,0,'ok','MarkerSize',3,'MarkerFaceColor','r');       % left up
                plot3(-5.0,15.0,0,'o','MarkerSize',1,'Color',[0.8 0.8 0.8]);        % left down
                plot3(85.0,105.0,0,'o','MarkerSize',1,'Color',[0.8 0.8 0.8]);       % right down
                plot3(105.0,85.0,0,'o','MarkerSize',1,'Color',[0.8 0.8 0.8]);       % right up
            end;
            if i==6;                      % 5->6
                buff=colorbar;
                set(buff,'Position',[0.89 0.1 0.03 0.4]);
            end;
            zoom(3);
            hold off;
        end;

        %//////////// Visible //////////////
        if hb == 1;
            if kl_map_h(p_cnt).chk_val == 1;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','on');

            else;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','off');
            end;
        end;
        if hb == 2;
            if kl_map_h(p_cnt).chk_val == 2;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','on');
            else;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','off');
            end;
        end;
        if hb == 3;
            if kl_map_h(p_cnt).chk_val == 3;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','on');
            else;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','off');
            end;
        end;
        if hb == 4;
            if kl_map_h(p_cnt).chk_val == 4;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','on');
            else;
                set(kl_map_h(p_cnt).map_plot(hb,:),'Visible','off');
            end;
        end;
    end;
end;

%///////// clear //////////
clear h1;
clear b1;
clear a;
clear b;
clear i;
clear j;

clear pol_l;

clear pol_r;
clear buff;
clear hb_max;
clear hb_min;
clear x;
clear y;
clear xi;
clear yi;
clear topo_fig;
clear topo_range;
clear ml;
clear mr;
clear ch;
clear figure_h;

clear work;
