% kl_para
%
% Input  : info,para,mark,hb_data,para_p,Sel_graph,hb_graph_h
% Output : hb_data,kl_graph_h,kl_map_h,sParaKL
% Example: [hb_data,kl_graph_h,kl_map_h,sParaKL] = kl_para(info,para,mark,hb_data,para_p,Sel_graph,hb_graph_h)

%%---------------------------------------------
%% History FKL set call Disp function 
%% History F02.11.07 Futahashi make -> 02.11.11
%% History F02.11.27 Kawasaki  4*4 Mode add
%% History F03.11.06 Kusabuka  Continuous Mode PCA Analysis 
%%---------------------------------------------

function [hb_data,kl_graph_h,kl_map_h,sParaKL] = kl_para(info,para,mark,hb_data,para_p,Sel_graph);


%fprintf('kl_para\n');
% The structure object for KL setup is created.
sParaKL.start_time       = 5;	   	% Rise stimulus inclination time
sParaKL.start_delay      = 0;				% Rise stimulus delay time
sParaKL.end_time         = 5;			% The falling stimulus inclination time
sParaKL.end_delay        = 0;				% The falling stimulus delay time
sParaKL.threshold        = 0.60;			% Correlation threshold
sParaKL.sel_compo        = 0;				% The main-ingredients compounding method selection
sParaKL.compo1           = 1;				% The 1st main-ingredients selection existence
sParaKL.compo2           = 0;				% The 2nd main-ingredients selection existence
sParaKL.compo3           = 0;				% The 3nd main-ingredients selection existence
sParaKL.compo4           = 0;				% The 4nd main-ingredients selection existence
sParaKL.compo5           = 0;				% The 5nd main-ingredients selection existence
sParaKL.compo6to24       = 0;				% The 6-24nd main-ingredients selection existence
sParaKL.sel_total_hb     = 0;				% Total_Hb data selection
sParaKL.disp_oxy_graph   = 1;				% Main-ingredients analysis graph [oxy] display existence
sParaKL.disp_deoxy_graph = 0;				% Main-ingredients analysis graph [deoxy] display existence
sParaKL.disp_total_graph = 0;				% Main-ingredients analysis graph [total] display existence
sParaKL.disp_oxy_topo    = 1;				% Main-ingredients analysis topo[oxy] display existence
sParaKL.disp_deoxy_topo  = 0;				% Main-ingredients analysis topo[deoxy] display existence
sParaKL.disp_total_topo  = 0;				% Main-ingredients analysis topo[total] display existence
sParaKL.weight_absolute  = 0;				% Weight absolute value use selection existence
sParaKL.sel_point        = 0;				% For drawing
sParaKL.thre_lbl         = 0;				% The handle of a threshold label
sParaKL.thre_edit        = 0;				% The handle of a threshold editing box
sParaKL.compo1chk        = 0;				% The handle of main-ingredients 1 check box
sParaKL.compo2chk        = 0;				% The handle of main-ingredients 2 check box
sParaKL.compo3chk        = 0;				% The handle of main-ingredients 3 check box
sParaKL.compo4chk        = 0;				% The handle of main-ingredients 4 check box
sParaKL.compo5chk        = 0;				% The handle of main-ingredients 5 check box
sParaKL.compo6to24chk    = 0;				% The handle of main-ingredients 6-24 check box
sParaKL.eve_time         = 5;         % The event measure time 
sParaKL.mode             = 2;          % Pca Analysis mode defult=2

% Always, since the number of setting parameters is one, they specify and create a handle.
ParamFigure = figure(27);
set(ParamFigure,'Name',sprintf('%s','PCA Parameter'));
set(ParamFigure,'Resize','on','Position',[50 200 400 520],'Color',[1 1 1]*.8);
plotedit(ParamFigure,'hidetoolsmenu');
% -------------------- Parameter control for stimulus correlation -------------------- 

% Control reference point
pos_left = 20;

pos_top  = 280;

h = uicontrol('Parent',ParamFigure,...	% The frame for stimulus correlation
	'Units','points',...   
	'Position',[pos_left pos_top-10 260 110],...
   'BackgroundColor',[0.75 0.75 0.75], ...
   'Style','frame',...
   'Tag','Frame1');

h = uicontrol('Parent',ParamFigure,...	% Mark setting label
	'Units','points',...
    'Position',[pos_left+5 pos_top+80 100 15],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','text',...
    'String','Reference Waveform',...
    'Tag','StaticText1');

h = uicontrol('Parent',ParamFigure,...	% Start mark label
	'Units','points',...
    'Position',[pos_left+35 pos_top+65 70 15],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','text',...
    'String','Start Dip[s]',...
    'Tag','StaticText1');

h = uicontrol('Parent',ParamFigure,...	% End mark label
	'Units','points',...
    'Position',[pos_left+165 pos_top+65 50 15],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','text',...
    'String','End Dip[s]',...
    'Tag','StaticText1');

h = uicontrol('Parent',ParamFigure,...	% Delay label
	'Units','points',...
	'Position',[pos_left+20 pos_top+40 50 15],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','text',...
    'String','MarkDelay',...
    'Tag','StaticText1');

h = uicontrol('Parent',ParamFigure,...	% Standup label
	'Units','points',...
	'Position',[pos_left+20 pos_top+20 50 15],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','text',...
    'String','PulseDelay',...
    'Tag','StaticText1');

h = uicontrol('Parent',ParamFigure,...	% Stimulus delay editing box
	'Units','points',...
	'BackgroundColor',[1 1 1],...
	'Position',[pos_left+75 pos_top+40 40 15],...
    'Style','edit',...
    'String',sParaKL.start_delay,...
    'Callback',['val=str2num(get(gcbo,''string''));',...
                'if length(val) ~= 0;',...
                   'ret=strchknum(get(gcbo,''string''));',...
                   'val = round(val*10)/10;',...
                   'if ret > 0;',...
                      'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                   'elseif val < 0 | val > info(Sel_graph).datanum*(info(Sel_graph).smpl_period/1000);',...
                      'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                   'else;',...
                      'sParaKL.start_delay= val;',...
                   'end;',...
                   'set(gcbo,''string'', sParaKL.start_delay);',...
                   'clear ret;',...
                'else;',...
                   'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                   'set(gcbo,''string'', sParaKL.start_delay);',...
                'end;',...
                'clear val;',...
      		    'sParaKL.start_delay;'],...
    'Tag','Edit1');

h = uicontrol('Parent',ParamFigure,...	% Standup stimulus inclination editing box
	'Units','points',...
	'BackgroundColor',[1 1 1],...
	'Position',[pos_left+75 pos_top+20 40 15],...
    'Style','edit',...
    'String',sParaKL.start_time,...
    'Callback',['val=str2num(get(gcbo,''string''));',...
                'if length(val) ~= 0;',...
                   'ret=strchknum(get(gcbo,''string''));',...
                   'val = round(val*10)/10;',...
                   'if ret > 0;',...
                      'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                   'elseif val < 0 | val > info(Sel_graph).datanum*(info(Sel_graph).smpl_period/1000);',...
                      'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                   'else;',...
                      'sParaKL.start_time= val;',...
                   'end;',...
                   'set(gcbo,''string'', sParaKL.start_time);',...
                   'clear ret;',...
                'else;',...
                   'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                   'set(gcbo,''string'', sParaKL.start_time);',...
                'end;',...                
                'clear val;',...
   			    'sParaKL.start_time;'],...
    'Tag','Edit1');

h = uicontrol('Parent',ParamFigure,...	% Falling delay label
	'Units','points',...
	'Position',[pos_left+135 pos_top+40 50 15],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','text',...
    'String','MarkDelay',...
    'Tag','StaticText1');

h = uicontrol('Parent',ParamFigure,...	% Falling label
	'Units','points',...
	'Position',[pos_left+135 pos_top+20 50 15],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','text',...
    'String','PulseDelay',...
    'Tag','StaticText1');

h = uicontrol('Parent',ParamFigure,...	% Falling stimulus delay editing box
	'Units','points',...
	'BackgroundColor',[1 1 1],...
	'Position',[pos_left+190 pos_top+40 40 15],...
    'Style','edit',...
    'String',sParaKL.end_delay,...
    'Callback',['val=str2num(get(gcbo,''string''));',...
                'if length(val) ~= 0;',...
                   'ret=strchknum(get(gcbo,''string''));',...
                   'val = round(val*10)/10;',...
                   'if ret > 0;',...
                      'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                   'elseif val < 0 | val > info(Sel_graph).datanum*(info(Sel_graph).smpl_period/1000);',...
                      'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                   'else;',...
                      'sParaKL.end_delay= val;',...
                   'end;',...
                   'set(gcbo,''string'', sParaKL.end_delay);',...
                   'clear ret;',...
                'else;',...
                   'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                   'set(gcbo,''string'', sParaKL.end_delay);',...
                'end;',...
                'clear val;',...
      		    'sParaKL.end_delay;'],...
    'Tag','Edit1');

h = uicontrol('Parent',ParamFigure,...	% Falling stimulus inclination editing box
	'Units','points',...
	'BackgroundColor',[1 1 1],...
	'Position',[pos_left+190 pos_top+20 40 15],...
    'Style','edit',...
    'String',sParaKL.end_time,...
    'Callback',['val=str2num(get(gcbo,''string''));'...
                'if length(val) ~= 0;',...
                   'ret=strchknum(get(gcbo,''string''));',...
                   'val = round(val*10)/10;',...
                   'if ret > 0;',...
                      'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                   'elseif val < 0 | val > info(Sel_graph).datanum*(info(Sel_graph).smpl_period/1000);',...
                      'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                   'else;',...
                      'sParaKL.end_time= val;',...
                   'end;',...
                   'set(gcbo,''string'', sParaKL.end_time);',...
                   'clear ret;',...
                'else;',...
                   'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                   'set(gcbo,''string'', sParaKL.end_time);',...
                'end;',...
                'clear val;',...
      			'sParaKL.end_time;'],...
    'Tag','Edit1');

h_et = uicontrol('Parent',ParamFigure,...	% Event Time text
	'Units','points',...	
    'Position',[pos_left+5 pos_top 80 15],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','text',...
    'String','Stim Time',...
    'Visible','off',...
    'Tag','StaticText1');

h_ev = uicontrol('Parent',ParamFigure,...	% Event time editing box
	'Units','points',...
	'BackgroundColor',[1 1 1],...
	'Position',[pos_left+75 pos_top 40 15],...
    'Style','edit',...
    'String',sParaKL.eve_time,...
    'Visible','off',...
    'Callback',['val=str2num(get(gcbo,''string''));'...
                'if length(val) ~= 0;',...
                   'ret=strchknum(get(gcbo,''string''));',...
                   'val = round(val*10)/10;',...
                   'if ret > 0;',...
                      'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                   'elseif val < 0 | val > info(Sel_graph).datanum*(info(Sel_graph).smpl_period/1000);',...
                      'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                   'else;',...
                      'sParaKL.eve_time= val;',...
                   'end;',...
                   'set(gcbo,''string'', sParaKL.eve_time);',...
                   'clear ret;',...
                'else;',...
                   'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                   'set(gcbo,''string'', sParaKL.eve_time);',...
                'end;',...
                'clear val;',...
                'sParaKL.eve_time;' ],...
               'Tag','Edit1');

if info(Sel_graph).measure_mode == 2;
      set(h_et ,'Visible','on');             
      set(h_ev ,'Visible','on');             
end;          
% -------------------- Parameter control for reconstruction -------------------- 

% Control reference point
pos_left = 20;
pos_top  = 90;

h = uicontrol('Parent',ParamFigure,...	% The frame for reconstruction
	'Units','points',...
	'Position',[pos_left pos_top-5 260 180],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','frame',...
    'Tag','Frame1');

sParaKL.thre_lbl = uicontrol('Parent',ParamFigure,...	% threshold value label
	'Units','points',...
	'Position',[pos_left+25 pos_top+120 50 15],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','text',...
    'String','r Threshold',...
    'Tag','StaticText1');

sParaKL.thre_edit = uicontrol('Parent',ParamFigure,...	% Correlation threshold editing box
	'Units','points',...
	'BackgroundColor',[1 1 1],...
	'Position',[pos_left+80 pos_top+120 40 15],...
    'Style','edit',...
    'String',sParaKL.threshold,...
    'Callback',['val=str2num(get(gcbo,''string''));',...
                'if length(val) ~= 0;',...
                   'ret=strchknum(get(gcbo,''string''));',...
                   'val = round(val*1000)/1000;',...
                   'if ret > 0;',...
                       'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                   'elseif val >= 10 | val <= -10;',...
                       'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                   'else;',...
                      'sParaKL.threshold= val;',...
                   'end;',...
                   'set(gcbo,''string'', sParaKL.threshold);',...
                   'clear ret;',...
                'else;',...
                   'warndlg(''An input value is inaccurate.'',''Warning !!'');',...
                   'set(gcbo,''string'', sParaKL.threshold);',...
                'end;',...
                'clear val;',...
        	    'sParaKL.threshold;'],...
    'Tag','Edit1');

sParaKL.compo1chk = uicontrol('Parent',ParamFigure,...	% The 1st main-ingredients check box
   'Units','points',...
	'Position',[pos_left+30 pos_top+120 100 15],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','checkbox',...
    'String','No.1 Component',...
    'Value',1,...
    'Visible','off',...
    'Callback',['if get(gcbo,''value'')==1;sParaKL.compo1=1;end;',... 
   				'if get(gcbo,''value'')==0;sParaKL.compo1=0;end;',... 
   				'sParaKL.compo1;'],... 
	'Tag','Checkbox1');

sParaKL.compo2chk = uicontrol('Parent',ParamFigure,...	% The 2st main-ingredients check box
    'Units','points',...
	'Position',[pos_left+30 pos_top+100 100 15],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','checkbox',...
    'String','No.2 Component',...
    'Value',0,...
    'Visible','off',...
    'Callback',['if get(gcbo,''value'')==1;sParaKL.compo2=1;end;',... 
   				'if get(gcbo,''value'')==0;sParaKL.compo2=0;end;',... 
   				'sParaKL.compo2;'],... 
    'Tag','Checkbox1');

sParaKL.compo3chk = uicontrol('Parent',ParamFigure,...	% The 3rd main-ingredients check box
    'Units','points',...
	'Position',[pos_left+30 pos_top+80 100 15],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','checkbox',...
    'String','No.3 Component',...
    'Value',0,...
    'Visible','off',...
    'Callback',['if get(gcbo,''value'')==1;sParaKL.compo3=1;end;',... 
   				'if get(gcbo,''value'')==0;sParaKL.compo3=0;end;',... 
   				'sParaKL.compo3;'],... 
    'Tag','Checkbox1');

sParaKL.compo4chk = uicontrol('Parent',ParamFigure,...	% The 4rd main-ingredients check box
    'Units','points',...
    'Position',[pos_left+140 pos_top+120 100 15],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','checkbox',...
    'String','No.4 Component',...
    'Value',0,...
    'Visible','off',...
    'Callback',['if get(gcbo,''value'')==1;sParaKL.compo4=1;end;',... 
   				'if get(gcbo,''value'')==0;sParaKL.compo4=0;end;',... 
   				'sParaKL.compo4;'],... 
    'Tag','Checkbox1');

sParaKL.compo5chk = uicontrol('Parent',ParamFigure,...	% The 5rd main-ingredients check box
    'Units','points',...
	'Position',[pos_left+140 pos_top+100 100 15],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','checkbox',...
    'String','No.5 Component',...
    'Value',0,...
    'Visible','off',...
    'Callback',['if get(gcbo,''value'')==1;sParaKL.compo5=1;end;',... 
   				'if get(gcbo,''value'')==0;sParaKL.compo5=0;end;',... 
   				'sParaKL.compo5;'],... 
    'Tag','Checkbox1');

sParaKL.compo6to24chk = uicontrol('Parent',ParamFigure,...	% The 6-24 main-ingredients check box
    'Units','points',...
	'Position',[pos_left+140 pos_top+80 100 15],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','checkbox',...
    'String','No.6- Component',...
    'Value',0,...
    'Visible','off',...
    'Callback',['if get(gcbo,''value'')==1;sParaKL.compo6to24=1;end;',... 
   				'if get(gcbo,''value'')==0;sParaKL.compo6to24=0;end;',... 
   				'sParaKL.compo6to24;'],... 
    'Tag','Checkbox1');

h = uicontrol('Parent',ParamFigure,...	% The main-ingredients compounding method label
	'Units','points',...
    'Position',[pos_left+15 pos_top+150 100 15],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','text',...
    'String','Reconstruct Component',...
    'Tag','StaticText1');

h = uicontrol('Parent',ParamFigure,...	% The main-ingredients compounding method combobox
	'Units','points',...
    'Position',[pos_left+130 pos_top+150 110 15],...
    'BackgroundColor',[1 1 1], ...
    'Style','popup',...
    'String','Auto|Manual',...
    'Value',1,...
    'Callback',['if get(gcbo,''value'')==1;',...
					'',...	% The input editing box of a correlation threshold is displayed at the time of Auto.
					'set(sParaKL.thre_lbl,''Visible'',''on'');',...
					'set(sParaKL.thre_edit,''Visible'',''on'');',...
					'set(sParaKL.compo1chk,''Visible'',''off'');',...
					'set(sParaKL.compo2chk,''Visible'',''off'');',...
					'set(sParaKL.compo3chk,''Visible'',''off'');',...
					'set(sParaKL.compo4chk,''Visible'',''off'');',...
					'set(sParaKL.compo5chk,''Visible'',''off'');',...
					'set(sParaKL.compo6to24chk,''Visible'',''off'');',...
					'sParaKL.sel_compo=0;',...
				 'end;',... 
   				 'if get(gcbo,''value'')==2;',...
					'',...	% It is the display of the input main-ingredients selection check box of 1-6 (6 is 6-24) at the time of Manual.
					'set(sParaKL.thre_lbl,''Visible'',''off'');',...
					'set(sParaKL.thre_edit,''Visible'',''off'');',...
					'set(sParaKL.compo1chk,''Visible'',''on'');',...
					'set(sParaKL.compo2chk,''Visible'',''on'');',...
					'set(sParaKL.compo3chk,''Visible'',''on'');',...
					'set(sParaKL.compo4chk,''Visible'',''on'');',...
					'set(sParaKL.compo5chk,''Visible'',''on'');',...
					'set(sParaKL.compo6to24chk,''Visible'',''on'');',...
					'sParaKL.sel_compo=1;',...
				 'end;',... 
   				 'sParaKL.sel_compo;'],... 
    'Tag','popup1');

h = uicontrol('Parent',ParamFigure,...	% Total_Hb yuan data label
	'Units','points',...
    'Position',[pos_left+8 pos_top+45 80 15],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','text',...
    'String','Make Total Hb',...
    'Tag','StaticText1');

h = uicontrol('Parent',ParamFigure,...	%Total_Hb yuan data combobox
	'Units','points',...
    'Position',[pos_left+90 pos_top+45 150 15],...
    'BackgroundColor',[1 1 1], ...
    'Style','popup',...
    'String','Raw(oxy+deoxy)|Reconstruct(oxy+deoxy)',...
    'Value',1,...
    'Callback',['if get(gcbo,''value'')==1;sParaKL.sel_total_hb=0;end;',... 
   				'if get(gcbo,''value'')==2;sParaKL.sel_total_hb=1;end;',... 
   				'sParaKL.sel_total_hb;'],... 
    'Tag','popup1');

% % -------------------- Parameter control for reconstruction -------------------- 
h1=uicontrol('Parent',ParamFigure,...
    'Units','points',...
             'Position',[pos_left+8 pos_top+5 80 15],...
             'BackgroundColor',[0.75 0.75 0.75], ...
             'Style','text',...
             'String','Analysis Mode');
          
h = uicontrol('Parent',ParamFigure,...	% Package display check box
    'Units','points',...
    'Position',[pos_left+90 pos_top+5 150 15],...
    'BackgroundColor',[1 1 1], ...
    'Style','popupmenu',...
    'String','Each Probe|All Probe ',...
    'Value',sParaKL.mode,...
    'Callback',['sParaKL.mode=get(gcbo,''value'');',... 
   				],... 
    'Tag','Checkbox1');
% -------------------- Dignity absolute value use selection control -------------------- 

% Control reference point
pos_left = 20;
pos_top  = 40;

h = uicontrol('Parent',ParamFigure,...	% Main-ingredients analysis result display selection frame
	'Units','points',...
	'Position',[pos_left pos_top+10 260 30],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','frame',...
    'Tag','Frame1');

h = uicontrol('Parent',ParamFigure,...	% Dignity absolute value use check box
    'Units','points',...
	'Position',[pos_left+15 pos_top+15 150 15],...
    'BackgroundColor',[0.75 0.75 0.75], ...
    'Style','checkbox',...
    'String','Weight Absolute',...
    'Value',0,...
    'Callback',['if get(gcbo,''value'')==1;sParaKL.weight_absolute=1;end;',... 
   				'if get(gcbo,''value'')==0;sParaKL.weight_absolute=0;end;',... 
   				'sParaKL.weight_absolute;'],... 
    'Tag','Checkbox1');

% -------------------- KL conversion control -------------------- 

%Control reference point
pos_left = 190;
pos_top  = 5;

% !) If there is no substance of a variable here, warning will come out.
%    Only substance is created.

kl_graph_h(1).time_min  = 1;
kl_map_h(1).flg   = 0;

KlBtn = uicontrol('Parent',ParamFigure,...
                  'Units','points',...
                  'BackgroundColor',[128/255 255/255 255/255], ...
                  'FontSize',13,...
                  'Position',[pos_left pos_top 90 40],...
                  'String','Start',...
                  'Visible','on',...
                  'Callback',['if move_stop == 1;',...
                                 'if Mode == MOD_HB;',...
                                    'move_stop=1;',...
                                    'if kl_flg~=1;',...
                                       'if sParaKL.mode == 1;',... % Every probe
                                          '[hb_data,kl_graph_h,kl_map_h,kl_data,kl_flg] = kl_exec(info,para,mark,sParaKL,hb_data,para_p,kl_flg);',...
                                       'else;',...                         % Probe package
                                          '[hb_data,kl_graph_h,kl_map_h,kl_data,kl_flg] = kl_exec2(info,para,mark,sParaKL,hb_data,para_p,kl_flg);',...
                                       'end;',...
                                       'kl_flg=0;',...
                                    'end;',...
                                 'else;',...
                                    'warndlg(''PCA analysis is possible at execution after data analysis.'',''Warning'');',...
                                 'end;',...
                              'else;',...
                                 'warndlg(''Please push a stop button.'',''Warning !!'');',...
                              'end;',...
                             ],... 
                   'Tag','Pushbutton1');

 
