% LOAD_AD_ETG7000.m
%
% Input  : fname,MainFigure,para,para_p,para_h,dis_no
% Output : info,ad_data,mark,para_p
% Example: [info,ad_data,mark,para_p] = load_ad_ETG7000(fname,MainFigure,para,para_p,para_h,dis_no)
%

%*******************************************************
%*       Topo AD Data Load Function (ETG7000)          *
%*                Isawa Hidenori(HTS)                  *
%*                  HITACHI MECICAL                    *
%*******************************************************
% history?F03.04.23 Ver 2.00 Isawa(HTS)  	 ETG7000 data correspondence
% history?F03.10.27 Ver 2.01 Kawasaki		 Load improvement in the speed
% history?F03.11.04 Ver 2.01 Kusabuka(HTS)  ETG4000 data correspondence multi probe
% history?F04.04.28 Ver 2.03 Kawasaki       Fixed ETG7000 Ver2.00 Data load
% history?F04.06.17 Ver 2.03 Kusabuka       Sampling time make  
%                                           Two or more line comment correspondence
%                                           Find number of data point chenge
% history?F05.06.30 Ver 2.05 Kusabuka       3x10  

function [info,ad_data,mark,para,para_p] = load_ad_ETG7000(fname,MainFigure,para,para_p,para_h,dis_no);

%***** Initial Value ******
load_flg = 0;

%fname='E:\Matlabtopo\MatlabTopoV203_Beta\sample_data\ETG7000_all\Ver200_MES_Probe1.csv';
para_p.max_prb=5;
%para.sel_move = 0;

%********** Probe roop **********
for p_cnt=1:para_p.max_prb;	
   % MATLAB system version
%   info(p_cnt).sys_ver=ver;
   work = version;
   info(p_cnt).sys_ver = str2num(strtok(work,'.'));
   clear work;
   
   info(p_cnt).file_name=[[fname(1:length(fname)-5),num2str(p_cnt)],'.csv'];
   info(p_cnt).flg=2;
   info(p_cnt).sel_ch=1;
   f_name = info(p_cnt).file_name;
   %**** Find number of data point *****
   fp = fopen(f_name,'r');
   if fp == -1;
      info(p_cnt).file_name = strrep(f_name,'.csv','.txt' );
      f_name = info(p_cnt).file_name;
      fp = fopen(f_name,'r');
   end;
   if fp ~= -1;
      fseek(fp,0,'eof');    
      %if info(p_cnt).probe_mode == 4
         fseek(fp,-1400,'cof');
      %else 
      %   fseek(fp,-600,'cof');
      %end;
      for num=1:20;
         dum=fgets(fp);
         if dum ~= -1;
            dum2=sscanf(dum,'%d');
         else;
            break;
         end;
      end;
      info(p_cnt).datanum=dum2(1);
      fclose(fp);
      
      %Probe select information in paramater window
      if p_cnt==1;para_p.sel_prb1=1;para_p.load_prb1=1;end;
      if p_cnt==2;para_p.sel_prb2=1;para_p.load_prb2=1;end;
      if p_cnt==3;para_p.sel_prb3=1;para_p.load_prb3=1;end;
      if p_cnt==4;para_p.sel_prb4=1;para_p.load_prb4=1;end;
      if p_cnt==5;para_p.sel_prb5=1;para_p.load_prb5=1;end;
   end;
   
   %******* A/D Data Load ******
   fp = fopen(f_name,'r');
   if fp ~= -1;
      for num=1:50;
         dum = fgets(fp);
         if length(dum)==2;dum(3:6)=' ';end;%offset blanck
         
         %Data Division
         if length(dum)>=2
            if strncmp(dum(1:2),'ID',2)==1;
               Div = sprintf('%s',dum(3));
            end;
         end;
         %Data Area
         if (length(dum)>=5);
            if strncmp(dum(1:5),'Probe',5)==1;
	   		%Nuber of channel & Probe Mode            
               info(p_cnt).ad_ch_max=length(findstr(dum,'CH'));
               info(p_cnt).probe_mode = 1; %3x3
               if info(p_cnt).ad_ch_max == 48;
               elseif info(p_cnt).ad_ch_max == 44;
               elseif info(p_cnt).ad_ch_max == 104;
               elseif info(p_cnt).ad_ch_max == 94;
               else;
                  info(p_cnt).probe_mode=6;
                  break;
               end;

               if strcmp(Div,',')==1;%Comma
                  if info(p_cnt).ad_ch_max==48;
                     buff=fscanf(fp, '%d,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%d,%d:%d:%f,%d,%d,%d', [56,info(p_cnt).datanum])';
                  end;
                  if info(p_cnt).ad_ch_max==44;
                     buff=fscanf(fp, '%d,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%d,%d:%d:%f,%d,%d,%d', [52,info(p_cnt).datanum])';
                  end;      
                  if info(p_cnt).ad_ch_max==104;
                     buff=fscanf(fp, '%d,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%d,%d:%d:%f,%d,%d,%d', [112,info(p_cnt).datanum])';
                  end;
                  if info(p_cnt).ad_ch_max==94;
                     buff=fscanf(fp, '%d,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%d,%d:%d:%f,%d,%d,%d', [102,info(p_cnt).datanum])';
                  end;
               end;
            
               if strcmp(Div,';')==1;%Semicoron
                  if info(p_cnt).ad_ch_max==48;
                     buff=fscanf(fp, '%d;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%d;%d:%d:%f;%d;%d;%d', [56,info(p_cnt).datanum])';
                  end;         
                  if info(p_cnt).ad_ch_max==44;
                     buff=fscanf(fp, '%d;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%d;%d:%d:%f;%d;%d;%d', [52,info(p_cnt).datanum])';
                  end; 
                  if info(p_cnt).ad_ch_max==104;
                     buff=fscanf(fp, '%d;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%d;%d:%d:%f;%d;%d;%d', [112,info(p_cnt).datanum])';
                  end;
                  if info(p_cnt).ad_ch_max==94;
                     buff=fscanf(fp, '%d;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%f;%d;%d:%d:%f;%d;%d;%d', [102,info(p_cnt).datanum])';
                  end;
               end;
            
               if strcmp(Div,'	')==1;%Tab
                  if info(p_cnt).ad_ch_max==48; 
                     buff=fscanf(fp, '%d	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%d	%d:%d:%f	%d	%d	%d', [56,info(p_cnt).datanum])';
                  end;     
                  if info(p_cnt).ad_ch_max==44; 
                     buff=fscanf(fp, '%d	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%d	%d:%d:%f	%d	%d	%d', [52,info(p_cnt).datanum])';
                  end;
                  if info(p_cnt).ad_ch_max==104; 
                     buff=fscanf(fp, '%d	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%d	%d:%d:%f	%d	%d	%d', [112,info(p_cnt).datanum])';
                  end;
                  if info(p_cnt).ad_ch_max==94; 
                     buff=fscanf(fp, '%d	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%f	%d	%d:%d:%f	%d	%d	%d', [102,info(p_cnt).datanum])';
                  end;      
               end;

               if strcmp(Div,' ')==1;%Space
                  if info(p_cnt).ad_ch_max==48; 
                     buff=fscanf(fp, '%d %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %d %d:%d:%f %d %d %d', [56,info(p_cnt).datanum])';
                  end;
                  if info(p_cnt).ad_ch_max==44; 
                     buff=fscanf(fp, '%d %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %d %d:%d:%f %d %d %d', [52,info(p_cnt).datanum])';
                  end;
                  if info(p_cnt).ad_ch_max==104; 
                     buff=fscanf(fp, '%d %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %d %d:%d:%f %d %d %d', [112,info(p_cnt).datanum])';
                  end;   
                  if info(p_cnt).ad_ch_max==94; 
                     buff=fscanf(fp, '%d %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %d %d:%d:%f %d %d %d', [102,info(p_cnt).datanum])';
                  end;   
               end;
           
               %****** Edit arrangement ******
               if info(p_cnt).ad_ch_max==48;
                  ad_data(p_cnt).raw(:,[1:48])=buff(:,[2:49]);
                  ad_data(p_cnt).raw(:,49)=0;           % 
                  ad_data(p_cnt).raw(:,50)=buff(:,54);  % BodyMovement
                  ad_data(p_cnt).raw(:,51)=buff(:,50);  % Mark
%                  ad_data(p_cnt).raw(:,52)= sprintf('%d:%d:%f',buff(:,51),buff(:,52),buff(:,53));    % date
                  ad_data(p_cnt).raw(:,52)=buff(:,55);    % RemovalMark
                  ad_data(p_cnt).raw(:,53)=buff(:,56);    % PreScan
               end;   
               if info(p_cnt).ad_ch_max==44;
                  ad_data(p_cnt).raw(:,[1:44])=buff(:,[2:45]);
                  ad_data(p_cnt).raw(:,[45:49])=0;
                  ad_data(p_cnt).raw(:,50)=buff(:,50);       % BodyMovement(time 3calum)
                  ad_data(p_cnt).raw(:,51)=buff(:,46);       % Mark
                  ad_data(p_cnt).raw(:,52)=buff(:,51);       % RemovalMark
                  ad_data(p_cnt).raw(:,53)=buff(:,52);       % PreScan
               end;
               if info(p_cnt).ad_ch_max==104;
                  ad_data(p_cnt).raw(:,[1:104])=buff(:,[2:105]);
                  ad_data(p_cnt).raw(:,105)=0;              % add
                  ad_data(p_cnt).raw(:,106)=buff(:,110);    % BodyMovement
                  ad_data(p_cnt).raw(:,107)=buff(:,106);    % Mark
                  ad_data(p_cnt).raw(:,108)=buff(:,111);    % RemovalMark
                  ad_data(p_cnt).raw(:,109)=buff(:,112);    % PreScan
               end;   
               if info(p_cnt).ad_ch_max==94;
                  ad_data(p_cnt).raw(:,[1:94])=buff(:,[2:95]);
                  ad_data(p_cnt).raw(:,95)=0;              % add
                  ad_data(p_cnt).raw(:,96)=buff(:,100);    % BodyMovement
                  ad_data(p_cnt).raw(:,97)=buff(:,96);     % Mark
                  ad_data(p_cnt).raw(:,98)=buff(:,101);    % RemovalMark
                  ad_data(p_cnt).raw(:,99)=buff(:,102);    % PreScan
               end;
               
               break;   
            end;
         end;
      end;  
      fclose(fp);
      clear dum;

      if info(p_cnt).probe_mode==6;
         break;
      end;
      %***** Initial Value2(because not detect Ver2.00)******
      %Wave[nm]
      ad_data(p_cnt).title1='780';
      ad_data(p_cnt).title2='830';
      
      %Mode
      if info(p_cnt).ad_ch_max==48;info(p_cnt).probe_mode = 2;end; %4x4
      if info(p_cnt).ad_ch_max==44;info(p_cnt).probe_mode = 3;end; %3x5
      if info(p_cnt).ad_ch_max==104;info(p_cnt).probe_mode = 4;end; %3x11
      if info(p_cnt).ad_ch_max==94;info(p_cnt).probe_mode = 5;end; %3x10
      
      %Wave Length
      for i=1:info(p_cnt).ad_ch_max;
         info(p_cnt).wlen(2*i-1) = 780;
         info(p_cnt).wlen(2*i)   = 830;
      end;   
      
      %Exception Ch
      for cnt=1:info(p_cnt).ad_ch_max/2;info(p_cnt).err_ch(cnt)=0;end;
      
      %Sampling Period[s]  I think that there is no lack of data.
      info(p_cnt).smpl_period = 100;       % def 100ms
      if info(p_cnt).ad_ch_max==48;
          if info(p_cnt).datanum > 5+1;    % 5data from 2 data (MAX 40sec)
             s1=buff(2,53);
             s2=buff(6,53);
             if s2 < s1;                   % min chenge
                info(p_cnt).smpl_period = round((s2+(60-s1))*1000/(5-1));
             else;
                info(p_cnt).smpl_period=round((s2-s1)*1000/(5-1));
             end;
          else;
             s1=buff(1,53);
             s2=buff(info(p_cnt).datanum,53);
             if s2 < s1;                   % min chenge
                info(p_cnt).smpl_period = round((s2+(60-s1))*1000/(info(p_cnt).datanum-1));
             else;
                info(p_cnt).smpl_period=round((s2-s1)*1000/(info(p_cnt).datanum-1));
             end;
          end;
      elseif info(p_cnt).ad_ch_max==44;
          if info(p_cnt).datanum > 5+1;    % 5data from 2 data (MAX 50sec)
             s1=buff(2,49);
             s2=buff(6,49);
             if s2 < s1;                   % min chenge
                info(p_cnt).smpl_period = round((s2+(60-s1))*1000/(5-1));
             else;
                info(p_cnt).smpl_period=round((s2-s1)*1000/(5-1));
             end;
          else;
             s1=buff(1,49);
             s2=buff(info(p_cnt).datanum,49);
             if s2 < s1;                   % min chenge
                info(p_cnt).smpl_period = round((s2+(60-s1))*1000/(info(p_cnt).datanum-1));
             else;
                info(p_cnt).smpl_period=round((s2-s1)*1000/(info(p_cnt).datanum-1));
             end;
          end;
%          info(p_cnt).smpl_period=abs(((h2+m2+s2)-(h1+m1+s1))/(info(p_cnt).datanum-1))*1000;
      elseif info(p_cnt).ad_ch_max==104;
         if info(p_cnt).datanum > 5+1;    % 5data from 2 data (MAX 50sec)
            s1=buff(2,109);
            s2=buff(6,109);
            if s2 < s1;                   % min chenge
                info(p_cnt).smpl_period = round((s2+(60-s1))*1000/(5-1));
             else;
                info(p_cnt).smpl_period=round((s2-s1)*1000/(5-1));
             end;
         else;
            s1=buff(1,109);
            s2=buff(info(p_cnt).datanum,109);
            if s2 < s1;                   % min chenge
                info(p_cnt).smpl_period = round((s2+(60-s1))*1000/(info(p_cnt).datanum-1));
            else;
                info(p_cnt).smpl_period=round((s2-s1)*1000/(info(p_cnt).datanum-1));
            end;
         end;
      elseif info(p_cnt).ad_ch_max==94;   % 3x10
         if info(p_cnt).datanum > 5+1;    % 5data from 2 data (MAX 50sec)
            s1=buff(2,99);
            s2=buff(6,99);
            if s2 < s1;                   % min chenge
                info(p_cnt).smpl_period = round((s2+(60-s1))*1000/(5-1));
             else;
                info(p_cnt).smpl_period=round((s2-s1)*1000/(5-1));
             end;
         else;
            s1=buff(1,99);
            s2=buff(info(p_cnt).datanum,99);
            if s2 < s1;                   % min chenge
                info(p_cnt).smpl_period = round((s2+(60-s1))*1000/(info(p_cnt).datanum-1));
            else;
                info(p_cnt).smpl_period=round((s2-s1)*1000/(info(p_cnt).datanum-1));
            end;
         end;
      end;
      
      %Arrangement of A/D number
      for i=1:info(p_cnt).ad_ch_max;info(p_cnt).adnmpn(i) = i - 1;end;
   end;
   
   %******* Load Header *******
   fp= fopen(f_name,'r');
   if fp == -1;
      info(p_cnt).file_name = '';info(p_cnt).version = '';info(p_cnt).id = '';
      info(p_cnt).name = '';info(p_cnt).comment = '';info(p_cnt).age = '';info(p_cnt).sex = '';
      info(p_cnt).probe_mode = 0;info(p_cnt).measure_mode = 0;
      info(p_cnt).date = '';info(p_cnt).adnmpn = '';info(p_cnt).wlen = '';info(p_cnt).adrng = '';
      info(p_cnt).amprng = '';info(p_cnt).ampset = '';info(p_cnt).smpl_period = 0;
      info(p_cnt).datanum = 0;
      ad_data(p_cnt).raw = '';
   else
      for num=1:50;                            % header 41 + app
         dum = fgets(fp);
         if length(dum)==2;dum(3:6)=' ';end;   %offset blanck
         
         %File Version
         if strncmp(dum(1:4),'File',4)==1;
         info(p_cnt).version = str2num(dum(14:18));
         end;
         %ID
         if strncmp(dum(1:2),'ID',2)==1;
%            info(p_cnt).id = sprintf('%s     ',dum(4:length(dum)));
            info(p_cnt).id = sprintf('%s',dum(4:length(dum)));
         end;
         %Name
         if strncmp(dum(1:4),'Name',4)==1;
%            info(p_cnt).name = sprintf('%s        ',dum(6:length(dum)));
            info(p_cnt).name = sprintf('%s',dum(6:length(dum)));
         end;
         %Comment
         if strncmp(dum(1:6),'Commen',6)==1;
            info(p_cnt).comment = sprintf('%s',dum(9:length(dum)));
            a=1;
            while(1);
               dum = fgets(fp);
               if length(dum) >= 4; 
                  if strncmp(dum(1:4),'Date',4)==1;  break;   % Date (Next data) 
                  elseif strncmp(dum(1:3),'Age',3)==1;   break;    % age (Next data) 
                  else info(p_cnt).comment=sprintf('%s%s',info(p_cnt).comment,dum);
                  end;
               elseif length(dum) >= 3;
                  if strncmp(dum(1:3),'Age',3)==1;   break;    % age (Next data) 
                  else info(p_cnt).comment=sprintf('%s%s',info(p_cnt).comment,dum);
                  end;
               else;
                  info(p_cnt).comment=sprintf('%s%s',info(p_cnt).comment,dum);
               end;
               
               a=a+1;
               if a > 20;break;                                       % max 20 line
               end;
            end;
%            info(p_cnt).comment = sprintf( '%s           ',info(p_cnt).comment);
            info(p_cnt).comment = sprintf( '%s',info(p_cnt).comment);
%             work=findstr(info(p_cnt).sys_ver(1).Version,'.');     % Version get
%             if length(work) == 0;
%                sys_ver=str2num(info(p_cnt).sys_ver(1).Version);
%             else;
%                sys_ver=str2num(info(p_cnt).sys_ver(1).Version(1:work(1)-1));
%             end;

            if info(p_cnt).sys_ver < 7;                                  % Version 7.0 upper
               info(p_cnt).comment=deblank(info(p_cnt).comment);
               len = length(info(p_cnt).comment);
               str=findstr(info(p_cnt).comment,13);          % CR
               str_len=length(str);
               for cnt=1:str_len;
                  info(p_cnt).comment(str(cnt))=' ';         % CR -> SP
               end;
               str=findstr(info(p_cnt).comment,10);          % LF
               str_len=length(str);
               for cnt=1:str_len;
                  info(p_cnt).comment(str(cnt))=13;          % LF -> CR
               end;

               str=findstr(info(p_cnt).comment,',');         % , == LF
               str_len=length(str);
               d_cnt=1;
               if str_len >=2;                             % end data
                  if len == str(str_len) & len-1 == str(str_len-1);
                     info(p_cnt).comment(len)=13;          % , -> CR
                     info(p_cnt).comment(len-1)=13;        % , -> CR
                     str_len=0;
                     info(p_cnt).comment=deblank(info(p_cnt).comment);
                     len = length(info(p_cnt).comment);
                  end;
               end;
               for cnt=1:str_len;
                  info(p_cnt).comment(str(cnt))=13;
               end;
               if str_len < 1;
                  if len > 60;
                     if str_len < 2;
                        work='';
                        for cnt=1:len;
                           if strcmp(info(p_cnt).comment(cnt),' ');
                              work(d_cnt) = ' ';
                           else;
                              work(d_cnt)=strcat(info(p_cnt).comment(cnt));
                           end;
                           if cnt==30;
                              d_cnt=d_cnt+1;
                              work(d_cnt)=13;                 % CR
                           elseif cnt==60;              % 1line max 30
                              d_cnt=d_cnt+1;
                              work=sprintf('%s\n',work);
                              work(d_cnt)=13;                 % CR
                           end;
                           d_cnt=d_cnt+1;
                        end;
                        info(p_cnt).comment = sprintf( '%s',work);
                     end;
                  elseif len > 30;
                     if str_len < 1;
                        work='';
                        for cnt=1:len;
                           if strcmp(info(p_cnt).comment(cnt),' ');
                              work(d_cnt) = ' ';
                           else;
                              work(d_cnt)=strcat(info(p_cnt).comment(cnt));
                           end;
                           if cnt==30;
                              d_cnt=d_cnt+1;
                              work(d_cnt)=13;                 % CR
                           end;
                           d_cnt=d_cnt+1;
                        end;
                        info(p_cnt).comment = sprintf( '%s',work);
                     end;
                  end;
               end;
            else;
               info(p_cnt).comment=deblank(info(p_cnt).comment);
               len = length(info(p_cnt).comment);
               str=findstr(info(p_cnt).comment,13);          % CR
               str_len=length(str);
               for cnt=1:str_len;
                  info(p_cnt).comment(str(cnt))=' ';         % CR -> SP
               end;
               str=findstr(info(p_cnt).comment,',');         % , == LF
               str_len=length(str);
               d_cnt=1;
               if str_len >=2;                             % end data
                  if len == str(str_len) & len-1 == str(str_len-1);
                     info(p_cnt).comment(len)=13;          % , -> CR
                     info(p_cnt).comment(len-1)=13;        % , -> CR
                     str_len=0;
                     info(p_cnt).comment=deblank(info(p_cnt).comment);
                     len = length(info(p_cnt).comment);
                  end;
               end;
               for cnt=1:str_len;
                  info(p_cnt).comment(str(cnt))=10;
               end;
            end;
            info(p_cnt).comment = sprintf( '%s           ',info(p_cnt).comment);
         end;
         %Age
         if strncmp(dum(1:3),'Age',3)==1;info(p_cnt).age = sprintf('%s',dum(5:length(dum)));end;
         %Sex   
         if strncmp(dum(1:3),'Sex',3)==1;info(p_cnt).sex = sprintf('%s',dum(5:length(dum)));end;
         %Date   
%         if strncmp(dum(1:4),'Date',4)==1;info(p_cnt).date = sprintf('%s         ',dum(6:length(dum)));end;
         if strncmp(dum(1:4),'Date',4)==1;
            info(p_cnt).date = sprintf('%s',dum(6:length(dum)));
         end;
         % 070302
         %AnalyzeMode
         if length(dum) > 11;
            if strncmp(dum(1:11),'AnalyzeMode',11)==1;
               para.analyze = sprintf('%s',deblank(dum(13:length(dum)) ) );
               para.analyze_org = para.analyze;
            end;
         end;
         if length(dum) > 13;
            if strncmp(dum(1:13),'Analysis Mode',13)==1;
               para.analyze = sprintf('%s',deblank(dum(15:length(dum)) ) );
               para.analyze_org = para.analyze;
            end;
         end;
         %Pre
         if length(dum) > 11;
            if strncmp(dum(1:11),'Pre Time[s]',11)==1;
               para.pre = str2num(sprintf('%s',dum(13:length(dum) ) ) );
            end;
         end;
         %Post
         if length(dum) > 12;
            if strncmp(dum(1:12),'Post Time[s]',12)==1;
               para.post = str2num(sprintf('%s',dum(14:length(dum))));
            end;
         end;
         %relax
         if length(dum) > 16;
            if strncmp(dum(1:16),'Recovery Time[s]',16)==1;
               para.relax = str2num(sprintf('%s',dum(18:length(dum))));
            end;
         end;
         if length(dum) > 13;
            if strncmp(dum(1:13),'Relax Time[s]',13)==1;
               para.relax = str2num(sprintf('%s',dum(15:length(dum))));
            end;
         end;
         %Base
         %added by xu cui
         para.base_st = 1;
         para.base_ed = 100;
%          if length(dum) > 12;
%             if strncmp(dum(1:12),'Base Time[s]',12)==1;
%                para.base_st = 1;
%                para.base_ed = str2num(sprintf('%s',dum(14:length(dum))));
% %               para.base = (para.base*1000/info(1).smpl_period);
%             end;         
%         end;
         %fitting no use
         if length(dum) > 14;
            if strncmp(dum(1:14),'Fitting Degree',14)==1;str2num(dum(16:length(dum)));;end;         
         end;
         
            
         %Mode   
         if strncmp(dum(1:4),'Mode',4)==1;   
            if strncmp(dum(6:length(dum)),'3x3',3)==1     ;info(p_cnt).probe_mode = 1; %3x3 only ETG4000
            elseif strncmp(dum(6:length(dum)),'4x4',3)==1 ;info(p_cnt).probe_mode = 2; %4x4
            elseif strncmp(dum(6:length(dum)),'3x5',3)==1 ;info(p_cnt).probe_mode = 3; %3x5
            elseif strncmp(dum(6:length(dum)),'3x11',4)==1;info(p_cnt).probe_mode = 4; %3x11 only ETG4000
            elseif strncmp(dum(6:length(dum)),'3x10',4)==1;info(p_cnt).probe_mode = 5; %3x10 only ETG7000
            end;
         end;   
         %Wave[nm]
         if strncmp(dum(1:6),'Wave[n',6)==1;
            if strcmp(Div,',')==1;             %Comma
               [work,rem]=strtok(dum,Div);    %header skip
               [work,rem]=strtok(rem,Div);    ad_data(p_cnt).title1=work; % Title1
               [work,rem]=strtok(rem,Div);    work2=str2num(work);        % Title2
               ad_data(p_cnt).title2 = sprintf('%d',work2); 
            elseif strcmp(Div,';')==1;         %Semicoron
               [work,rem]=strtok(dum,Div);    %header skip
               [work,rem]=strtok(rem,Div);    ad_data(p_cnt).title1=work; % Title1
               [work,rem]=strtok(rem,Div);    work2=str2num(work);        % Title2
               ad_data(p_cnt).title2 = sprintf('%d',work2); 
            elseif strcmp(Div,'	')==1;        %Tab
               [work,rem]=strtok(dum,Div);    %header skip
               [work,rem]=strtok(rem,Div);    ad_data(p_cnt).title1=work; % Title1
               [work,rem]=strtok(rem,Div);    work2=str2num(work);        % Title2
               ad_data(p_cnt).title2 = sprintf('%d',work2); 
            elseif strcmp(Div,' ')==1;         %Space
               [work,rem]=strtok(dum,Div);    %header skip
               [work,rem]=strtok(rem,Div);    ad_data(p_cnt).title1=work; % title1
               [work,rem]=strtok(rem,Div);    work2=str2num(work);        % Title2
               ad_data(p_cnt).title2 = sprintf('%d',work2); 
            end;   
         end;   
         %Wave Length
         if strncmp(dum(1:6),'Wave L',6)==1;
            WaveCnt = 1;
            for i=13:length(dum);
               % ' ('is searched)
               if strcmp(dum(i:i), '(') == 1; 
                  for j=i+1: length(dum);
                     % ' ('is searched)
                     if strcmp(dum(j:j), ')') == 1 ;
                        % The data in a parenthesis is acquired.   
                        buf = dum(i:j);
                        val = sscanf(dum(i+1:j-1), '%f', [1,1]);
                        info(p_cnt).wlen(WaveCnt) = val;
                        WaveCnt = WaveCnt + 1;
                        i = i + j;
                        break;
                     end;
                  end;
               end;
            end;
         end;
         %Sampling Period[s]
         if strncmp(dum(1:6),'Sampli',6)==1;
            info(p_cnt).smpl_period = str2num(dum(20:length(dum)))*1000;
         end;

         %Measure Mode(1:Stim 2:Event)
         if strncmp(dum(1:6),'StimTy',6)==1;
            if strncmp(dum(10:length(dum)),'STIM',4)==1;info(p_cnt).measure_mode = 1; %STIM
            elseif strncmp(dum(10:length(dum)),'EVENT',5)==1 info(p_cnt).measure_mode = 2; %EVENT
            end;
         end;
         %Exception Ch
         if strncmp(dum(1:6),'Except',6)==1;
            [work,rem]=strtok(dum,Div);%header skip
            for cnt=1:info(p_cnt).ad_ch_max/2;
               [work,rem]=strtok(rem,Div);
               len=length(work);
               if len>1;
                  info(p_cnt).err_ch(cnt)=str2num(work(1));% last data return del
               else;
                  info(p_cnt).err_ch(cnt)=str2num(work);
               end;
            end;
         end; 
      end;
      if isfield(info(p_cnt),'version') == 0;
         info(p_cnt).version=2.0;
      end;
      fclose(fp);
      clear dum;
      
      % reset
      para.pre = (para.pre*1000/info(1).smpl_period);
      para.pre_org = para.pre;
      para.post = (para.post*1000/info(1).smpl_period);
      para.post_org = para.post;
      para.relax = (para.relax*1000/info(1).smpl_period);
      para.relax_org = para.relax;
      %****** Marker Check ******
      if p_cnt==1;
         mark.num = 0;mark.point = 0;
         mark.ave = 0;mark.char = '';
      end;
      
      %***** Mark make *****
      input_move;
      
      %****** Add Mark Infomation ******
      mark.ave(1:mark.num) = 1;
      mark.contrast = mark.ave * 0;
      load_flg= 1;
   end;
   clear dum;
end;% probe loop

if load_flg == 0;
   warndlg('Warning. File not found!  Choose proper file, please.','Warning');
end;
