function [dsignal, lmean, relativeChange] = mAveDetrend(signal,period)
% [dsignal, lmean, relativeChange] = mAveDetrend(signal,period)
% Signal is an input vector or matrix. If it is a matrix, each
% column (the first index) is detrended. 
% If signal is a row vector, dsignal will still be a column vector.
% 
% if signal is a vector, do detrend on this vector
% if signal is a matrix (2-D to 4-D), do detrend on first dimension
%
% dsignal: detrended signal
% lmean: the moving average (or the trend, the baseline)
% relativeChange: dsignal./lmean
%
% 2004, Chess Stetson and Cui Xu
%
% last revised: 2005/12/27 (add the case where period > signal length)
%
if (size(signal,1) == 1) signal = signal'; end;

dsignal = zeros(size(signal));
lmean = dsignal;

% if signal is only a vector, then this will convert it to a column vector
[row col]=size(signal);
if row==1
    signal = signal';
end

L = size(signal,1);
phalf = floor(period/2);

if period > L
    for ii=1:L
        lmean(ii,:,:,:) = mean(signal);
    end
else
    for ii=1:phalf
        lmean(ii,:,:,:) = mean(signal(1:2*ii-1,:,:,:),1);
    end;
    for ii=phalf+1:size(signal,1)-phalf
        lmean(ii,:,:,:) = mean(signal(ii-phalf:ii+phalf,:,:,:),1);
    end;
    for ii=size(signal,1)-phalf + 1:size(signal,1)
        lmean(ii,:,:,:) = mean(signal(2*ii-L:L,:,:,:),1);
    end;
end

dsignal = signal - lmean;
relativeChange = dsignal./lmean;

return;
